/*-
 * Copyright (c) 1994 by David Bagley.
 *
 * Permission to use, copy, modify, and distribute this software and its
 * documentation for any purpose and without fee is hereby granted,
 * provided that the above copyright notice appear in all copies and that
 * both that copyright notice and this permission notice appear in
 * supporting documentation.
 *
 * This file is provided AS IS with no warranties of any kind.  The author
 * shall have no liability with respect to the infringement of copyrights,
 * trade secrets or any patents by this file or any part thereof.  In no
 * event will the author be liable for any lost revenue or profits or
 * other special, indirect and consequential damages.
 *
 * Revision History:
 * 09-Nov-2010: Cubic close packing (-neighbors 14)
 * 28-Jun-2004: LIFE_NAMES compile-time option.
 * 02-Jun-2004: Lots more lifeforms.
 * 16-Apr-2004: S45B5 shower, blob with stabilizers, big pinwheel,
 *	      pulsar 10, pulsar 20
 * 15-Apr-2004: S45B5 linked glider, 123243, dancing beacon, Lq
 *	      S567B6 sparky, fountain, cruncher, big star, mouth
 *	      S56B5 double switch
 *	      S678B5 waving tail, deformed runner
 *	      S6767 pump
 *	      Found with life4d searcher by Lee Earl Meeker.
 * 13-Mar-2004: Updated with minimum points from:
 *	      Lee Earl Meeker's "Four Dimensional Cellular Automata and
 *	      the Game of Life" 1998
 *	      http://home.sc.rr.com/lmeeker/Lee/Home.html
 * 25-Jan-2003: File spawned from life3d.c, life forms from Carter Bays.
 *
 */

#define MAXNEIGHBORS 26
#define NEIGHBORKINDS 8
#define NUMPTS 42

typedef struct {
	int	 survival, birth;
} paramstruct;

static char plots[NEIGHBORKINDS] =
{
	6, 8, 12, 14, -14, 18, 20, 26	/* Neighborhoods */
};

/* http://www.tux.org/~bagleyd/life.html */
/* Below generated from java Life3DForms | dos2unix */

static char glider_12S3B3[][3 * NUMPTS + 1] =
{
	{
        1, 0, 0,

        0, 0, 1, 2, 0, 1,

        0, 1, 2, 2, 1, 2,
        1, 2, 2,

        1, 1, 3,
        127
	},
	{
        2, 1, 0,

        2, 0, 1,
        2, 2, 1,

        2, 1, 2,

        1, 3, 3, 3, 3, 3,

        1, 4, 4, 3, 4, 4,
        2, 5, 4,

        2, 4, 5,
        127
	},
};

static char glider_12S456B3[][3 * NUMPTS + 1] =
{
	{
        0, 1, 0, 2, 1, 0,

        2, 0, 1,
        1, 1, 1,

        1, 0, 2,
        2, 1, 2,

        0, 0, 3, 2, 0, 3,
        127
	},
};

static char glider_14S34B4[][3 * NUMPTS + 1] =
{
	{
        2, 1, 0,

         1, 1, 1, 2, 1, 1,
         2, 0, 1,

        1, 2, 2, 2, 2, 2,

         0, 0, 3,
         0, 1, 3,

        0, 1, 4,
        0, 2, 4, 1, 2, 4,

         0, 1, 5,
        127
	},
};

static char glider_14S34B46[][3 * NUMPTS + 1] =
{
	{
        2, 1, 0,

         1, 1, 1, 2, 1, 1,
         2, 0, 1,

        1, 2, 2, 2, 2, 2,

         0, 0, 3,
         0, 1, 3,

        0, 1, 4,
        0, 2, 4, 1, 2, 4,

         0, 1, 5,
        127
	},
};

static char glider_18S45B4[][3 * NUMPTS + 1] =
{
	{
        0, 0, 0, 1, 0, 0,
        1, 1, 0,
        1, 2, 0,
        0, 3, 0, 1, 3, 0,

        0, 0, 1, 1, 0, 1,
        1, 1, 1,
        1, 2, 1,
        0, 3, 1, 1, 3, 1,
        127
	},
};

static char glider_20S45B4[][3 * NUMPTS + 1] =
{
	{
        1, 0, 0,
        2, 1, 0,
        2, 2, 0,
        1, 3, 0,

        1, 0, 1,
        0, 1, 1, 1, 1, 1, 2, 1, 1,
        0, 2, 1, 1, 2, 1, 2, 2, 1,
        1, 3, 1,
        127
	},
};

static char glider_26S23B5[][3 * NUMPTS + 1] =
{
	{
        0, 0, 0,
        1, 1, 0,
        1, 2, 0,
        0, 3, 0,

        1, 0, 1,
        1, 3, 1,

        1, 0, 2,
        1, 3, 2,

        0, 0, 3,
        1, 1, 3,
        1, 2, 3,
        0, 3, 3,
        127
	},
};

static char glider_26S25B5[][3 * NUMPTS + 1] =
{
	{
        1, 0, 0,
        1, 1, 0,
        0, 2, 0, 1, 2, 0,
        1, 3, 0,
        0, 4, 0, 1, 4, 0,
        1, 5, 0,
        1, 6, 0,

        1, 0, 1,
        1, 2, 1,
        1, 4, 1,
        1, 6, 1,
        127
	},
};

static char glider_26S27B5[][3 * NUMPTS + 1] =
{
	{
        2, 1, 0,

        2, 0, 1,
        2, 2, 1,

        0, 0, 2, 2, 0, 2,
        0, 2, 2, 2, 2, 2,

        0, 0, 3, 2, 0, 3,
        0, 2, 3, 2, 2, 3,

        2, 0, 4,
        2, 2, 4,

        2, 1, 5,
        127
	},
};

static char glider_26S35B5[][3 * NUMPTS + 1] =
{
	{
        2, 2, 0,
        3, 3, 0,
        3, 4, 0,
        2, 5, 0,

        2, 2, 1,
        2, 5, 1,

        0, 0, 2, 1, 0, 2,
        2, 1, 2,
        3, 2, 2,
        3, 5, 2,
        2, 6, 2,
        0, 7, 2, 1, 7, 2,

        2, 2, 3,
        2, 5, 3,

        2, 2, 4,
        3, 3, 4,
        3, 4, 4,
        2, 5, 4,
        127
	},
};

static char glider_26S36B5[][3 * NUMPTS + 1] =
{
	{
        0, 2, 0,
        0, 3, 0,

        1, 2, 1,
        1, 3, 1,

        0, 0, 2,
        1, 1, 2,
        1, 2, 2,
        1, 3, 2,
        1, 4, 2,
        0, 5, 2,

        0, 0, 3,
        1, 1, 3,
        1, 2, 3,
        1, 3, 3,
        1, 4, 3,
        0, 5, 3,

        1, 2, 4,
        1, 3, 4,

        0, 2, 5,
        0, 3, 5,
        127
	},
};

static char glider_26S37B5[][3 * NUMPTS + 1] =
{
	{
        0, 2, 0,

        0, 1, 1, 1, 1, 1,
        0, 2, 1, 1, 2, 1,
        0, 3, 1, 1, 3, 1,

        0, 0, 2,
        0, 1, 2, 1, 1, 2,
        0, 3, 2, 1, 3, 2,
        0, 4, 2,

        0, 1, 3, 1, 1, 3,
        0, 2, 3, 1, 2, 3,
        0, 3, 3, 1, 3, 3,

        0, 2, 4,
        127
	},
};

static char glider_26S38B5[][3 * NUMPTS + 1] =
{
	{
        1, 0, 2, 2, 0, 2,
        1, 1, 2, 2, 1, 2,
        0, 2, 2, 1, 2, 2, 2, 2, 2, 3, 2, 2,

        1, 1, 3, 2, 1, 3,
        1, 2, 3, 2, 2, 3,
        127
	},
	{
        1, 0, 0, 2, 0, 0,

        0, 0, 1, 3, 0, 1,

        1, 0, 2, 2, 0, 2,
        1, 1, 2, 2, 1, 2,
        0, 2, 2, 1, 2, 2, 2, 2, 2, 3, 2, 2,

        1, 1, 3, 2, 1, 3,
        1, 2, 3, 2, 2, 3,
        127
	},
};

static char glider_26S4B5[][3 * NUMPTS + 1] =
{
	{
        0, 0, 0,
        1, 1, 0,
        1, 2, 0,
        0, 3, 0,

        1, 1, 1,
        1, 2, 1,

        1, 0, 2,
        1, 1, 2,
        1, 2, 2,
        1, 3, 2,

        1, 0, 3,
        1, 1, 3,
        1, 2, 3,
        1, 3, 3,

        1, 1, 4,
        1, 2, 4,

        0, 0, 5,
        1, 1, 5,
        1, 2, 5,
        0, 3, 5,
        127
	},
};

static char glider_26S45B5[][3 * NUMPTS + 1] =
{
	{
        0, 0, 0, 0, 1, 0,
        1, 2, 0,
        2, 2, 0,
        3, 0, 0, 3, 1, 0,

        1, 0, 1, 1, 1, 1,
        2, 0, 1, 2, 1, 1,
        127
	},
};

static char glider_26S47B5[][3 * NUMPTS + 1] =
{
	{
        0, 0, 0,
        0, 2, 0, 1, 2, 0,
        0, 4, 0,

        1, 1, 1,
        1, 2, 1,
        1, 3, 1,

        0, 0, 2, 1, 0, 2,
        1, 1, 2,
        1, 3, 2,
        0, 4, 2, 1, 4, 2,

        1, 1, 3,
        1, 2, 3,
        1, 3, 3,

        0, 0, 4,
        0, 2, 4, 1, 2, 4,
        0, 4, 4,
        127
	},
};

static char glider_26S56B5[][3 * NUMPTS + 1] =
{
	{
        1, -2, -1,
        -2, 1, -1,

        0, -2, 0, 2, -2, 0,
        1, -1, 0, 2, -1, 0,
        -2, 0, 0,
        -1, 1, 0,
        -2, 2, 0, -1, 2, 0,

        1, -2, 1, 2, -2, 1,
        -2, 1, 1,
        -2, 2, 1,
        127
	},
	{
        1, 4, 0, 2, 4, 0,
        0, 4, 1, 1, 4, 1, 2, 4, 1,
        0, 3, 1, 1, 3, 1,

        0, 1, 3, 1, 1, 3,

        1, 0, 4, 2, 0, 4,
        0, 1, 4, 1, 1, 4, 2, 1, 4,
        127
	},
};

static char glider_26S567B6[][3 * NUMPTS + 1] =
{
	{
        0, 1, 0, 1, 1, 0,
        0, 2, 1, 1, 2, 1,
        0, 0, 2, 1, 0, 2,
        0, 1, 2, 1, 1, 2,
        0, 2, 2, 1, 2, 2,
        127
	},
};

static char glider_26S57B6[][3 * NUMPTS + 1] =
{
	{
        0, 1, 0, 1, 1, 0,

        0, 2, 1, 1, 2, 1,

        0, 0, 2, 1, 0, 2,
        0, 1, 2, 1, 1, 2,
        0, 2, 2, 1, 2, 2,
        127
	},
};

static char glider_26S58B5[][3 * NUMPTS + 1] =
{
	{
        1, 3, 0, 2, 3, 0,

        1, 2, 1, 2, 2, 1,
        1, 3, 1, 2, 3, 1,

        1, 0, 2, 2, 0, 2,
        0, 2, 2, 1, 2, 2, 2, 2, 2, 3, 2, 2,
        1, 3, 2, 2, 3, 2,
        127
	},
};

static char glider_26S678B5[][3 * NUMPTS + 1] =
{
	{
        -1, -1, -1, -1, -1, 0,
        -1, 0, -2, -1, 0, -1, -1, 0, 0, -1, 0, 1,

        0, -1, -1, 0, -1, 0,
        0, 0, -1, 0, 0, 0,

        1, 0, -1, 1, 0, 0,
        127
	},
};

static char glider_26S8B5[][3 * NUMPTS + 1] =
{
	{
        1, 0, 0, 2, 0, 0,

        1, 0, 1, 2, 0, 1,
        1, 1, 1, 2, 1, 1,

        0, 0, 2, 1, 0, 2, 2, 0, 2, 3, 0, 2,
        1, 1, 2, 2, 1, 2,
        127
	},
};

static char patterns_12S3B3[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"2-N little glider (p2, diagonal)"},
#endif
	{
        1, 0, 0,

        0, 0, 1, 2, 0, 1,

        0, 1, 2, 2, 1, 2,
        1, 2, 2,

        1, 1, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"2-O big glider (p2, diagonal)"},
#endif
	{
        2, 1, 0,

        2, 0, 1,
        2, 2, 1,

        2, 1, 2,

        1, 3, 3, 3, 3, 3,

        1, 4, 4, 3, 4, 4,
        2, 5, 4,

        2, 4, 5,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"2-A"},
#endif
	{
        0, 0, -1,
        -1, 1, -1,

        0, -1, 0,
        1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"2-B"},
#endif
	{
        -1, -1, -1,
        0, 0, -1,

        0, -1, 0,
        1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"2-C"},
#endif
	{
        -1, -1, -1,

        1, -2, 0,
        0, -1, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2-E"},
#endif
	{
        0, 0, -1,

        0, -1, 0,
        1, 0, 0,

        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2-F"},
#endif
	{
        0, 0, -1,

        -2, 1, 0, 0, 1, 0,

        -1, -1, 1, 1, -1, 1,

        -1, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"2-G"},
#endif
	{
        -1, -2, 0,
        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0, 2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"2-H"},
#endif
	{
        -1, -1, -1, 1, -1, -1,
        0, 0, -1, 2, 0, -1,
        1, 1, -1,
        2, 2, -1,

        0, -2, 1,
        1, -1, 1,
        0, 0, 1, 2, 0, 1,
        1, 1, 1, 3, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2-I"},
#endif
	{
        -2, 0, -1,
        -1, 1, -1,

        -1, -2, 0,
        -2, -1, 0,
        1, 0, 0,
        0, 1, 0,

        -2, 0, 1,
        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2-J"},
#endif
	{
        -1, -2, -2,
        1, 0, -2,

        -1, -3, -1,
        0, -2, -1,
        -3, -1, -1, 1, -1, -1,
        -2, 0, -1, 2, 0, -1,
        -1, 1, -1,
        0, 2, -1,

        -2, -1, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"2-K"},
#endif
	{
        1, 1, -3,

        0, 1, -2,
        1, 2, -2,

        3, 1, -1, -1, 1, -1,
        2, 2, -1,

        -2, 1, 0, 2, 1, 0,
        -1, 2, 0,

        1, 1, 1,
        0, 2, 1,

        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"2-L"},
#endif
	{
        0, -2, -1,
        2, 0, -1,

        -2, -1, 0,
        -1, 0, 0,
        0, 1, 0,
        1, 2, 0,

        0, -2, 1,
        1, -1, 1,
        2, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2-L variant"},
#endif
	{
        0, -2, -1,
        0, 2, -1,

        -1, -2, 0,
        -1, 0, 0,
        -1, 2, 0,

        1, -3, 1,
        1, -1, 1,
        1, 1, 1,
        1, 3, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2-M"},
#endif
	{
        -1, -1, -1, 1, -1, -1,

        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        0, 1, 0,

        0, -1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"3-A"},
#endif
	{
        1, 1, -1,

        1, 0, 0,
        0, 1, 0,

        1, -1, 1,
        -1, 1, 1,

        1, -2, 2,
        0, -1, 2,
        -1, 0, 2,
        -2, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"3-B"},
#endif
	{
        0, -1, -2,
        -1, 0, -2, 1, 0, -2,
        -2, 1, -2, 2, 1, -2,

        -1, 1, -1, 1, 1, -1,

        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"3-C"},
#endif
	{
        1, -3, -3,
        0, -2, -3,
        -1, -1, -3,
        -2, 0, -3,

        1, -2, -2,
        -1, 0, -2,

        3, -3, -1,
        2, -2, -1,
        -1, 1, -1,
        -2, 2, -1,

        3, -2, 0,
        -1, 2, 0,

        3, -1, 1,
        2, 0, 1,
        1, 1, 1,
        0, 2, 1,

        1, 2, 2,
        3, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"3-D"},
#endif
	{
        -3, -3, -3,
        -1, -1, -3,
        1, 1, -3,
        3, 3, -3,

        -4, -3, -2,
        -3, -2, -2,
        -2, -1, -2,
        -1, 0, -2,
        0, 1, -2,
        1, 2, -2,
        2, 3, -2,
        3, 4, -2,

        -5, -3, -1,
        3, 5, -1,

        -4, -3, 0,
        -3, -2, 0,
        -2, -1, 0,
        -1, 0, 0,
        0, 1, 0,
        1, 2, 0,
        2, 3, 0,
        3, 4, 0,

        -3, -3, 1,
        -1, -1, 1,
        1, 1, 1,
        3, 3, 1,
        127
	},
#ifdef LIFE_NAMES
	{"3-BD"},
#endif
	{
        -2, 0, -3,
        0, 2, -3,

        -2, -1, -2,
        -1, 0, -2,
        0, 1, -2,
        1, 2, -2,

        -2, -2, -1,
        2, 2, -1,

        -2, -1, 0,
        -1, 0, 0,
        0, 1, 0,
        1, 2, 0,

        -2, 0, 1,
        0, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"3-E"},
#endif
	{
        0, -1, -2,
        1, 0, -2,
        -2, 1, -2,
        -1, 2, -2,

        -1, -3, -1,
        0, -2, -1,
        -3, -1, -1,
        -2, 0, -1, 2, 0, -1,
        3, 1, -1,
        0, 2, -1,
        1, 3, -1,

        1, -2, 0,
        2, -1, 0,
        -1, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"3-F"},
#endif
	{
        -2, -1, -2,

        0, -2, -1,
        -1, -1, -1,
        -2, 0, -1, 2, 0, -1,

        1, 0, 0,
        2, 1, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"4-F"},
#endif
	{
        -2, -2, -3,
        1, -1, -3,
        -1, 1, -3,
        2, 2, -3,

        1, -2, -2,
        0, -1, -2, 2, -1, -2,
        -1, 0, -2, 1, 0, -2,
        -2, 1, -2, 0, 1, -2,
        -1, 2, -2,

        -1, -1, -1, 1, -1, -1,
        -1, 1, -1, 1, 1, -1,

        -1, -2, 0,
        -2, -1, 0, 0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0, 2, 1, 0,
        1, 2, 0,

        2, -2, 1,
        -1, -1, 1,
        1, 1, 1,
        -2, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"4-H"},
#endif
	{
        0, 0, -1,
        1, 1, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0, 2, 1, 0,
        1, 2, 0,

        1, -1, 1,
        0, 0, 1, 2, 0, 1,
        -1, 1, 1, 1, 1, 1,
        0, 2, 1,

        1, 0, 2,
        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"5-A"},
#endif
	{
        0, -1, -2,

        -2, -2, -1,
        -1, -1, -1,
        0, 0, -1,
        1, 1, -1,

        -2, -1, 0,
        0, 1, 0,

        -3, -1, 1,
        -2, 0, 1,
        -1, 1, 1,
        0, 2, 1,

        -2, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"5-B"},
#endif
	{
        -2, -1, -2, 0, -1, -2,
        -1, 0, -2, 1, 0, -2,
        0, 1, -2, 1, 2, -2,

        -2, -2, -1, 0, -2, -1,
        1, -1, -1,
        2, 0, -1,
        2, 2, -1,

        -1, -2, 0, 0, -2, 1, 1, -2, 0,
        2, -1, 0,
        -1, 0, 0,
        0, 1, 0, 2, 1, 0,

        0, 0, 1, 2, 0, 1,

        2, -1, 2,
        1, -2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"6-A"},
#endif
	{
        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,

        0, -4, 1,
        -2, -2, 1, 2, -2, 1,
        -4, 0, 1, 4, 0, 1,
        -2, 2, 1, 2, 2, 1,
        0, 4, 1,
        127
	},
#ifdef LIFE_NAMES
	{"6-C"},
#endif
	{
        0, 0, -3,

        -1, -2, -2,
        0, -1, -2,
        1, 0, -2,
        2, 1, -2,

        -1, -1, -1,
        -2, 0, -1,
        1, 1, -1,
        0, 2, -1,

        -1, 0, 0,
        0, 1, 0,

        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"6-G"},
#endif
	{
        0, -1, -2,

        0, 0, -1,

        -1, -2, 0, 1, -2, 0,
        -2, 1, 0, 0, 1, 0,

        -1, -1, 1,
        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"6-H variant 1"},
#endif
	{
        -1, -3, -1,
        -2, -2, -1, 0, -2, -1,
        -1, -1, -1,
        1, 1, -1,
        0, 2, -1, 2, 2, -1,
        1, 3, -1,

        0, -1, 0,
        0, 1, 0,

        -1, -3, 1,
        -1, -1, 1,
        1, 1, 1,
        1, 3, 1,
        127
	},
#ifdef LIFE_NAMES
	{"6-H variant 2"},
#endif
	{
        -2, -1, 0, 2, -1, 0,
        -3, 0, 0, -1, 0, 0, 1, 0, 0, 3, 0, 0,
        -2, 1, 0, 2, 1, 0,

        -1, -1, 1, 1, -1, 1,

        -3, 0, 2, -1, 0, 2, 1, 0, 2, 3, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"7-A"},
#endif
	{
        0, 0, -3,

        0, -2, -1,
        1, -1, -1,
        1, 1, -1,
        0, 2, -1,

        -1, -2, 0,
        -2, -1, 0,
        -2, 1, 0,
        -1, 2, 0,

        -1, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"7-B"},
#endif
	{
        0, -1, -2,

        -1, -1, -1,
        0, 0, -1,
        -1, 1, -1, 1, 1, -1,

        0, -1, 0,
        -1, 0, 0,
        -2, 1, 0, 0, 1, 0,

        -1, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"8-C"},
#endif
	{
        0, -1, -2,

        0, -2, -1,
        -1, 1, -1, 1, 1, -1,

        -1, -2, 0, 1, -2, 0,
        0, 1, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"8-D"},
#endif
	{
        0, -1, -2,

        -2, 0, -1,
        -1, 1, -1,
        0, 2, -1,

        0, -1, 0,
        1, 0, 0,
        2, 1, 0,

        0, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"8-F"},
#endif
	{
        -2, -1, -2,
        0, 1, -2,

        -2, 0, -1,
        0, 2, -1, 2, 2, -1,

        -1, -2, 0,
        -2, -1, 0,
        1, 2, 0,

        2, 0, 1,

        1, -2, 2,
        0, -1, 2,
        1, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"8-H"},
#endif
	{
        0, -1, -2,
        -1, 0, -2, 1, 0, -2,
        0, 1, -2,

        0, -2, -1,
        -2, 0, -1,
        1, 1, -1,

        2, -1, 0,
        -1, -2, 0,
        1, -2, 0,

        0, -2, 1,
        -1, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"9-AB variant 1"},
#endif
	{
        2, 1, -4,

        0, 2, -3,

        3, 0, -2,
        2, 1, -2,
        -1, 2, -2,
        -1, 4, -2,

        2, -2, -1, 4, -2, -1,

        2, -3, 0,
        -2, 3, 0,

        -4, 2, 1, -2, 2, 1,

        1, -4, 2,
        1, -2, 2,
        -2, -1, 2,
        -3, 0, 2,

        0, -2, 3,

        -2, -1, 4,
        127
	},
#ifdef LIFE_NAMES
	{"9-AB variant 2"},
#endif
	{
        2, 1, -4,

        2, -1, -2,
        2, 1, -2,
        -1, 2, -2, 1, 2, -2,
        -1, 4, -2,

        2, -2, -1, 4, -2, -1,
        -2, 2, -1,


        2, -2, 1,
        -4, 2, 1, -2, 2, 1,

        1, -4, 2,
        -1, -2, 2, 1, -2, 2,
        -2, -1, 2,
        -2, 1, 2,

        -2, -1, 4,
        127
	},
#ifdef LIFE_NAMES
	{"9-AB variant 3"},
#endif
	{
        2, 1, -4,

        3, -1, -3,
        1, 1, -3,
        1, 3, -3,

        -1, 4, -2,

        4, -2, -1,
        3, -1, -1,
        -3, 3, -1, -1, 3, -1,


        1, -3, 1, 3, -3, 1,
        -3, 1, 1,
        -4, 2, 1,

        1, -4, 2,

        -1, -3, 3,
        -1, -1, 3,
        -3, 1, 3,

        -2, -1, 4,
        127
	},
#ifdef LIFE_NAMES
	{"9-AB variant 4"},
#endif
	{
        2, 0, -3,
        1, 1, -3,

        0, 1, -2,
        0, 3, -2,

        3, -1, -1,
        2, 0, -1,
        -1, 3, -1,

        1, -2, 0, 3, -2, 0,
        -3, 2, 0, -1, 2, 0,

        1, -3, 1,
        -2, 0, 1,
        -3, 1, 1,

        0, -3, 2,
        0, -1, 2,

        -1, -1, 3,
        -2, 0, 3,
        127
	},
#ifdef LIFE_NAMES
	{"9-F"},
#endif
	{
        -1, -1, -3,
        0, 0, -3,
        -3, 1, -3, 1, 1, -3,
        -2, 2, -3,
        -1, 3, -3,

        0, -1, -2,
        -3, 2, -2, 1, 2, -2,
        0, 3, -2,

        -3, -1, -1, 1, -1, -1,
        -3, 3, -1, 1, 3, -1,

        -2, -1, 0,
        -3, 0, 0, 1, 0, 0,
        -2, 3, 0,

        -1, -1, 1,
        0, 0, 1,
        -3, 1, 1, 1, 1, 1,
        -2, 2, 1,
        -1, 3, 1,
        127
	},
#ifdef LIFE_NAMES
	{"flip flop"},
#endif
	{
        0, -2, -1,
        -2, 0, -1, 2, 0, -1,
        0, 2, -1,

        -1, -2, 0,
        2, -1, 0,
        -2, 1, 0,
        1, 2, 0,

        -1, -1, 1, 1, -1, 1,
        -1, 1, 1, 1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"bridge"},
#endif
	{
        -2, -3, -2,
        2, 1, -2,

        -3, -3, -1,
        -3, -1, -1,
        0, 2, -1, 2, 2, -1,

        -2, -3, 0,
        -1, -2, 0,
        -1, 0, 0, 1, 0, 0,
        2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"octahedron"},
#endif
	{
        1, -1, -1,
        -1, 1, -1,

        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,

        -1, -1, 1,
        1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"star flicker"},
#endif
	{
        2, -1, -2,
        1, 0, -2,
        1, 2, -2,

        1, -1, -1,
        -1, 1, -1, 1, 1, -1,
        -2, 2, -1, 0, 2, -1,

        2, -1, 0,
        -2, 1, 0,

        0, -2, 1, 2, -2, 1,
        -1, -1, 1, 1, -1, 1,
        -1, 1, 1,

        -1, -2, 2,
        -1, 0, 2,
        -2, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"internal cube"},
#endif
	{
        0, 2, -3,

        1, -2, -2,
        -1, 0, -2, 1, 0, -2, 3, 0, -2,
        -2, 1, -2,

        0, -2, -1,
        -1, -1, -1,
        0, 2, -1, 2, 2, -1,

        2, -3, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -2, 3, 0,

        -2, -2, 1, 0, -2, 1,
        1, 1, 1,
        0, 2, 1,

        2, -1, 2,
        -3, 0, 2, -1, 0, 2, 1, 0, 2,
        -1, 2, 2,

        0, -2, 3,
        127
	},
#ifdef LIFE_NAMES
	{"square and diagonals"},
#endif
	{
        0, -1, -2,
        0, 1, -2,

        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,

        -1, 0, 2, 1, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"shake hands"},
#endif
	{
        2, -1, -2,
        -2, 1, -2,

        0, -2, -1, 2, -2, -1,
        -2, 2, -1, 0, 2, -1,

        2, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"strange toggler"},
#endif
	{
        0, -2, -3,
        -1, -1, -3, 1, -1, -3,

        1, 0, -2,

        0, -2, -1,
        -1, 1, -1, 1, 1, -1,

        0, -1, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"split"},
#endif
	{
        -2, 0, -1, 0, 0, -1,
        0, 2, -1,

        -1, -2, 0,
        0, 3, 0,

        -1, -1, 1,
        -1, 1, 1, 1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"CC"},
#endif
	{
        0, -2, -1,
        -1, -1, -1,
        0, 0, -1, 2, 0, -1,
        1, 1, -1,


        -1, -1, 1,
        -2, 0, 1, 0, 0, 1,
        1, 1, 1,
        0, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"throw"},
#endif
	{
        0, -1, -2,

        -1, -1, -1,
        0, 0, -1,

        -2, -1, 0,
        0, 1, 0,

        0, -2, 1,
        1, -1, 1,

        0, -1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"kick ball"},
#endif
	{
        0, -1, -2,
        -1, 0, -2, 1, 0, -2,

        -1, -1, -1, 1, -1, -1,

        -2, -1, 0,
        0, 1, 0, 2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"boxers"},
#endif
	{
        -2, 0, -1, 2, 0, -1,

        -1, -2, 0,
        0, -1, 0, 2, -1, 0,
        -2, 1, 0, 0, 1, 0,
        1, 2, 0,

        -1, -1, 1, 1, -1, 1,
        -1, 1, 1, 1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"shuffle"},
#endif
	{
        0, -2, -1,

        -2, -1, 0, 2, -1, 0,

        -1, -3, 1, 1, -3, 1,

        -3, -2, 2, -1, -2, 2, 1, -2, 2, 3, -2, 2,
        -2, -1, 2, 2, -1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"shuffle variant"},
#endif
	{
        0, -1, -2,
        -2, 1, -2, 2, 1, -2,

        -1, -1, -1, 1, -1, -1,

        -3, 0, 0, -1, 0, 0, 1, 0, 0, 3, 0, 0,
        -2, 1, 0, 2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"dancer"},
#endif
	{
        0, -1, -2,
        0, 1, -2,

        -2, 0, -1, 2, 0, -1,

        -1, -2, 0,
        1, 2, 0,

        -1, -1, 1,
        1, 1, 1,

        0, -1, 2,
        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"bird"},
#endif
	{
        0, -2, -1,
        0, 0, -1,

        -2, -1, 0, 2, -1, 0,

        -2, 0, 1, 0, 0, 1, 2, 0, 1,

        -2, -1, 2, 2, -1, 2,
        -2, 1, 2, 2, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"bat"},
#endif
	{
        -1, -2, -2,
        1, 0, -2,
        -1, 2, -2,

        1, -1, -1,
        1, 1, -1,

        0, -3, 0,
        -1, -2, 0,
        -1, 0, 0,
        -1, 2, 0,
        0, 3, 0,

        1, -1, 1,
        1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"bowl"},
#endif
	{
        -1, -3, -1, 1, -3, -1,
        -3, -1, -1, 3, -1, -1,
        -3, 1, -1, 3, 1, -1,
        -1, 3, -1, 1, 3, -1,

        -1, -4, 0, 1, -4, 0,
        -4, -1, 0, 0, -1, 0, 4, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -4, 1, 0, 0, 1, 0, 4, 1, 0,
        -1, 4, 0, 1, 4, 0,

        -1, -3, 1, 1, -3, 1,
        -3, -1, 1, 3, -1, 1,
        -3, 1, 1, 3, 1, 1,
        -1, 3, 1, 1, 3, 1,

        -1, -4, 2, 1, -4, 2,
        0, -3, 2,
        -4, -1, 2, 4, -1, 2,
        -3, 0, 2, 3, 0, 2,
        -4, 1, 2, 4, 1, 2,
        0, 3, 2,
        -1, 4, 2, 1, 4, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"monstra"},
#endif
	{
        -1, -3, -3,
        -2, -2, -3,
        -3, -1, -3, -1, -1, -3,
        1, 1, -3, 3, 1, -3,
        2, 2, -3,
        1, 3, -3,

        -2, -3, -2,
        -3, -2, -2,
        0, -1, -2,
        0, 1, -2,
        3, 2, -2,
        2, 3, -2,

        -3, -3, -1, -1, -3, -1,
        -3, -1, -1,
        -2, 0, -1, 2, 0, -1,
        3, 1, -1,
        1, 3, -1, 3, 3, -1,

        -1, -2, 0, 1, -2, 0,
        -1, 2, 0, 1, 2, 0,

        1, -3, 1, 3, -3, 1,
        3, -1, 1,
        -2, 0, 1, 2, 0, 1,
        -3, 1, 1,
        -3, 3, 1, -1, 3, 1,

        2, -3, 2,
        3, -2, 2,
        0, -1, 2,
        0, 1, 2,
        -3, 2, 2,
        -2, 3, 2,

        1, -3, 3,
        2, -2, 3,
        1, -1, 3, 3, -1, 3,
        -3, 1, 3, -1, 1, 3,
        -2, 2, 3,
        -1, 3, 3,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"2-D (p4)"},
#endif
	{
        -1, -1, -1,
        0, 0, -1,

        1, -2, 0,
        -1, 0, 0,
        0, 1, 0,

        -1, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"11-A portion opp (p4)"},
#endif
	{
        -4, 0, -1, 4, 0, -1,

        -1, 0, 0, 1, 0, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,

        -3, -1, 1, 3, -1, 1,
        -2, 0, 1, 2, 0, 1,
        -3, 1, 1, 3, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"11-A portion sync (p4)"},
#endif
	{
        0, -2, -1,
        -1, -1, -1,
        1, 1, -1,
        0, 2, -1,

        0, -3, 0,
        -1, -2, 0,
        1, 2, 0,
        0, 3, 0,

        0, -2, 1,
        -1, -1, 1,
        1, 1, 1,
        0, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"11-A double (p4)"},
#endif
	{
        -2, -2, -1, 2, -2, -1,
        -1, -1, -1, 1, -1, -1,
        -1, 1, -1, 1, 1, -1,
        -2, 2, -1, 2, 2, -1,

        -3, -2, 0, 3, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -3, 2, 0, 3, 2, 0,

        -2, -2, 1, 2, -2, 1,
        -1, -1, 1, 1, -1, 1,
        -1, 1, 1, 1, 1, 1,
        -2, 2, 1, 2, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"this that (p4)"},
#endif
	{
        -1, -3, -1, 1, -3, -1,
        -2, -2, -1, 2, -2, -1,
        -2, 2, -1, 2, 2, -1,
        -1, 3, -1, 1, 3, -1,

        -2, -3, 0, 2, -3, 0,
        -1, -2, 0, 1, -2, 0,
        -1, 2, 0, 1, 2, 0,
        -2, 3, 0, 2, 3, 0,

        -1, -3, 1, 1, -3, 1,
        -2, -2, 1, 2, -2, 1,
        -2, 2, 1, 2, 2, 1,
        -1, 3, 1, 1, 3, 1,
        127
	},
#ifdef LIFE_NAMES
	{"7-G Mitosis (p4)"},
#endif
	{
        0, 1, -4,
        -2, 1, -2, 2, 1, -2,
        -1, 2, -2, 1, 2, -2,

        -1, 1, -1, 1, 1, -1,
        -2, 2, -1, 2, 2, -1,
        0, 4, -1,

        0, -3, 0,
        -2, -1, 0, 2, -1, 0,
        -1, 0, 0, 1, 0, 0,

        -1, -1, 1, 1, -1, 1,
        -2, 0, 1, 2, 0, 1,

        0, 0, 3,
        127
	},
#ifdef LIFE_NAMES
	{"8-J Star (p4)"},
#endif
	{
        0, -1, -2,
        0, 1, -2,

        1, -1, -1,
        -2, 0, -1, 2, 0, -1,

        -1, -2, 0, 1, -2, 0,
        -1, 2, 0, 1, 2, 0,

        -2, 0, 1, 2, 0, 1,
        -1, 1, 1,

        0, -1, 2,
        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"ratchet (p4)"},
#endif
	{
        2, -1, -2,
        -1, 0, -2,
        2, 1, -2,
        -1, 2, -2, 1, 2, -2,

        0, -2, -1, 2, -2, -1,
        -1, -1, -1,
        -2, 2, -1,

        -2, -1, 0,
        2, 1, 0,

        2, -2, 1,
        1, 1, 1,
        -2, 2, 1, 0, 2, 1,

        -1, -2, 2, 1, -2, 2,
        -2, -1, 2,
        1, 0, 2,
        -2, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"5-C Metamorphosis (p6)"},
#endif
	{
        -1, -2, -2, 1, -2, -2,
        -2, -1, -2, 0, -1, -2, 2, -1, -2,
        -1, 0, -2, 1, 0, -2,
        -2, 1, -2, 0, 1, -2, 2, 1, -2,
        -1, 2, -2, 1, 2, -2,

        0, -2, -1,
        -2, 0, -1, 2, 0, -1,
        0, 2, -1,

        0, -3, 0,
        -3, 0, 0, 3, 0, 0,
        0, 3, 0,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"ball56 (p14)"},
#endif
	{
        0, -3, -4,
        0, -1, -4,
        0, 1, -4,
        0, 3, -4,

        -3, -3, -3, -1, -3, -3, 1, -3, -3, 3, -3, -3,
        -3, -1, -3, 3, -1, -3,
        -4, 0, -3, 4, 0, -3,
        -3, 1, -3, 3, 1, -3,
        -3, 3, -3, -1, 3, -3, 1, 3, -3, 3, 3, -3,


        -3, -3, -1, 3, -3, -1,
        -4, 0, -1, 4, 0, -1,
        -3, 3, -1, 3, 3, -1,

        -3, -4, 0, -1, -4, 0, 1, -4, 0, 3, -4, 0,
        -3, 4, 0, -1, 4, 0, 1, 4, 0, 3, 4, 0,

        -3, -3, 1, 3, -3, 1,
        -4, 0, 1, 4, 0, 1,
        -3, 3, 1, 3, 3, 1,


        -3, -3, 3, -1, -3, 3, 1, -3, 3, 3, -3, 3,
        -3, -1, 3, 3, -1, 3,
        -4, 0, 3, 4, 0, 3,
        -3, 1, 3, 3, 1, 3,
        -3, 3, 3, -1, 3, 3, 1, 3, 3, 3, 3, 3,

        0, -3, 4,
        0, -1, 4,
        0, 1, 4,
        0, 3, 4,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"4-A (stable)"},
#endif
	{
        -1, -1, -1,
        0, 0, -1,

        0, -1, 0,
        -1, 0, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"4-B (stable)"},
#endif
	{
        1, 0, -2,
        0, 1, -2, 2, 1, -2,
        1, 2, -2,

        2, 0, -1,
        0, 2, -1,

        1, -2, 0,
        2, -1, 0,
        -2, 1, 0,
        -1, 2, 0,

        0, -2, 1, 2, -2, 1,
        -2, 0, 1,
        -2, 2, 1,

        1, -2, 2,
        0, -1, 2,
        -1, 0, 2,
        -2, 1, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"4-D (stable)"},
#endif
	{
        1, -1, -3,
        0, 0, -3, 2, 0, -3,
        1, 1, -3,

        1, -2, -2,
        -1, 0, -2, 3, 0, -2,
        1, 2, -2,

        2, -2, -1, 0, -2, -1,
        -1, -1, -1, 3, -1, -1,
        -1, 1, -1, 3, 1, -1,
        0, 2, -1, 2, 2, -1,

        1, -2, 0,
        -1, 0, 0, 3, 0, 0,
        1, 2, 0,

        1, -1, 1,
        0, 0, 1, 2, 0, 1,
        1, 1, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"9-J (stable)"},
#endif
	{
        -1, 0, -2,
        0, 1, -2,

        0, -2, -1,
        -1, -1, -1, 1, -1, -1,
        2, 0, -1,
        -1, 1, -1, 1, 1, -1,

        1, -2, 0,
        -2, -1, 0,
        2, 1, 0,
        -1, 2, 0,

        -1, -1, 1, 1, -1, 1,
        -2, 0, 1,
        -1, 1, 1, 1, 1, 1,
        0, 2, 1,

        0, -1, 2,
        1, 0, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"10-G variant (stable)"},
#endif
	{
        3, 0, -4,
        2, 1, -4,
        1, 2, -4,
        0, 3, -4,

        2, 0, -3, 4, 0, -3,
        0, 2, -3,
        0, 4, -3,

        4, -1, -2,
        3, 0, -2,
        0, 3, -2,
        -1, 4, -2,

        4, -2, -1,
        -2, 4, -1,

        3, -4, 0,
        2, -3, 0, 4, -3, 0,
        3, -2, 0,
        -3, 2, 0,
        -4, 3, 0, -2, 3, 0,
        -3, 4, 0,

        2, -4, 1,
        -4, 2, 1,

        1, -4, 2,
        0, -3, 2,
        -3, 0, 2,
        -4, 1, 2,

        0, -4, 3,
        0, -2, 3,
        -4, 0, 3, -2, 0, 3,

        0, -3, 4,
        -1, -2, 4,
        -2, -1, 4,
        -3, 0, 4,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"bridge (stable)"},
#endif
	{
        2, -3, -2,
        1, -2, -2, 3, -2, -2,
        2, -1, -2,
        -2, 1, -2,
        -3, 2, -2, -1, 2, -2,
        -2, 3, -2,

        1, -3, -1,
        3, -1, -1,
        -3, 1, -1,
        -1, 3, -1,

        1, -2, 0,
        0, -1, 0, 2, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -2, 1, 0, 0, 1, 0,
        -1, 2, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"square (stable)"},
#endif
	{
        0, -3, -2,
        1, -2, -2,
        2, -1, -2,
        -3, 0, -2, 3, 0, -2,
        -2, 1, -2,
        -1, 2, -2,
        0, 3, -2,

        -1, -3, -1, 1, -3, -1,
        -3, -1, -1, 3, -1, -1,
        -3, 1, -1, 3, 1, -1,
        -1, 3, -1, 1, 3, -1,

        0, -3, 0,
        -1, -2, 0,
        -2, -1, 0,
        -3, 0, 0, 3, 0, 0,
        2, 1, 0,
        1, 2, 0,
        0, 3, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"hexagon (stable)"},
#endif
	{
        2, 1, -4,
        1, 2, -4,

        2, 0, -3,
        0, 2, -3, 2, 2, -3,

        3, -2, -2,
        2, -1, -2, 4, -1, -2,
        3, 0, -2,
        1, 2, -2,
        -2, 3, -2, 0, 3, -2,
        -1, 4, -2,

        4, -2, -1,
        -2, 2, -1,
        -2, 4, -1,

        2, -3, 0,
        3, -2, 0,
        -3, 2, 0,
        -2, 3, 0,

        2, -4, 1,
        2, -2, 1,
        -4, 2, 1,

        1, -4, 2,
        0, -3, 2, 2, -3, 2,
        -1, -2, 2,
        -3, 0, 2,
        -4, 1, 2, -2, 1, 2,
        -3, 2, 2,

        -2, -2, 3, 0, -2, 3,
        -2, 0, 3,

        -1, -2, 4,
        -2, -1, 4,
        127
	},
#endif
};

static char patterns_12S456B3[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider (c/2, p12 full diagonal)"},
#endif
	{
        0, 1, 0, 2, 1, 0,

        2, 0, 1,
        1, 1, 1,

        1, 0, 2,
        2, 1, 2,

        0, 0, 3, 2, 0, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"blinker"},
#endif
	{
        1, 1, -1,

        -1, 0, 0, 0, -1, 0,

        1, 1, 1,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"hex"},
#endif
	{
        1, -1, -1,
        0, 0, -1,

        1, -2, 0,
        0, -1, 0,
        -1, 0, 0,

        0, -2, 1,
        -1, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"blinker2"},
#endif
	{
        -1, -1, -1, 1, -1, -1,
        0, 0, -1,
        0, -2, -1,

        1, -2, 0,
        0, -1, 0,
        -1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"double blinker2"},
#endif
	{
        -2, -1, 0, 0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0, 2, 1, 0,
        -1, -2, 0, 1, 2, 0,

        0, -2, 1,
        -1, -1, 1,
        -2, 0, 1, 2, 0, 1,
        1, 1, 1,
        0, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"saucer"},
#endif
	{
        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 0, -1, 0, 2, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"prop"},
#endif
	{
        -1, -1, -1, 1, -1, -1,
        -1, 1, -1, 1, 1, -1,

        1, -2, 0,
        -2, -1, 0, 0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0, 2, 1, 0,
        -1, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"tetra"},
#endif
	{
        -1, -1, -1,
        0, 0, -1,
        1, 1, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        1, -1, 1,
        0, 0, 1,
        -1, 1, 1,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"cross cube"},
#endif
	{
        -2, -3, -4, 2, -3, -4,
        -3, -2, -4, -1, -2, -4, 1, -2, -4, 3, -2, -4,
        -2, -1, -4, 0, -1, -4, 2, -1, -4,
        -1, 0, -4, 1, 0, -4,
        -2, 1, -4, 0, 1, -4, 2, 1, -4,
        -3, 2, -4, -1, 2, -4, 1, 2, -4, 3, 2, -4,
        -2, 3, -4, 2, 3, -4,

        -2, -4, -3, 2, -4, -3,
        -1, -3, -3, 1, -3, -3,
        -4, -2, -3, 4, -2, -3,
        -3, -1, -3, 3, -1, -3,
        -3, 1, -3, 3, 1, -3,
        -4, 2, -3, 4, 2, -3,
        -1, 3, -3, 1, 3, -3,
        -2, 4, -3, 2, 4, -3,

        -3, -4, -2, -1, -4, -2, 1, -4, -2, 3, -4, -2,
        -4, -3, -2, 4, -3, -2,
        -4, -1, -2, 4, -1, -2,
        -4, 1, -2, 4, 1, -2,
        -4, 3, -2, 4, 3, -2,
        -3, 4, -2, -1, 4, -2, 1, 4, -2, 3, 4, -2,

        -2, -4, -1, 0, -4, -1, 2, -4, -1,
        -3, -3, -1, 3, -3, -1,
        -4, -2, -1, 4, -2, -1,
        -4, 0, -1, 4, 0, -1,
        -4, 2, -1, 4, 2, -1,
        -3, 3, -1, 3, 3, -1,
        -2, 4, -1, 0, 4, -1, 2, 4, -1,

        -1, -4, 0, 1, -4, 0,
        -4, -1, 0, 4, -1, 0,
        -4, 1, 0, 4, 1, 0,
        -1, 4, 0, 1, 4, 0,

        -2, -4, 1, 0, -4, 1, 2, -4, 1,
        -3, -3, 1, 3, -3, 1,
        -4, -2, 1, 4, -2, 1,
        -4, 0, 1, 4, 0, 1,
        -4, 2, 1, 4, 2, 1,
        -3, 3, 1, 3, 3, 1,
        -2, 4, 1, 0, 4, 1, 2, 4, 1,

        -3, -4, 2, -1, -4, 2, 1, -4, 2, 3, -4, 2,
        -4, -3, 2, 4, -3, 2,
        -4, -1, 2, 4, -1, 2,
        -4, 1, 2, 4, 1, 2,
        -4, 3, 2, 4, 3, 2,
        -3, 4, 2, -1, 4, 2, 1, 4, 2, 3, 4, 2,

        -2, -4, 3, 2, -4, 3,
        -1, -3, 3, 1, -3, 3,
        -4, -2, 3, 4, -2, 3,
        -3, -1, 3, 3, -1, 3,
        -3, 1, 3, 3, 1, 3,
        -4, 2, 3, 4, 2, 3,
        -1, 3, 3, 1, 3, 3,
        -2, 4, 3, 2, 4, 3,

        -2, -3, 4, 2, -3, 4,
        -3, -2, 4, -1, -2, 4, 1, -2, 4, 3, -2, 4,
        -2, -1, 4, 0, -1, 4, 2, -1, 4,
        -1, 0, 4, 1, 0, 4,
        -2, 1, 4, 0, 1, 4, 2, 1, 4,
        -3, 2, 4, -1, 2, 4, 1, 2, 4, 3, 2, 4,
        -2, 3, 4, 2, 3, 4,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"tetra mold"},
#endif
	{
        -1, -3, -3,
        -3, -1, -3,
        3, 1, -3,
        1, 3, -3,

        -1, -2, -2,
        -2, -1, -2, 0, -1, -2,
        -1, 0, -2, 1, 0, -2,
        0, 1, -2, 2, 1, -2,
        1, 2, -2,

        -3, -3, -1,
        -2, -2, -1, 0, -2, -1,
        -2, 0, -1, 2, 0, -1,
        0, 2, -1, 2, 2, -1,
        3, 3, -1,

        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,

        3, -3, 1,
        0, -2, 1, 2, -2, 1,
        -2, 0, 1, 2, 0, 1,
        -2, 2, 1, 0, 2, 1,
        -3, 3, 1,

        1, -2, 2,
        0, -1, 2, 2, -1, 2,
        -1, 0, 2, 1, 0, 2,
        -2, 1, 2, 0, 1, 2,
        -1, 2, 2,

        1, -3, 3,
        3, -1, 3,
        -3, 1, 3,
        -1, 3, 3,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"F (p3)"},
#endif
	{
        -2, -2, -3,
        -3, -1, -3, -1, -1, -3,
        -2, 0, -3,

        -3, -2, -2, -1, -2, -2,
        -3, 0, -2, -1, 0, -2,

        -2, -2, -1,
        -3, -1, -1, -1, -1, -1,
        -2, 0, -1,

        1, 0, 0,
        0, 1, 0, 2, 1, 0,
        1, 2, 0,

        0, 0, 1, 2, 0, 1,
        0, 2, 1, 2, 2, 1,

        1, 0, 2,
        0, 1, 2, 2, 1, 2,
        1, 2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"spore (p3)"},
#endif
	{
        -3, -3, -3, -1, -3, -3,
        -2, -2, -3,
        -3, -1, -3,
        0, 0, -3,

        -2, -3, -2,
        -3, -2, -2,

        -3, -3, -1,
        0, 0, -1,

        0, -3, 0,
        0, -1, 0,
        -3, 0, 0, -1, 0, 0, 1, 0, 0, 3, 0, 0,
        0, 1, 0,
        0, 3, 0,

        0, 0, 1,
        3, 3, 1,

        3, 2, 2,
        2, 3, 2,

        0, 0, 3,
        3, 1, 3,
        2, 2, 3,
        1, 3, 3, 3, 3, 3,
        127
	},
#ifdef LIFE_NAMES
	{"turtle (p3)"},
#endif
	{
        -1, -3, -1,
        -3, -1, -1, -1, -1, -1,
        1, 1, -1, 3, 1, -1,
        1, 3, -1,

        0, -3, 0,
        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 0, -1, 0, 2, -1, 0,
        -3, 0, 0, -1, 0, 0, 1, 0, 0, 3, 0, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,
        0, 3, 0,

        0, -2, 1,
        -2, 0, 1, 2, 0, 1,
        0, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"kissing fish (p3)"},
#endif
	{
        -1, 0, -2, 1, 0, -2,

        -2, 0, -1, 2, 0, -1,

        -4, -1, 0, -2, -1, 0, 2, -1, 0, 4, -1, 0,
        -3, 0, 0, -1, 0, 0, 1, 0, 0, 3, 0, 0,
        -4, 1, 0, -2, 1, 0, 2, 1, 0, 4, 1, 0,

        -2, 0, 1, 2, 0, 1,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"L variant (p3)"},
#endif
	{
        2, 0, -3,
        0, 2, -3,

        -1, -2, -2,
        -2, -1, -2, 0, -1, -2, 2, -1, -2,
        -1, 0, -2, 1, 0, -2, 3, 0, -2,
        0, 1, -2, 2, 1, -2,
        -1, 2, -2, 1, 2, -2,
        0, 3, -2,

        -2, -2, -1, 0, -2, -1, 2, -2, -1,
        -2, 0, -1, 2, 0, -1,
        -2, 2, -1, 0, 2, -1,

        2, -3, 0,
        -1, -2, 0, 1, -2, 0, 3, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -3, 2, 0, -1, 2, 0, 1, 2, 0,
        -2, 3, 0,

        0, -2, 1, 2, -2, 1,
        -2, 0, 1, 2, 0, 1,
        -2, 2, 1, 0, 2, 1, 2, 2, 1,

        0, -3, 2,
        -1, -2, 2, 1, -2, 2,
        -2, -1, 2, 0, -1, 2,
        -3, 0, 2, -1, 0, 2, 1, 0, 2,
        -2, 1, 2, 0, 1, 2, 2, 1, 2,
        1, 2, 2,

        0, -2, 3,
        -2, 0, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"exploding box (p3)"},
#endif
	{
        -3, -3, -3, -1, -3, -3, 1, -3, -3, 3, -3, -3,
        -2, -2, -3, 2, -2, -3,
        -3, -1, -3, 3, -1, -3,
        -3, 1, -3, 3, 1, -3,
        -2, 2, -3, 2, 2, -3,
        -3, 3, -3, -1, 3, -3, 1, 3, -3, 3, 3, -3,

        -2, -3, -2, 2, -3, -2,
        -3, -2, -2, 3, -2, -2,
        -3, 2, -2, 3, 2, -2,
        -2, 3, -2, 2, 3, -2,

        -3, -3, -1, 3, -3, -1,
        -3, 3, -1, 3, 3, -1,

        -3, -3, 1, 3, -3, 1,
        -3, 3, 1, 3, 3, 1,

        -2, -3, 2, 2, -3, 2,
        -3, -2, 2, 3, -2, 2,
        -3, 2, 2, 3, 2, 2,
        -2, 3, 2, 2, 3, 2,

        -3, -3, 3, -1, -3, 3, 1, -3, 3, 3, -3, 3,
        -2, -2, 3, 2, -2, 3,
        -3, -1, 3, 3, -1, 3,
        -3, 1, 3, 3, 1, 3,
        -2, 2, 3, 2, 2, 3,
        -3, 3, 3, -1, 3, 3, 1, 3, 3, 3, 3, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"sporeball (p3)"},
#endif
	{
        -3, -3, -3, -1, -3, -3, 1, -3, -3, 3, -3, -3,
        -2, -2, -3, 2, -2, -3,
        -3, -1, -3, 3, -1, -3,
        -3, 1, -3, 3, 1, -3,
        -2, 2, -3, 2, 2, -3,
        -3, 3, -3, -1, 3, -3, 1, 3, -3, 3, 3, -3,

        -2, -3, -2, 2, -3, -2,
        -3, -2, -2, 3, -2, -2,
        -3, 2, -2, 3, 2, -2,
        -2, 3, -2, 2, 3, -2,

        -3, -3, -1, 3, -3, -1,
        -3, 3, -1, 3, 3, -1,

        -3, -3, 1, 3, -3, 1,
        -3, 3, 1, 3, 3, 1,

        -2, -3, 2, 2, -3, 2,
        -3, -2, 2, 3, -2, 2,
        -3, 2, 2, 3, 2, 2,
        -2, 3, 2, 2, 3, 2,

        -3, -3, 3, -1, -3, 3, 1, -3, 3, 3, -3, 3,
        -2, -2, 3, 2, -2, 3,
        -3, -1, 3, 3, -1, 3,
        -3, 1, 3, 3, 1, 3,
        -2, 2, 3, 2, 2, 3,
        -3, 3, 3, -1, 3, 3, 1, 3, 3, 3, 3, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"big oct (p3)"},
#endif
	{
        0, -2, -5,
        -2, 0, -5, 2, 0, -5,
        0, 2, -5,

        0, -3, -4,
        -1, -2, -4, 1, -2, -4,
        -2, -1, -4, 0, -1, -4, 2, -1, -4,
        -3, 0, -4, -1, 0, -4, 1, 0, -4, 3, 0, -4,
        -2, 1, -4, 0, 1, -4, 2, 1, -4,
        -1, 2, -4, 1, 2, -4,
        0, 3, -4,

        0, -4, -3,
        -4, 0, -3, 4, 0, -3,
        0, 4, -3,

        0, -5, -2,
        -1, -4, -2, 1, -4, -2,
        -4, -1, -2, 4, -1, -2,
        -5, 0, -2, 5, 0, -2,
        -4, 1, -2, 4, 1, -2,
        -1, 4, -2, 1, 4, -2,
        0, 5, -2,

        -2, -4, -1, 0, -4, -1, 2, -4, -1,
        -4, -2, -1, 4, -2, -1,
        -4, 0, -1, 4, 0, -1,
        -4, 2, -1, 4, 2, -1,
        -2, 4, -1, 0, 4, -1, 2, 4, -1,

        -2, -5, 0, 2, -5, 0,
        -3, -4, 0, -1, -4, 0, 1, -4, 0, 3, -4, 0,
        -4, -3, 0, 4, -3, 0,
        -5, -2, 0, 5, -2, 0,
        -4, -1, 0, 4, -1, 0,
        -4, 1, 0, 4, 1, 0,
        -5, 2, 0, 5, 2, 0,
        -4, 3, 0, 4, 3, 0,
        -3, 4, 0, -1, 4, 0, 1, 4, 0, 3, 4, 0,
        -2, 5, 0, 2, 5, 0,

        -2, -4, 1, 0, -4, 1, 2, -4, 1,
        -4, -2, 1, 4, -2, 1,
        -4, 0, 1, 4, 0, 1,
        -4, 2, 1, 4, 2, 1,
        -2, 4, 1, 0, 4, 1, 2, 4, 1,

        0, -5, 2,
        -1, -4, 2, 1, -4, 2,
        -4, -1, 2, 4, -1, 2,
        -5, 0, 2, 5, 0, 2,
        -4, 1, 2, 4, 1, 2,
        -1, 4, 2, 1, 4, 2,
        0, 5, 2,

        0, -4, 3,
        -4, 0, 3, 4, 0, 3,
        0, 4, 3,

        0, -3, 4,
        -1, -2, 4, 1, -2, 4,
        -2, -1, 4, 0, -1, 4, 2, -1, 4,
        -3, 0, 4, -1, 0, 4, 1, 0, 4, 3, 0, 4,
        -2, 1, 4, 0, 1, 4, 2, 1, 4,
        -1, 2, 4, 1, 2, 4,
        0, 3, 4,

        0, -2, 5,
        -2, 0, 5, 2, 0, 5,
        0, 2, 5,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"big oct variant (p3)"},
#endif
	{
        0, -2, -5,
        -2, 0, -5, 2, 0, -5,
        0, 2, -5,

        0, -3, -4,
        -1, -2, -4, 1, -2, -4,
        -2, -1, -4, 0, -1, -4, 2, -1, -4,
        -3, 0, -4, -1, 0, -4, 1, 0, -4, 3, 0, -4,
        -2, 1, -4, 0, 1, -4, 2, 1, -4,
        -1, 2, -4, 1, 2, -4,
        0, 3, -4,

        0, -4, -3,
        -4, 0, -3, 4, 0, -3,
        0, 4, -3,

        0, -5, -2,
        -1, -4, -2, 1, -4, -2,
        -1, -2, -2, 1, -2, -2,
        -4, -1, -2, -2, -1, -2, 0, -1, -2, 2, -1, -2, 4, -1, -2,
        -5, 0, -2, -1, 0, -2, 1, 0, -2, 5, 0, -2,
        -4, 1, -2, -2, 1, -2, 0, 1, -2, 2, 1, -2, 4, 1, -2,
        -1, 2, -2, 1, 2, -2,
        -1, 4, -2, 1, 4, -2,
        0, 5, -2,

        -2, -4, -1, 0, -4, -1, 2, -4, -1,
        -4, -2, -1, -2, -2, -1, 0, -2, -1, 2, -2, -1, 4, -2, -1,
        -4, 0, -1, -2, 0, -1, 2, 0, -1, 4, 0, -1,
        -4, 2, -1, -2, 2, -1, 0, 2, -1, 2, 2, -1, 4, 2, -1,
        -2, 4, -1, 0, 4, -1, 2, 4, -1,

        -2, -5, 0, 2, -5, 0,
        -3, -4, 0, -1, -4, 0, 1, -4, 0, 3, -4, 0,
        -4, -3, 0, 4, -3, 0,
        -5, -2, 0, -1, -2, 0, 1, -2, 0, 5, -2, 0,
        -4, -1, 0, -2, -1, 0, 2, -1, 0, 4, -1, 0,
        -4, 1, 0, -2, 1, 0, 2, 1, 0, 4, 1, 0,
        -5, 2, 0, -1, 2, 0, 1, 2, 0, 5, 2, 0,
        -4, 3, 0, 4, 3, 0,
        -3, 4, 0, -1, 4, 0, 1, 4, 0, 3, 4, 0,
        -2, 5, 0, 2, 5, 0,

        -2, -4, 1, 0, -4, 1, 2, -4, 1,
        -4, -2, 1, -2, -2, 1, 0, -2, 1, 2, -2, 1, 4, -2, 1,
        -4, 0, 1, -2, 0, 1, 2, 0, 1, 4, 0, 1,
        -4, 2, 1, -2, 2, 1, 0, 2, 1, 2, 2, 1, 4, 2, 1,
        -2, 4, 1, 0, 4, 1, 2, 4, 1,

        0, -5, 2,
        -1, -4, 2, 1, -4, 2,
        -1, -2, 2, 1, -2, 2,
        -4, -1, 2, -2, -1, 2, 0, -1, 2, 2, -1, 2, 4, -1, 2,
        -5, 0, 2, -1, 0, 2, 1, 0, 2, 5, 0, 2,
        -4, 1, 2, -2, 1, 2, 0, 1, 2, 2, 1, 2, 4, 1, 2,
        -1, 2, 2, 1, 2, 2,
        -1, 4, 2, 1, 4, 2,
        0, 5, 2,

        0, -4, 3,
        -4, 0, 3, 4, 0, 3,
        0, 4, 3,

        0, -3, 4,
        -1, -2, 4, 1, -2, 4,
        -2, -1, 4, 0, -1, 4, 2, -1, 4,
        -3, 0, 4, -1, 0, 4, 1, 0, 4, 3, 0, 4,
        -2, 1, 4, 0, 1, 4, 2, 1, 4,
        -1, 2, 4, 1, 2, 4,
        0, 3, 4,

        0, -2, 5,
        -2, 0, 5, 2, 0, 5,
        0, 2, 5,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"A (p4)"},
#endif
	{
        -1, -1, -1,
        0, 0, -1,

        1, -2, 0,
        0, -1, 0,
        -1, 0, 0,

        -2, 0, 1,
        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"clock (p4)"},
#endif
	{
        0, 0, -1,

        -1, -2, 0,
        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,
        -1, 2, 0, 1, 2, 0,

        1, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"E (p4)"},
#endif
	{
        -1, -1, -1,
        0, 0, -1,
        1, 1, -1,

        1, -2, 0,
        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -2, 1, 0, 0, 1, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"B (p4)"},
#endif
	{
        -1, -1, -1,
        0, 0, -1,
        1, 1, -1,

        1, -2, 0,
        0, -1, 0, 2, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -2, 1, 0, 0, 1, 0,
        -1, 2, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"H (p4)"},
#endif
	{
        0, -2, -1,
        -3, -1, -1, -1, -1, -1,
        2, 0, -1,
        1, 1, -1,
        1, 3, -1,

        -1, -2, 0,
        -2, -1, 0, 0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0, 2, 1, 0,
        1, 2, 0,

        -2, -2, 1,
        -1, -1, 1,
        1, 1, 1,
        2, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"M or I (p4)"},
#endif
	{
        -2, -1, -2, 0, -1, -2,
        -1, 0, -2,
        0, 1, -2,

        -2, -2, -1, 0, -2, -1,
        1, -1, -1,
        -2, 0, -1,
        -1, 1, -1, 1, 1, -1,

        -1, -2, 0,
        -2, -1, 0,
        1, 0, 0,
        0, 1, 0,

        0, -2, 1,
        -1, -1, 1, 1, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"poppy (p4)"},
#endif
	{
        0, -1, -2,
        -1, 0, -2, 1, 0, -2,
        0, 1, -2,

        -2, -2, -1, 2, -2, -1,
        -1, -1, -1, 1, -1, -1,
        -1, 1, -1, 1, 1, -1,
        -2, 2, -1, 2, 2, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        0, -2, 1,
        -2, 0, 1, 2, 0, 1,
        0, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"swimming square (p4)"},
#endif
	{
        0, -2, -1,
        -2, 0, -1, 2, 0, -1,
        0, 2, -1,

        1, -4, 0,
        0, -3, 0,
        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 0, -1, 0, 2, -1, 0, 4, -1, 0,
        -3, 0, 0, -1, 0, 0, 1, 0, 0, 3, 0, 0,
        -4, 1, 0, -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,
        0, 3, 0,
        -1, 4, 0,

        -1, -3, 1,
        0, -2, 1,
        -3, -1, 1,
        -2, 0, 1, 2, 0, 1,
        3, 1, 1,
        0, 2, 1,
        1, 3, 1,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"cross variant 1 (p4)"},
#endif
	{
        0, -1, -2,
        -1, 0, -2, 1, 0, -2,
        0, 1, -2,

        -1, -1, -1, 1, -1, -1,
        -1, 1, -1, 1, 1, -1,

        -2, -3, 0, 2, -3, 0,
        -3, -2, 0, -1, -2, 0, 1, -2, 0, 3, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -3, 2, 0, -1, 2, 0, 1, 2, 0, 3, 2, 0,
        -2, 3, 0, 2, 3, 0,

        -3, -3, 1, -1, -3, 1, 1, -3, 1, 3, -3, 1,
        -3, -1, 1, 3, -1, 1,
        -3, 1, 1, 3, 1, 1,
        -3, 3, 1, -1, 3, 1, 1, 3, 1, 3, 3, 1,

        -2, -3, 2, 2, -3, 2,
        -3, -2, 2, -1, -2, 2, 1, -2, 2, 3, -2, 2,
        -2, -1, 2, 0, -1, 2, 2, -1, 2,
        -1, 0, 2, 1, 0, 2,
        -2, 1, 2, 0, 1, 2, 2, 1, 2,
        -3, 2, 2, -1, 2, 2, 1, 2, 2, 3, 2, 2,
        -2, 3, 2, 2, 3, 2,

        0, -4, 3,
        0, -2, 3,
        -4, 0, 3, -2, 0, 3, 2, 0, 3, 4, 0, 3,
        0, 2, 3,
        0, 4, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"cross variant 2 (p4)"},
#endif
	{
        0, -4, -1,
        0, -2, -1,
        -4, 0, -1, -2, 0, -1, 2, 0, -1, 4, 0, -1,
        0, 2, -1,
        0, 4, -1,

        -2, -3, 0, 2, -3, 0,
        -3, -2, 0, -1, -2, 0, 1, -2, 0, 3, -2, 0,
        -2, -1, 0, 0, -1, 0, 2, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -3, 2, 0, -1, 2, 0, 1, 2, 0, 3, 2, 0,
        -2, 3, 0, 2, 3, 0,

        -3, -3, 1, -1, -3, 1, 1, -3, 1, 3, -3, 1,
        -3, -1, 1, 3, -1, 1,
        -3, 1, 1, 3, 1, 1,
        -3, 3, 1, -1, 3, 1, 1, 3, 1, 3, 3, 1,

        -1, -4, 2, 1, -4, 2,
        -2, -3, 2, 2, -3, 2,
        -3, -2, 2, -1, -2, 2, 1, -2, 2, 3, -2, 2,
        -4, -1, 2, -2, -1, 2, 0, -1, 2, 2, -1, 2, 4, -1, 2,
        -1, 0, 2, 1, 0, 2,
        -4, 1, 2, -2, 1, 2, 0, 1, 2, 2, 1, 2, 4, 1, 2,
        -3, 2, 2, -1, 2, 2, 1, 2, 2, 3, 2, 2,
        -2, 3, 2, 2, 3, 2,
        -1, 4, 2, 1, 4, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"cross variant 3 (p4)"},
#endif
	{
        0, -4, -1,
        0, -2, -1,
        -4, 0, -1, -2, 0, -1, 2, 0, -1, 4, 0, -1,
        0, 2, -1,
        0, 4, -1,

        -2, -3, 0, 2, -3, 0,
        -3, -2, 0, -1, -2, 0, 1, -2, 0, 3, -2, 0,
        -2, -1, 0, 0, -1, 0, 2, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -3, 2, 0, -1, 2, 0, 1, 2, 0, 3, 2, 0,
        -2, 3, 0, 2, 3, 0,

        -3, -3, 1, -1, -3, 1, 1, -3, 1, 3, -3, 1,
        -3, -1, 1, 3, -1, 1,
        -3, 1, 1, 3, 1, 1,
        -3, 3, 1, -1, 3, 1, 1, 3, 1, 3, 3, 1,

        -2, -3, 2, 2, -3, 2,
        -3, -2, 2, -1, -2, 2, 1, -2, 2, 3, -2, 2,
        -2, -1, 2, 0, -1, 2, 2, -1, 2,
        -1, 0, 2, 1, 0, 2,
        -2, 1, 2, 0, 1, 2, 2, 1, 2,
        -3, 2, 2, -1, 2, 2, 1, 2, 2, 3, 2, 2,
        -2, 3, 2, 2, 3, 2,

        0, -4, 3,
        0, -2, 3,
        -4, 0, 3, -2, 0, 3, 2, 0, 3, 4, 0, 3,
        0, 2, 3,
        0, 4, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"cross variant 4 (p4)"},
#endif
	{
        0, -4, -3,
        0, -2, -3,
        -4, 0, -3, -2, 0, -3, 2, 0, -3, 4, 0, -3,
        0, 2, -3,
        0, 4, -3,

        -2, -3, -2, 2, -3, -2,
        -3, -2, -2, -1, -2, -2, 1, -2, -2, 3, -2, -2,
        -2, -1, -2, 0, -1, -2, 2, -1, -2,
        -1, 0, -2, 1, 0, -2,
        -2, 1, -2, 0, 1, -2, 2, 1, -2,
        -3, 2, -2, -1, 2, -2, 1, 2, -2, 3, 2, -2,
        -2, 3, -2, 2, 3, -2,

        -3, -3, -1, -1, -3, -1, 1, -3, -1, 3, -3, -1,
        -3, -1, -1, 3, -1, -1,
        -3, 1, -1, 3, 1, -1,
        -3, 3, -1, -1, 3, -1, 1, 3, -1, 3, 3, -1,

        -2, -3, 0, 2, -3, 0,
        -3, -2, 0, -1, -2, 0, 1, -2, 0, 3, -2, 0,
        -2, -1, 0, 0, -1, 0, 2, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -3, 2, 0, -1, 2, 0, 1, 2, 0, 3, 2, 0,
        -2, 3, 0, 2, 3, 0,

        -1, -3, 1, 1, -3, 1,
        0, -2, 1,
        -3, -1, 1, 3, -1, 1,
        -2, 0, 1, 2, 0, 1,
        -3, 1, 1, 3, 1, 1,
        0, 2, 1,
        -1, 3, 1, 1, 3, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"cross variant 5 (p4)"},
#endif
	{
        0, -4, -3,
        0, -2, -3,
        -4, 0, -3, -2, 0, -3, 2, 0, -3, 4, 0, -3,
        0, 2, -3,
        0, 4, -3,

        -2, -3, -2, 2, -3, -2,
        -3, -2, -2, -1, -2, -2, 1, -2, -2, 3, -2, -2,
        -2, -1, -2, 0, -1, -2, 2, -1, -2,
        -1, 0, -2, 1, 0, -2,
        -2, 1, -2, 0, 1, -2, 2, 1, -2,
        -3, 2, -2, -1, 2, -2, 1, 2, -2, 3, 2, -2,
        -2, 3, -2, 2, 3, -2,

        -3, -3, -1, -1, -3, -1, 1, -3, -1, 3, -3, -1,
        -3, -1, -1, 3, -1, -1,
        -3, 1, -1, 3, 1, -1,
        -3, 3, -1, -1, 3, -1, 1, 3, -1, 3, 3, -1,

        -2, -3, 0, 2, -3, 0,
        -3, -2, 0, -1, -2, 0, 1, -2, 0, 3, -2, 0,
        -2, -1, 0, 0, -1, 0, 2, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -3, 2, 0, -1, 2, 0, 1, 2, 0, 3, 2, 0,
        -2, 3, 0, 2, 3, 0,

        -1, -3, 1, 1, -3, 1,
        -3, -1, 1, -1, -1, 1, 1, -1, 1, 3, -1, 1,
        -3, 1, 1, -1, 1, 1, 1, 1, 1, 3, 1, 1,
        -1, 3, 1, 1, 3, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"egg (p4)"},
#endif
	{
        -1, -2, -4,
        -2, -1, -4,

        -3, -3, -3,
        0, -2, -3,
        1, -1, -3,
        -2, 0, -3,
        -1, 1, -3,

        -1, -4, -2,
        0, -3, -2,
        -4, -1, -2, 0, -1, -2, 2, -1, -2,
        -3, 0, -2, -1, 0, -2, 1, 0, -2,
        0, 1, -2, 2, 1, -2,
        -1, 2, -2, 1, 2, -2,

        -2, -4, -1,
        1, -3, -1,
        -4, -2, -1, 0, -2, -1, 2, -2, -1,
        -2, 0, -1, 2, 0, -1,
        -3, 1, -1, 3, 1, -1,
        -2, 2, -1, 0, 2, -1,
        1, 3, -1,

        -2, -3, 0,
        -3, -2, 0, -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0, 3, 2, 0,
        2, 3, 0,

        -1, -3, 1,
        0, -2, 1, 2, -2, 1,
        -3, -1, 1, 3, -1, 1,
        -2, 0, 1, 2, 0, 1,
        -2, 2, 1, 0, 2, 1, 4, 2, 1,
        -1, 3, 1,
        2, 4, 1,

        -1, -2, 2, 1, -2, 2,
        -2, -1, 2, 0, -1, 2,
        -1, 0, 2, 1, 0, 2, 3, 0, 2,
        -2, 1, 2, 0, 1, 2, 4, 1, 2,
        0, 3, 2,
        1, 4, 2,

        1, -1, 3,
        2, 0, 3,
        -1, 1, 3,
        0, 2, 3,
        3, 3, 3,

        2, 1, 4,
        1, 2, 4,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"crystal (p5)"},
#endif
	{
        -1, -3, -3, 1, -3, -3,
        -2, -2, -3, 2, -2, -3,
        -2, 0, -3, 2, 0, -3,
        -1, 1, -3, 1, 1, -3,

        -1, -4, -2, 1, -4, -2,
        -2, -3, -2, 0, -3, -2, 2, -3, -2,
        -3, -2, -2, -1, -2, -2, 1, -2, -2, 3, -2, -2,
        -2, -1, -2, 2, -1, -2,
        -3, 0, -2, -1, 0, -2, 1, 0, -2, 3, 0, -2,
        -2, 1, -2, 0, 1, -2, 2, 1, -2,
        -1, 2, -2, 1, 2, -2,

        -1, -4, 0, 1, -4, 0,
        -2, -3, 0, 0, -3, 0, 2, -3, 0,
        -3, -2, 0, -1, -2, 0, 1, -2, 0, 3, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -3, 0, 0, -1, 0, 0, 1, 0, 0, 3, 0, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,

        -1, -3, 1, 1, -3, 1,
        -2, -2, 1, 2, -2, 1,
        -2, 0, 1, 2, 0, 1,
        -1, 1, 1, 1, 1, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"large crystal (p5)"},
#endif
	{
        0, -2, -3,
        -2, 0, -3, 2, 0, -3,
        0, 2, -3,

        0, -3, -2,
        -1, -2, -2, 1, -2, -2,
        -2, -1, -2, 0, -1, -2, 2, -1, -2,
        -3, 0, -2, 3, 0, -2,
        -2, 1, -2, 0, 1, -2, 2, 1, -2,
        -1, 2, -2, 1, 2, -2,
        0, 3, -2,

        -2, -2, -1, 2, -2, -1,
        -2, 0, -1, 0, 0, -1, 2, 0, -1,
        -2, 2, -1, 2, 2, -1,

        -2, -3, 0, 2, -3, 0,
        -3, -2, 0, -1, -2, 0, 1, -2, 0, 3, -2, 0,
        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,
        -3, 2, 0, -1, 2, 0, 1, 2, 0, 3, 2, 0,
        -2, 3, 0, 2, 3, 0,

        -2, -2, 1, 2, -2, 1,
        -2, 0, 1, 0, 0, 1, 2, 0, 1,
        -2, 2, 1, 2, 2, 1,

        0, -3, 2,
        -1, -2, 2, 1, -2, 2,
        -2, -1, 2, 0, -1, 2, 2, -1, 2,
        -3, 0, 2, 3, 0, 2,
        -2, 1, 2, 0, 1, 2, 2, 1, 2,
        -1, 2, 2, 1, 2, 2,
        0, 3, 2,

        0, -2, 3,
        -2, 0, 3, 2, 0, 3,
        0, 2, 3,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"C (p6)"},
#endif
	{
        0, -1, -2,
        0, 1, -2,

        0, 0, -1,

        -2, -1, 0, 0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -2, 1, 0, 0, 1, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"K (p6)"},
#endif
	{
        1, -1, -3,
        0, 0, -3,
        0, 2, -3,

        1, 0, -2, 3, 0, -2,
        0, 1, -2,

        1, -1, -1,
        2, 0, -1,
        -3, 1, -1, -1, 1, -1, 1, 1, -1,
        0, 2, -1,
        1, 3, -1,

        0, -3, 0, 2, -3, 0,
        1, -2, 0,
        2, -1, 0,
        -3, 0, 0, 3, 0, 0,
        -2, 1, 0,
        -1, 2, 0,
        -2, 3, 0, 0, 3, 0,

        -1, -3, 1,
        0, -2, 1,
        -1, -1, 1, 1, -1, 1, 3, -1, 1,
        -2, 0, 1,
        -1, 1, 1,

        0, -1, 2,
        -3, 0, 2, -1, 0, 2,

        0, -2, 3,
        0, 0, 3,
        -1, 1, 3,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"L (p6)"},
#endif
	{
        -1, -3, -3,
        -3, -1, -3,
        2, 0, -3,
        0, 2, -3,

        -1, -2, -2,
        -2, -1, -2, 0, -1, -2, 2, -1, -2,
        -1, 0, -2, 1, 0, -2, 3, 0, -2,
        0, 1, -2, 2, 1, -2,
        -1, 2, -2, 1, 2, -2,
        0, 3, -2,

        -3, -3, -1,
        -2, -2, -1, 0, -2, -1, 2, -2, -1,
        -2, 0, -1, 2, 0, -1,
        -2, 2, -1, 0, 2, -1,

        2, -3, 0,
        -1, -2, 0, 1, -2, 0, 3, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -3, 2, 0, -1, 2, 0, 1, 2, 0,
        -2, 3, 0,

        0, -2, 1, 2, -2, 1,
        -2, 0, 1, 2, 0, 1,
        -2, 2, 1, 0, 2, 1, 2, 2, 1,
        3, 3, 1,

        0, -3, 2,
        -1, -2, 2, 1, -2, 2,
        -2, -1, 2, 0, -1, 2,
        -3, 0, 2, -1, 0, 2, 1, 0, 2,
        -2, 1, 2, 0, 1, 2, 2, 1, 2,
        1, 2, 2,

        0, -2, 3,
        -2, 0, 3,
        3, 1, 3,
        1, 3, 3,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"corner (p6)"},
#endif
	{
        0, -2, -3, 2, -2, -3,
        1, -1, -3,
        -2, 0, -3,
        -1, 1, -3,
        -2, 2, -3,

        -2, -3, 2, 0, -3, -2, 2, -3, -2,
        0, -1, -2, 2, -1, -2,
        -3, 0, -2, -1, 0, -2, 1, 0, -2,
        0, 1, -2,
        -3, 2, -2, -1, 2, -2,

        1, -3, -1,
        0, -2, -1, 2, -2, -1,
        -2, 0, -1,
        -3, 1, -1,
        -2, 2, -1,

        -2, -3, 0,
        -3, -2, 0, -1, -2, 0,
        1, -2, 0,
        -2, -1, 0,
        -2, 1, 0,

        -1, -3, 1,
        0, -2, 1,
        -3, -1, 1,
        -2, 0, 1,

        -3, -2, 2, -1, -2, 2,
        -2, -1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"ripple (p6)"},
#endif
	{
        0, -2, -1,
        -2, 0, -1, 2, 0, -1,
        0, 2, -1,

        0, -3, 0,
        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 0, -1, 0, 2, -1, 0,
        -3, 0, 0, -1, 0, 0, 1, 0, 0, 3, 0, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,
        0, 3, 0,

        0, -2, 1,
        -2, 0, 1, 2, 0, 1,
        0, 2, 1,

        -1, -2, 2, 1, -2, 2,
        -2, -1, 2, 2, -1, 2,
        -2, 1, 2, 2, 1, 2,
        -1, 2, 2, 1, 2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"pound (p6)"},
#endif
	{
        -1, -3, -1,
        0, -2, -1,
        -3, -1, -1, 1, -1, -1,
        -2, 0, -1, 2, 0, -1,
        -1, 1, -1,
        0, 2, -1,

        -1, -4, 0,
        0, -3, 0,
        -1, -2, 0,
        -4, -1, 0, -2, -1, 0, 2, -1, 0,
        -3, 0, 0, 1, 0, 0, 3, 0, 0,
        0, 1, 0,
        -1, 2, 0,
        0, 3, 0,
        127
	},
#ifdef LIFE_NAMES
	{"flying carpet (p6)"},
#endif
	{
        -2, -2, -1,
        2, 2, -1,

        -1, -4, 0,
        -2, -3, 0, 0, -3, 0,
        -3, -2, 0, -1, -2, 0, 1, -2, 0,
        -4, -1, 0, -2, -1, 0, 0, -1, 0, 2, -1, 0,
        -3, 0, 0, -1, 0, 0, 1, 0, 0, 3, 0, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0, 4, 1, 0,
        -1, 2, 0, 1, 2, 0, 3, 2, 0,
        0, 3, 0, 2, 3, 0,
        1, 4, 0,

        -1, -3, 1,
        -3, -1, 1, 1, -1, 1,
        -1, 1, 1, 3, 1, 1,
        1, 3, 1,

        1, -2, 2,
        2, -1, 2,
        -2, 1, 2,
        -1, 2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"cradle (p6)"},
#endif
	{
        2, -3, -2,
        -1, -2, -2, 1, -2, -2, 3, -2, -2,
        -2, -1, -2, 0, -1, -2, 2, -1, -2,
        -1, 0, -2, 1, 0, -2,
        -2, 1, -2, 0, 1, -2, 2, 1, -2,
        -3, 2, -2, -1, 2, -2, 1, 2, -2,
        -2, 3, -2,

        1, -3, -1,
        0, -2, -1,
        3, -1, -1,
        -2, 0, -1, 2, 0, -1,
        -3, 1, -1,
        0, 2, -1,
        -1, 3, -1,

        2, -3, 0,
        1, -2, 0, 3, -2, 0,
        2, -1, 0,
        -2, 1, 0,
        -3, 2, 0, -1, 2, 0,
        -2, 3, 0,
        127
	},
#ifdef LIFE_NAMES
	{"pyramid (p6)"},
#endif
	{
        -3, 1, -3,
        -1, 3, -3,

        -2, 1, -2,
        -3, 2, -2, -1, 2, -2,
        -2, 3, -2,

        -2, 0, -1, 0, 0, -1,
        -3, 1, -1,
        0, 2, -1,
        -1, 3, -1,

        -2, -1, 0, 0, -1, 0,
        1, 0, 0,
        -2, 1, 0,
        -1, 2, 0, 1, 2, 0,

        -3, -3, 1,
        -2, -2, 1,
        -3, -1, 1,
        -2, 0, 1,
        0, 2, 1, 2, 2, 1,
        1, 3, 1, 3, 3, 1,

        -3, -2, 2, -1, -2, 2,
        0, -1, 2,
        -1, 0, 2, 1, 0, 2,
        0, 1, 2, 2, 1, 2,
        2, 3, 2,

        -1, -3, 3,
        -2, -2, 3,
        -1, -1, 3,
        1, 1, 3, 3, 1, 3,
        2, 2, 3,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"inverting corner (p6)"},
#endif
	{
        2, -3, -4,
        -2, -1, -4,
        2, 1, -4,
        -2, 3, -4,

        1, -3, -3, 3, -3, -3,
        -2, -2, -3, 4, -2, -3,
        -1, -1, -3, 3, -1, -3,
        -3, 1, -3, 1, 1, -3,
        -4, 2, -3, 2, 2, -3,
        -3, 3, -3, -1, 3, -3,

        -1, -4, -2, 3, -4, -2,
        -2, -3, -2,
        -3, -2, -2, -1, -2, -2,
        -2, -1, -2,
        2, 1, -2,
        1, 2, -2, 3, 2, -2,
        2, 3, -2,
        -3, 4, -2, 1, 4, -2,

        -1, -3, -1, 3, -3, -1,
        -4, -2, -1, -2, -2, -1,
        -3, -1, -1, 1, -1, -1,
        -1, 1, -1, 3, 1, -1,
        2, 2, -1, 4, 2, -1,
        -3, 3, -1, 1, 3, -1,

        -3, -3, 1, 1, -3, 1,
        2, -2, 1, 4, -2, 1,
        -1, -1, 1, 3, -1, 1,
        -3, 1, 1, 1, 1, 1,
        -4, 2, 1, -2, 2, 1,
        -1, 3, 1, 3, 3, 1,

        -3, -4, 2, 1, -4, 2,
        2, -3, 2,
        1, -2, 2, 3, -2, 2,
        2, -1, 2,
        -2, 1, 2,
        -3, 2, 2, -1, 2, 2,
        -2, 3, 2,
        -1, 4, 2, 3, 4, 2,

        -3, -3, 3, -1, -3, 3,
        -4, -2, 3, 2, -2, 3,
        -3, -1, 3, 1, -1, 3,
        -1, 1, 3, 3, 1, 3,
        -2, 2, 3, 4, 2, 3,
        1, 3, 3, 3, 3, 3,

        -2, -3, 4,
        2, -1, 4,
        -2, 1, 4,
        2, 3, 4,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"another (p6)"},
#endif
	{
        -3, -2, -4, -1, -2, -4, 1, -2, -4, 3, -2, -4,
        -3, 2, -4, -1, 2, -4, 1, 2, -4, 3, 2, -4,

        -2, -4, -3, 2, -4, -3,
        -1, -1, -3, 1, -1, -3,
        -1, 1, -3, 1, 1, -3,
        -2, 4, -3, 2, 4, -3,

        -4, -3, -2, 4, -3, -2,
        -4, -1, -2, 0, -1, -2, 4, -1, -2,
        -4, 1, -2, 0, 1, -2, 4, 1, -2,
        -4, 3, -2, 4, 3, -2,

        -2, -4, -1, 2, -4, -1,
        -1, -3, -1, 1, -3, -1,
        -3, -1, -1, -1, -1, -1, 1, -1, -1, 3, -1, -1,
        -2, 0, -1, 2, 0, -1,
        -3, 1, -1, -1, 1, -1, 1, 1, -1, 3, 1, -1,
        -1, 3, -1, 1, 3, -1,
        -2, 4, -1, 2, 4, -1,

        -1, -2, 0, 1, -2, 0,
        -1, 2, 0, 1, 2, 0,

        -2, -4, 1, 2, -4, 1,
        -1, -3, 1, 1, -3, 1,
        -3, -1, 1, -1, -1, 1, 1, -1, 1, 3, -1, 1,
        -2, 0, 1, 2, 0, 1,
        -3, 1, 1, -1, 1, 1, 1, 1, 1, 3, 1, 1,
        -1, 3, 1, 1, 3, 1,
        -2, 4, 1, 2, 4, 1,

        -4, -3, 2, 4, -3, 2,
        -4, -1, 2, 0, -1, 2, 4, -1, 2,
        -4, 1, 2, 0, 1, 2, 4, 1, 2,
        -4, 3, 2, 4, 3, 2,

        -2, -4, 3, 2, -4, 3,
        -1, -1, 3, 1, -1, 3,
        -1, 1, 3, 1, 1, 3,
        -2, 4, 3, 2, 4, 3,

        -3, -2, 4, -1, -2, 4, 1, -2, 4, 3, -2, 4,
        -3, 2, 4, -1, 2, 4, 1, 2, 4, 3, 2, 4,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"G (p8)"},
#endif
	{
        -1, -2, -2,
        2, 1, -2,

        -1, -1, -1,
        1, 1, -1,

        -1, -2, 0,
        -2, -1, 0, 0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0, 2, 1, 0,
        1, 2, 0,

        -1, -1, 1,
        1, 1, 1,

        -1, -2, 2,
        -1, 0, 2,
        0, 1, 2, 2, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"population (p8)"},
#endif
	{
        -1, -2, -2,
        -2, -1, -2, 0, -1, -2, 2, -1, -2,
        -1, 0, -2, 1, 0, -2,
        0, 1, -2,
        1, 2, -2,

        -2, -2, -1, 0, -2, -1,
        -2, 0, -1, 2, 0, -1,
        -2, 2, -1, 0, 2, -1,

        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,

        0, -2, 1, 2, -2, 1,
        -2, 0, 1, 2, 0, 1,
        0, 2, 1, 2, 2, 1,

        -1, -2, 2,
        0, -1, 2,
        -1, 0, 2, 1, 0, 2,
        -2, 1, 2, 0, 1, 2, 2, 1, 2,
        1, 2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"J (p10)"},
#endif
	{
        1, -1, -3,
        2, 0, -3,
        -1, 1, -3,
        0, 2, -3,

        2, -1, -2,
        3, 0, -2,
        2, 1, -2,
        -1, 2, -2, 1, 2, -2,
        0, 3, -2,

        1, -3, -1,
        2, -2, -1,
        -3, 1, -1, 3, 1, -1,
        -2, 2, -1,
        1, 3, -1,

        2, -3, 0,
        3, -2, 0,
        -3, 2, 0,
        -2, 3, 0,

        -1, -3, 1,
        2, -2, 1,
        -3, -1, 1, 3, -1, 1,
        -2, 2, 1,
        -1, 3, 1,

        0, -3, 2,
        -1, -2, 2, 1, -2, 2,
        -2, -1, 2,
        -3, 0, 2,
        -2, 1, 2,

        0, -2, 3,
        1, -1, 3,
        -2, 0, 3,
        -1, 1, 3,
        127
	},
#ifdef LIFE_NAMES
	{"Ottoman (p10)"},
#endif
	{
        1, -4, -2,
        -2, -3, -2, 0, -3, -2, 2, -3, -2,
        -3, -2, -2,
        -2, -1, -2, 2, -1, -2,
        3, 0, -2,
        -2, 1, -2, 0, 1, -2, 2, 1, -2,
        -1, 2, -2,

         -1, -3, -1, 1, -3, -1,
         -2, -2, -1, 0, -2, -1, 2, -2, -1,
         -1, -1, -1, 1, -1, -1,
         -2, 0, -1, 0, 0, -1, 2, 0, -1,
         -1, 1, -1, 1, 1, -1,

        0, -3, 0,
        -2, -1, 0, 2, -1, 0,
        0, 1, 0,

        0, -2, 1,
         -1, -1, 1, 1, -1, 1,
         0, 0, 1,

        0, -3, 2,
        -2, -1, 2, 2, -1, 2,
        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"D (p12)"},
#endif
	{
        0, -2, -1,

        1, -2, 0,
        0, -1, 0,
        -1, 0, 0,
        0, 1, 0,

        1, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"P (p30)"},
#endif
	{
        1, -2, 0,
        0, -1, 0,
        -1, 0, 0,
        0, 1, 0,
        -1, 2, 0,

        1, -3, 1,
        0, -2, 1,
        1, -1, 1,
        0, 0, 1,
        -1, 1, 1,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"ball (stable)"},
#endif
	{
        0, -1, -2,
        -1, 0, -2, 1, 0, -2,
        0, 1, -2,

        -1, -1, -1, 1, -1, -1,
        -1, 1, -1, 1, 1, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"2 balls (stable)"},
#endif
	{
        -1, -2, -2,
        -2, -1, -2, 0, -1, -2,
        -1, 0, -2, 1, 0, -2,
        0, 1, -2, 2, 1, -2,
        1, 2, -2,

        -2, -2, -1, 0, -2, -1,
        -2, 0, -1, 2, 0, -1,
        0, 2, -1, 2, 2, -1,

        -1, -2, 0,
        -2, -1, 0, 0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0, 2, 1, 0,
        1, 2, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"4 balls (stable)"},
#endif
	{
        0, -3, -2,
        -1, -2, -2, 1, -2, -2,
        -2, -1, -2, 0, -1, -2, 2, -1, -2,
        -3, 0, -2, -1, 0, -2, 1, 0, -2, 3, 0, -2,
        -2, 1, -2, 0, 1, -2, 2, 1, -2,
        -1, 2, -2, 1, 2, -2,
        0, 3, -2,

        -1, -3, -1, 1, -3, -1,
        -3, -1, -1, 3, -1, -1,
        -3, 1, -1, 3, 1, -1,
        -1, 3, -1, 1, 3, -1,

        0, -3, 0,
        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 0, -1, 0, 2, -1, 0,
        -3, 0, 0, -1, 0, 0, 1, 0, 0, 3, 0, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,
        0, 3, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"tetrahedron (stable)"},
#endif
	{
        -1, -2, -2,
        -2, -1, -2, 0, -1, -2,
        -1, 0, -2, 1, 0, -2,
        0, 1, -2, 2, 1, -2,
        1, 2, -2,

        -2, -2, -1, 0, -2, -1,
        -2, 0, -1, 2, 0, -1,
        0, 2, -1, 2, 2, -1,

        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,

        0, -2, 1, 2, -2, 1,
        -2, 0, 1, 2, 0, 1,
        -2, 2, 1, 0, 2, 1,

        1, -2, 2,
        0, -1, 2, 2, -1, 2,
        -1, 0, 2, 1, 0, 2,
        -2, 1, 2, 0, 1, 2,
        -1, 2, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"tetrahedron variant (stable)"},
#endif
	{
        -1, -2, -2,
        -2, -1, -2, 0, -1, -2,
        -1, 0, -2, 1, 0, -2,
        0, 1, -2, 2, 1, -2,
        1, 2, -2,

        -2, -2, -1, 0, -2, -1,
        -2, 0, -1, 2, 0, -1,
        0, 2, -1, 2, 2, -1,

        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -1, 0, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,

        0, -2, 1, 2, -2, 1,
        -2, 0, 1, 0, 0, 1, 2, 0, 1,
        0, 2, 1,

        1, -2, 2,
        0, -1, 2, 2, -1, 2,
        -1, 0, 2, 1, 0, 2,
        0, 1, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"snub cube 120 (stable)"},
#endif
	{
        0, -3, -4,
        -1, -2, -4, 1, -2, -4,
        -2, -1, -4, 0, -1, -4, 2, -1, -4,
        -3, 0, -4, -1, 0, -4, 1, 0, -4, 3, 0, -4,
        -2, 1, -4, 0, 1, -4, 2, 1, -4,
        -1, 2, -4, 1, 2, -4,
        0, 3, -4,

        0, -4, -3,
        0, -2, -3,
        -4, 0, -3, -2, 0, -3, 2, 0, -3, 4, 0, -3,
        0, 2, -3,
        0, 4, -3,

        -1, -4, -2, 1, -4, -2,
        0, -3, -2,
        -4, -1, -2, 4, -1, -2,
        -3, 0, -2, 3, 0, -2,
        -4, 1, -2, 4, 1, -2,
        0, 3, -2,
        -1, 4, -2, 1, 4, -2,

        -2, -4, -1, 0, -4, -1, 2, -4, -1,
        -4, -2, -1, 4, -2, -1,
        -4, 0, -1, 4, 0, -1,
        -4, 2, -1, 4, 2, -1,
        -2, 4, -1, 0, 4, -1, 2, 4, -1,

        -3, -4, 0, -1, -4, 0, 1, -4, 0, 3, -4, 0,
        -4, -3, 0, -2, -3, 0, 2, -3, 0, 4, -3, 0,
        -3, -2, 0, 3, -2, 0,
        -4, -1, 0, 4, -1, 0,
        -4, 1, 0, 4, 1, 0,
        -3, 2, 0, 3, 2, 0,
        -4, 3, 0, -2, 3, 0, 2, 3, 0, 4, 3, 0,
        -3, 4, 0, -1, 4, 0, 1, 4, 0, 3, 4, 0,

        -2, -4, 1, 0, -4, 1, 2, -4, 1,
        -4, -2, 1, 4, -2, 1,
        -4, 0, 1, 4, 0, 1,
        -4, 2, 1, 4, 2, 1,
        -2, 4, 1, 0, 4, 1, 2, 4, 1,

        -1, -4, 2, 1, -4, 2,
        0, -3, 2,
        -4, -1, 2, 4, -1, 2,
        -3, 0, 2, 3, 0, 2,
        -4, 1, 2, 4, 1, 2,
        0, 3, 2,
        -1, 4, 2, 1, 4, 2,

        0, -4, 3,
        0, -2, 3,
        -4, 0, 3, -2, 0, 3, 2, 0, 3, 4, 0, 3,
        0, 2, 3,
        0, 4, 3,

        0, -3, 4,
        -1, -2, 4, 1, -2, 4,
        -2, -1, 4, 0, -1, 4, 2, -1, 4,
        -3, 0, 4, -1, 0, 4, 1, 0, 4, 3, 0, 4,
        -2, 1, 4, 0, 1, 4, 2, 1, 4,
        -1, 2, 4, 1, 2, 4,
        0, 3, 4,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"tetra 132 (stable)"},
#endif
	{
        -2, -3, -4,
        -3, -2, -4, -1, -2, -4,
        -2, -1, -4, 0, -1, -4,
        -1, 0, -4, 1, 0, -4,
        0, 1, -4, 2, 1, -4,
        1, 2, -4, 3, 2, -4,
        2, 3, -4,

        -2, -4, -3,
        -4, -2, -3, -2, -2, -3, 0, -2, -3,
        -2, 0, -3, 2, 0, -3,
        0, 2, -3, 2, 2, -3, 4, 2, -3,
        2, 4, -3,

        -3, -4, -2, -1, -4, -2,
        -4, -3, -2, -2, -3, -2, 0, -3, -2,
        -3, -2, -2,
        -4, -1, -2, 0, -1, -2,
        -3, 0, -2, -1, 0, -2, 1, 0, -2, 3, 0, -2,
        0, 1, -2, 4, 1, -2,
        3, 2, -2,
        0, 3, -2, 2, 3, -2, 4, 3, -2,
        1, 4, -2, 3, 4, -2,

        -2, -4, -1, 0, -4, -1,
        -4, -2, -1, 0, -2, -1,
        -4, 0, -1, -2, 0, -1, 2, 0, -1, 4, 0, -1,
        0, 2, -1, 4, 2, -1,
        0, 4, -1, 2, 4, -1,

        -1, -4, 0, 1, -4, 0,
        -2, -3, 0, 2, -3, 0,
        -3, -2, 0, -1, -2, 0, 1, -2, 0, 3, -2, 0,
        -4, -1, 0, -2, -1, 0, 2, -1, 0, 4, -1, 0,
        -4, 1, 0, -2, 1, 0, 2, 1, 0, 4, 1, 0,
        -3, 2, 0, -1, 2, 0, 1, 2, 0, 3, 2, 0,
        -2, 3, 0, 2, 3, 0,
        -1, 4, 0, 1, 4, 0,

        0, -4, 1, 2, -4, 1,
        0, -2, 1, 4, -2, 1,
        -4, 0, 1, -2, 0, 1, 2, 0, 1, 4, 0, 1,
        -4, 2, 1, 0, 2, 1,
        -2, 4, 1, 0, 4, 1,

        1, -4, 2, 3, -4, 2,
        0, -3, 2, 2, -3, 2, 4, -3, 2,
        3, -2, 2,
        0, -1, 2, 4, -1, 2,
        -3, 0, 2, -1, 0, 2, 1, 0, 2, 3, 0, 2,
        -4, 1, 2, 0, 1, 2,
        -3, 2, 2,
        -4, 3, 2, -2, 3, 2, 0, 3, 2,
        -3, 4, 2, -1, 4, 2,

        2, -4, 3,
        0, -2, 3, 2, -2, 3, 4, -2, 3,
        -2, 0, 3, 2, 0, 3,
        -4, 2, 3, -2, 2, 3, 0, 2, 3,
        -2, 4, 3,

        2, -3, 4,
        1, -2, 4, 3, -2, 4,
        0, -1, 4, 2, -1, 4,
        -1, 0, 4, 1, 0, 4,
        -2, 1, 4, 0, 1, 4,
        -3, 2, 4, -1, 2, 4,
        -2, 3, 4,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"O smaller variant (stable)"},
#endif
	{
        0, -2, -5,
        -2, 0, -5, 2, 0, -5,
        0, 2, -5,

        -3, -4, -4, 3, -4, -4,
        -4, -3, -4, -2, -3, -4, 0, -3, -4, 2, -3, -4, 4, -3, -4,
        -3, -2, -4, -1, -2, -4, 1, -2, -4, 3, -2, -4,
        -2, -1, -4, 0, -1, -4, 2, -1, -4,
        -3, 0, -4, -1, 0, -4, 1, 0, -4, 3, 0, -4,
        -2, 1, -4, 0, 1, -4, 2, 1, -4,
        -3, 2, -4, -1, 2, -4, 1, 2, -4, 3, 2, -4,
        -4, 3, -4, -2, 3, -4, 0, 3, -4, 2, 3, -4, 4, 3, -4,
        -3, 4, -4, 3, 4, -4,

        -4, -4, -3, -2, -4, -3, 0, -4, -3, 2, -4, -3, 4, -4, -3,
        -4, -2, -3, 4, -2, -3,
        -4, 0, -3, 4, 0, -3,
        -4, 2, -3, 4, 2, -3,
        -4, 4, -3, -2, 4, -3, 0, 4, -3, 2, 4, -3, 4, 4, -3,

        0, -5, -2,
        -3, -4, -2, -1, -4, -2, 1, -4, -2, 3, -4, -2,
        -4, -3, -2, 4, -3, -2,
        -4, -1, -2, 4, -1, -2,
        -5, 0, -2, 5, 0, -2,
        -4, 1, -2, 4, 1, -2,
        -4, 3, -2, 4, 3, -2,
        -3, 4, -2, -1, 4, -2, 1, 4, -2, 3, 4, -2,
        0, 5, -2,

        -2, -4, -1, 0, -4, -1, 2, -4, -1,
        -4, -2, -1, 4, -2, -1,
        -4, 0, -1, 4, 0, -1,
        -4, 2, -1, 4, 2, -1,
        -2, 4, -1, 0, 4, -1, 2, 4, -1,

        -2, -5, 0, 2, -5, 0,
        -3, -4, 0, -1, -4, 0, 1, -4, 0, 3, -4, 0,
        -4, -3, 0, 4, -3, 0,
        -5, -2, 0, 5, -2, 0,
        -4, -1, 0, 4, -1, 0,
        -4, 1, 0, 4, 1, 0,
        -5, 2, 0, 5, 2, 0,
        -4, 3, 0, 4, 3, 0,
        -3, 4, 0, -1, 4, 0, 1, 4, 0, 3, 4, 0,
        -2, 5, 0, 2, 5, 0,

        -2, -4, 1, 0, -4, 1, 2, -4, 1,
        -4, -2, 1, 4, -2, 1,
        -4, 0, 1, 4, 0, 1,
        -4, 2, 1, 4, 2, 1,
        -2, 4, 1, 0, 4, 1, 2, 4, 1,

        0, -5, 2,
        -3, -4, 2, -1, -4, 2, 1, -4, 2, 3, -4, 2,
        -4, -3, 2, 4, -3, 2,
        -4, -1, 2, 4, -1, 2,
        -5, 0, 2, 5, 0, 2,
        -4, 1, 2, 4, 1, 2,
        -4, 3, 2, 4, 3, 2,
        -3, 4, 2, -1, 4, 2, 1, 4, 2, 3, 4, 2,
        0, 5, 2,

        -4, -4, 3, -2, -4, 3, 0, -4, 3, 2, -4, 3, 4, -4, 3,
        -4, -2, 3, 4, -2, 3,
        -4, 0, 3, 4, 0, 3,
        -4, 2, 3, 4, 2, 3,
        -4, 4, 3, -2, 4, 3, 0, 4, 3, 2, 4, 3, 4, 4, 3,

        -3, -4, 4, 3, -4, 4,
        -4, -3, 4, -2, -3, 4, 0, -3, 4, 2, -3, 4, 4, -3, 4,
        -3, -2, 4, -1, -2, 4, 1, -2, 4, 3, -2, 4,
        -2, -1, 4, 0, -1, 4, 2, -1, 4,
        -3, 0, 4, -1, 0, 4, 1, 0, 4, 3, 0, 4,
        -2, 1, 4, 0, 1, 4, 2, 1, 4,
        -3, 2, 4, -1, 2, 4, 1, 2, 4, 3, 2, 4,
        -4, 3, 4, -2, 3, 4, 0, 3, 4, 2, 3, 4, 4, 3, 4,
        -3, 4, 4, 3, 4, 4,

        0, -2, 5,
        -2, 0, 5, 2, 0, 5,
        0, 2, 5,
        127
	},
#endif
};

static char patterns_14S34B4[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider (diagonal p4)"},
#endif
	{
        2, 1, 0,

         1, 1, 1, 2, 1, 1,
         2, 0, 1,

        1, 2, 2, 2, 2, 2,

         0, 0, 3,
         0, 1, 3,

        0, 1, 4,
        0, 2, 4, 1, 2, 4,

         0, 1, 5,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"blinker"},
#endif
	{
        0, 0, -2,

         -1, -1, -1,
         0, 0, -1,

        0, 0, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"tetrahedron"},
#endif
	{
        0, -1, -2,
        -1, 0, -2,

         -1, -1, -1,

        -1, -1, 0,
        0, 0, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"gear"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
          -1, 0, -1,

         0, 0, 0,

          -1, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"lift"},
#endif
	{
        0, -1, -1,

        1, -2, 0,
        1, -1, 0,
        -1, 0, 0, 0, 0, 0,

         0, -2, 1,
         -1, -1, 1,

        1, -1, 2,
        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"squeeze"},
#endif
	{
        -1, -1, -2,

         -1, -2, -1,

        0, -2, 0,
        -1, -1, 0,

         -1, -3, 1,
         -2, -2, 1, 0, -2, 1,
         -1, -1, 1,

        -1, -3, 2,
        -1, -2, 2,
        0, -1, 2, 1, -1, 2,

         -1, -2, 3,
        127
	},
#ifdef LIFE_NAMES
	{"dampen"},
#endif
	{
        1, -1, -3,
         0, 0, -3,

        0, -1, -2,
        1, 0, -2,

         -1, -2, -1, 0, -2, -1,
         -1, -1, -1,
         1, 0, -1,

        1, -1, 0,
        0, 0, 0,

         0, -2, 1,
         -1, -1, 1, 0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"twinkle"},
#endif
	{
        -1, -2, -3, 0, -2, -3,
         0, -1, -3,

        0, -2, -2, 1, -2, -2,
        -1, -1, -2, 1, -1, -2,
        -1, 0, -2,

         -1, -3, -1,
         -2, -2, -1,
         -2, -1, -1, 0, -1, -1,

        -1, -2, 0,
        1, -1, 0,
        -1, 0, 0, 0, 0, 0,

         -1, -3, 1, 0, -3, 1,
         0, -2, 1,
         -2, -1, 1, -1, -1, 1,

        -1, -2, 2, 0, -2, 2,
        0, -1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"octahedron"},
#endif
	{
        0, -2, -4,

        0, -3, -2,
        -1, -2, -2, 0, -2, -2, 1, -2, -2,
        0, -1, -2,

        0, -4, 0,
        -1, -3, 0, 0, -3, 0, 1, -3, 0,
        -2, -2, 0, -1, -2, 0, 1, -2, 0, 2, -2, 0,
        -1, -1, 0, 0, -1, 0, 1, -1, 0,
        0, 0, 0,

        0, -3, 2,
        -1, -2, 2, 0, -2, 2, 1, -2, 2,
        0, -1, 2,

        0, -2, 4,
        127
	},
#ifdef LIFE_NAMES
	{"star (p3)"},
#endif
	{
        -1, -1, -2,

         0, -2, -1,
         -1, -1, -1,
         -2, 0, -1,

        0, -1, 0,
        -1, 0, 0,

         0, -1, 1,
         -1, 0, 1,

        1, -1, 2,
        0, 0, 2,
        -1, 1, 2,

         0, 0, 3,
        127
	},
#ifdef LIFE_NAMES
	{"spark3 (p3)"},
#endif
	{
        0, -1, -4,
        0, 0, -4,

         -1, -1, -3, 0, -1, -3,

         -1, -1, -1,
         0, 0, -1,
         0, 1, -1,

        0, -1, 0,
        1, 1, 0,

         -1, -1, 1,
         0, 0, 1,
         0, 1, 1,

         -1, -1, 3, 0, -1, 3,

        0, -1, 4,
        0, 0, 4,
        127
	},
#ifdef LIFE_NAMES
	{"spark3v2 (p3)"},
#endif
	{
        1, 0, -4, 2, 0, -4,

         0, -2, -3,
         0, -1, -3,
         1, 0, -3,

        0, -1, -2,
        2, 0, -2,

         0, -2, -1,
         1, -1, -1,

        0, -1, 0,
        1, 0, 0,

         0, -2, 1,
         1, -1, 1,

        0, -1, 2,
        2, 0, 2,

         0, -2, 3,
         0, -1, 3,
         1, 0, 3,

        1, 0, 4, 2, 0, 4,
        127
	},
#ifdef LIFE_NAMES
	{"wavy hair (p3)"},
#endif
	{
        -1, -2, -2, 0, -2, -2, 1, -2, -2,
        -1, 0, -2, 0, 0, -2, 1, 0, -2,

         -1, -3, -1, 0, -3, -1,
         -1, 0, -1, 0, 0, -1,

        -1, -2, 0, 1, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 1, 0, 0,

        -1, -1, 2, 0, -1, 2, 1, -1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"moon lander (p3)"},
#endif
	{
        -1, -2, -4,
        -1, -1, -4,
        0, 0, -4, 1, 0, -4,

         -2, -2, -3,
         0, 0, -3,

        -1, -2, -2,
        1, 0, -2,

         -2, -1, -1,
         -2, 0, -1, -1, 0, -1,

        0, -2, 0, 1, -2, 0,
        1, -1, 0,
        -2, 0, 0,
        -1, 1, 0,

         0, -2, 1,
         -2, -1, 1, -1, -1, 1,
         -1, 0, 1,

        -1, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"sandwich (p3)"},
#endif
	{
        0, -1, -4,

         -2, -2, -3, 1, -2, -3,
         -2, -1, -3, 1, -1, -3,

        -1, -2, -2, 0, -2, -2, 1, -2, -2,
        -1, 0, -2, 0, 0, -2, 1, 0, -2,

        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -1, 0, 0, 1, 0, 0,

        -1, -2, 2, 0, -2, 2, 1, -2, 2,
        -1, 0, 2, 0, 0, 2, 1, 0, 2,

         -2, -2, 3, 1, -2, 3,
         -2, -1, 3, 1, -1, 3,

        0, -1, 4,
        127
	},
#ifdef LIFE_NAMES
	{"captured (p3)"},
#endif
	{
        -1, -2, -4,
        -1, -1, -4,

         -1, -3, -3, 0, -3, -3,
         -2, -2, -3,
         -2, -1, -3, -1, -1, -3,

        -1, -3, -2, 0, -3, -2,
        -2, -2, -2,
        0, -1, -2,

         -2, -3, -1, 0, -3, -1,
         1, -1, -1,
         1, 0, -1,

        -2, -2, 0, 0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        0, 0, 0, 2, 0, 0,

         -2, -3, 1,
         -2, -2, 1,
         -1, 0, 1, 1, 0, 1,

        0, -1, 2,
        2, 0, 2,
        0, 1, 2, 1, 1, 2,

         0, -2, 3, 1, -2, 3,
         1, -1, 3,
         -1, 0, 3, 0, 0, 3,

        1, -1, 4,
        1, 0, 4,
        127
	},
#ifdef LIFE_NAMES
	{"jiggle (p4)"},
#endif
	{
        -1, -1, -3,

        0, -1, -2,
        0, 0, -2,

         -1, -1, -1,

        0, -1, 0,

         -1, -1, 1,

        0, -1, 2,
        0, 0, 2,

         -1, -1, 3,
        127
	},
#ifdef LIFE_NAMES
	{"pass back (p4)"},
#endif
	{
        -2, 0, -1, -1, 0, -1, 1, 0, -1,

        -1, 0, 0, 1, 0, 0,
        -1, 1, 0,

         0, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"hat trick (p4)"},
#endif
	{
        1, -1, -1,
         0, 0, -1, 1, 0, -1,
         0, 1, -1,
         0, 2, -1,

        2, 0, 0,
        0, 1, 0,
        0, 2, 0, 1, 2, 0,

         1, -1, 1,
         1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"double hat trick (p4)"},
#endif
	{
        1, -1, -1, 2, -1, -1,
         -1, 1, -1,
         -1, 2, -1,

        2, -1, 0,
        2, 1, 0,
        -1, 2, 0, 1, 2, 0, 2, 2, 0,

         1, -1, 1, 2, -1, 1,
         1, 0, 1,
         -1, 1, 1, 0, 1, 1, 1, 1, 1,
         -1, 2, 1,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"double hat variant (p4)"},
#endif
	{
        1, -2, -1,
         1, -1, -1,
         1, 0, -1,
         -2, 1, -1, -1, 1, -1, 0, 1, -1, 1, 1, -1,

        2, -1, 0,
        2, 1, 0,
        -1, 2, 0, 1, 2, 0, 2, 2, 0,

         1, -2, 1,
         1, -1, 1,
         -2, 1, 1, -1, 1, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"double hat variant2 (p4)"},
#endif
	{
        2, -2, -1,
         -2, 2, -1,

        3, -2, 0,
        3, -1, 0,
        0, 0, 0, 1, 0, 0,
        0, 1, 0,
        -2, 3, 0, -1, 3, 0,

         2, -2, 1,
         -1, -1, 1, 0, -1, 1, 1, -1, 1, 2, -1, 1,
         -1, 0, 1,
         -1, 1, 1,
         -2, 2, 1, -1, 2, 1,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"spark4 (p4)"},
#endif
	{
        0, -1, -1, 1, -1, -1,
         -1, 0, -1,
         -1, 1, -1,

        0, -1, 0, 2, -1, 0,
        -1, 0, 0, 2, 0, 0,
        -1, 2, 0, 0, 2, 0,

         0, -1, 1, 1, -1, 1,
         -1, 0, 1,
         -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"spark4v2 (p4)"},
#endif
	{
        0, 0, -3, 1, 0, -3,
         0, 1, -3,

        1, 0, -2,
        0, 1, -2,

         0, -1, -1,
         -1, 0, -1, 1, 0, -1,
         0, 1, -1,

        0, -1, 0,
        -1, 0, 0,
        1, 1, 0,

         0, -1, 1,
         -1, 0, 1, 1, 0, 1,
         0, 1, 1,

        1, 0, 2,
        0, 1, 2,

         0, 0, 3, 1, 0, 3,
         0, 1, 3,
        127
	},
#ifdef LIFE_NAMES
	{"spark5 (p5)"},
#endif
	{
        1, 0, -2,
        0, 1, -2, 1, 1, -2,

         0, -1, -1,
         1, 0, -1,
         0, 1, -1,

        1, -1, 0,
        0, 1, 0,

         0, -1, 1,
         1, 0, 1,
         0, 1, 1,

        1, 0, 2,
        0, 1, 2, 1, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"hoola hoop (p8)"},
#endif
	{
        -2, 1, -1, -1, 1, -1,
         -2, 2, -1, -1, 2, -1,

        0, 1, 0,
        0, 2, 0,

         -2, 2, 1, -1, 2, 1,

        -1, 1, 2, 0, 1, 2,
        -1, 2, 2, 0, 2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"spark8 (p8)"},
#endif
	{
        0, -1, -2, 1, -1, -2,
        -1, 0, -2,
        -1, 1, -2,

         -2, -2, -1, -1, -2, -1, 0, -2, -1,
         -2, -1, -1,
         -2, 0, -1,

        -1, -1, 0, 1, -1, 0,
        -1, 1, 0,

         -1, -1, 1, 0, -1, 1,
         -1, 0, 1,

        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"necklace (p8)"},
#endif
	{
        -1, -2, -3,
         -2, -1, -3, -1, -1, -3,

        0, -1, -2,
        -1, 0, -2,

         -1, -2, -1,
         -2, -1, -1,

        0, -1, 0,
        -1, 0, 0,

         -1, -2, 1,
         -2, -1, 1,

        -1, -1, 2,

         -1, -2, 3, 0, -2, 3,
         -2, -1, 3, 0, -1, 3,
         -2, 0, 3, -1, 0, 3,

        0, -1, 4, 1, -1, 4,
        -1, 0, 4,
        -1, 1, 4,
        127
	},
#ifdef LIFE_NAMES
	{"exploding box (p10)"},
#endif
	{
        1, 0, -2,
        0, 1, -2,

         0, -1, -1,
         -1, 0, -1, 1, 0, -1,
         0, 1, -1,

        1, 0, 0,
        0, 1, 0,

         0, -1, 1,
         -1, 0, 1, 1, 0, 1,
         0, 1, 1,

        1, 0, 2,
        0, 1, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"tetrahedron (stable)"},
#endif
	{
        0, 0, -1,

         0, 1, 0, 1, 1, 0,

        0, 0, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"hat (stable)"},
#endif
	{
        -1, -1, 0, 0, -1, 0,
        -1, 0, 0, 0, 0, 0,

         -1, -1, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"tire (stable)"},
#endif
	{
        0, 0, -1,

        0, 0, 0, 1, 0, 0,
        0, 1, 0,

         1, 0, 1,
         0, 1, 1, 1, 1, 1,

        1, 1, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"bad tire (stable)"},
#endif
	{
        0, 0, -2, 1, 0, -2,

         1, -1, -1,
         0, 0, -1, 1, 0, -1,

        1, -1, 0,
        0, 0, 0,

         0, -1, 1, 1, -1, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"seat (stable)"},
#endif
	{
        0, 0, -2,
        0, 1, -2, 1, 1, -2,

         -1, 0, -1, 1, 0, -1,
         1, 1, -1,

        0, 0, 0,
        0, 1, 0, 1, 1, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"frozen arrow (stable)"},
#endif
	{
        0, -1, -2, 1, -1, -2,

         0, -2, -1,
         -1, -1, -1, 1, -1, -1,

        0, 0, 0, 1, 0, 0,

         0, -2, 1,
         -1, -1, 1, 1, -1, 1,

        0, -1, 2, 1, -1, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"throne (stable)"},
#endif
	{
        0, 0, -2,
        0, 1, -2,

         0, -1, -1, 1, -1, -1,
         -1, 0, -1,

        1, -1, 0,
        0, 1, 0,

         0, -1, 1, 1, -1, 1,
         -1, 0, 1,

        0, 0, 2,
        0, 1, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"O (stable)"},
#endif
	{
        -1, 0, -1, 0, 0, -1, 1, 0, -1,

        -1, 0, 0,
        -1, 1, 0, 0, 1, 0, 1, 1, 0,

         -1, -1, 1, 0, -1, 1, 1, -1, 1,
         1, 0, 1,

        -1, 0, 2, 0, 0, 2, 1, 0, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"big tire (stable)"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2,

         -1, -2, -1, 0, -2, -1,
         -2, -1, -1,
         -2, 0, -1,

        1, -1, 0,
        -1, 1, 0,

         0, -2, 1,
         -2, 0, 1,

        1, -1, 2,
        1, 0, 2,
        -1, 1, 2, 0, 1, 2,

         0, -1, 3,
         -1, 0, 3, 0, 0, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"stool (stable)"},
#endif
	{
        0, 0, -3, 1, 0, -3,

        1, 0, -2,
        0, 1, -2,

         1, 0, -1,
         0, 1, -1,

        1, 0, 0,
        0, 1, 0,

         0, 0, 1,
         0, 1, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"ball (stable)"},
#endif
	{
        0, 0, -2,
        0, 1, -2, 1, 1, -2,

         0, -1, -1,
         -1, 0, -1, 1, 0, -1,
         0, 1, -1,

        1, 0, 0,

         0, -1, 1,
         -1, 0, 1, 1, 0, 1,
         0, 1, 1,

        0, 0, 2,
        0, 1, 2, 1, 1, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"chain (stable)"},
#endif
	{
        0, 0, -4,
        0, 1, -4,

         -1, 0, -3, 0, 0, -3,

         -1, 0, -1, 0, 0, -1,

        0, 1, 0,

         -1, 0, 1, 0, 0, 1,

         -1, 0, 3, 0, 0, 3,

        0, 0, 4,
        0, 1, 4,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"log (stable)"},
#endif
	{
        0, -1, -3,
         0, 0, -3, 1, 0, -3,

        0, 0, -2,
        1, 1, -2,

         0, -1, -1,
         1, 0, -1,

        0, 0, 0,
        1, 1, 0,

         0, -1, 1,
         1, 0, 1,

        0, 0, 2,
        1, 1, 2,

         0, -1, 3,
         0, 0, 3, 1, 0, 3,
        127
	},
#endif
};

static char patterns_14S34B46[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider (diagonal p4)"},
#endif
	{
        2, 1, 0,

         1, 1, 1, 2, 1, 1,
         2, 0, 1,

        1, 2, 2, 2, 2, 2,

         0, 0, 3,
         0, 1, 3,

        0, 1, 4,
        0, 2, 4, 1, 2, 4,

         0, 1, 5,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"blinker"},
#endif
	{
        0, 0, -2,

         -1, -1, -1,
         0, 0, -1,

        0, 0, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"tetrahedron"},
#endif
	{
        0, -1, -2,
        -1, 0, -2,

         -1, -1, -1,

        -1, -1, 0,
        0, 0, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"gear"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
         -1, 0, -1,

        0, 0, 0,

         -1, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"lift"},
#endif
	{
        0, -1, -1,

        1, -2, 0,
        1, -1, 0,
        -1, 0, 0, 0, 0, 0,

         0, -2, 1,
         -1, -1, 1,

        1, -1, 2,
        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"share"},
#endif
	{
        0, -1, -2,
        1, 0, -2,

         -1, -2, -1, 0, -2, -1,
         -1, -1, -1, 1, -1, -1,
         0, 0, -1, 1, 0, -1,

        1, -1, 0,
        0, 0, 0, 1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"hook"},
#endif
	{
        -1, -1, -3, 0, -1, -3,

        0, -1, -2,
        0, 0, -2, 1, 0, -2,

         1, -1, -1,

        1, -1, 0,

         0, -1, 1, 1, -1, 1,

        1, -1, 2,
        1, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"crystal"},
#endif
	{
        0, 0, -3,

        0, 0, -2, 1, 0, -2,
        0, 1, -2, 1, 1, -2,

         0, -1, -1,
         -1, 0, -1, 1, 0, -1,
         0, 1, -1,

         0, -1, 1,
         -1, 0, 1, 1, 0, 1,
         0, 1, 1,

        0, 0, 2, 1, 0, 2,
        0, 1, 2, 1, 1, 2,

         0, 0, 3,
        127
	},
#ifdef LIFE_NAMES
	{"capacitor (p3)"},
#endif
	{
        -1, 1, -2, 0, 1, -2,

         -1, 0, -1,
         0, 1, -1,

        -1, 1, 0,
        1, 2, 0,

         -1, 1, 1,
         0, 2, 1,

        0, 2, 2, 1, 2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"jiggle (p4)"},
#endif
	{
        -1, -1, -3,

        0, -1, -2,
        0, 0, -2,

         -1, -1, -1,

        0, -1, 0,

         -1, -1, 1,

        0, -1, 2,
        0, 0, 2,

         -1, -1, 3,
        127
	},
#ifdef LIFE_NAMES
	{"reel mower (p4)"},
#endif
	{
        0, -1, -1,
         -2, 1, -1, 0, 1, -1,

         0, -1, 1,
         1, 0, 1,
         -2, 1, 1,
         -1, 2, 1,

        0, 0, 2, 1, 0, 2,
        -1, 1, 2, 0, 1, 2, 1, 1, 2,
        -1, 2, 2, 0, 2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"kiss (p5)"},
#endif
	{
        -1, -2, -3,

        -1, -2, -2, 0, -2, -2,
        -1, -1, -2,

         -1, -3, -1,
         -2, -2, -1,

        -1, -2, 0,
        1, 0, 0,

         1, -1, 1,
         0, 0, 1,

        1, -1, 2,
        0, 0, 2, 1, 0, 2,

         0, -1, 3,
        127
	},
#ifdef LIFE_NAMES
	{"hoola hoop (p8)"},
#endif
	{
        -2, 1, -1, -1, 1, -1,
         -2, 2, -1, -1, 2, -1,

        0, 1, 0,
        0, 2, 0,

         -2, 2, 1, -1, 2, 1,

        -1, 1, 2, 0, 1, 2,
        -1, 2, 2, 0, 2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"arrow (p8)"},
#endif
	{
        0, 1, -2,

         0, 0, -1,
         -1, 1, -1,

        1, 0, 0,
        -1, 1, 0,
        0, 2, 0,

         0, 0, 1,
         -1, 1, 1,

        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"fungus (p8)"},
#endif
	{
        1, 0, -2,

         0, -1, -1, 1, -1, -1,
         0, 0, -1,

        1, -1, 0,
        0, 0, 0, 1, 0, 0,
        1, 1, 0,

         1, -1, 1,
         0, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"planet (p8)"},
#endif
	{
        -1, 1, -2, 0, 1, -2,
        0, 2, -2,

         0, 0, -1,

        -1, 0, 0, 0, 0, 0,
        -1, 1, 0, 1, 1, 0,
        0, 2, 0,

         -1, 0, 1, 0, 0, 1,
         -1, 1, 1, 0, 1, 1,

        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"shuttle (p20)"},
#endif
	{
        -1, -2, -2,
        -1, -1, -2,
        -1, 0, -2, 0, 0, -2, 1, 0, -2,

         -1, -1, -1,

        -1, -2, 0,
        1, 0, 0,

         -1, -2, 1,
         0, -1, 1,

        -1, -2, 2, 0, -2, 2, 1, -2, 2,
        1, -1, 2,
        1, 0, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"tetrahedron (stable)"},
#endif
	{
        0, 0, -1,

        0, 1, 0, 1, 1, 0,

         0, 0, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"hat (stable)"},
#endif
	{
        -1, -1, 0, 0, -1, 0,
        -1, 0, 0, 0, 0, 0,

         -1, -1, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"tire (stable)"},
#endif
	{
        0, 0, -1,

        0, 0, 0, 1, 0, 0,
        0, 1, 0,

         1, 0, 1,
         0, 1, 1, 1, 1, 1,

        1, 1, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"bad tire (stable)"},
#endif
	{
        0, 0, -2, 1, 0, -2,

         1, -1, -1,
         0, 0, -1, 1, 0, -1,

        1, -1, 0,
        0, 0, 0,

         0, -1, 1, 1, -1, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"seat (stable)"},
#endif
	{
        0, 0, -2,
        0, 1, -2, 1, 1, -2,

         -1, 0, -1, 1, 0, -1,
         1, 1, -1,

        0, 0, 0,
        0, 1, 0, 1, 1, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"frozen arrow (stable)"},
#endif
	{
        0, -1, -2, 1, -1, -2,

         0, -2, -1,
         -1, -1, -1, 1, -1, -1,

        0, 0, 0, 1, 0, 0,

         0, -2, 1,
         -1, -1, 1, 1, -1, 1,

        0, -1, 2, 1, -1, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"throne (stable)"},
#endif
	{
        0, 0, -2,
        0, 1, -2,

         0, -1, -1, 1, -1, -1,
         -1, 0, -1,

        1, -1, 0,
        0, 1, 0,

         0, -1, 1, 1, -1, 1,
         -1, 0, 1,

        0, 0, 2,
        0, 1, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"O (stable)"},
#endif
	{
        -1, 0, -1, 0, 0, -1, 1, 0, -1,

        -1, 0, 0,
        -1, 1, 0, 0, 1, 0, 1, 1, 0,

         -1, -1, 1, 0, -1, 1, 1, -1, 1,
         1, 0, 1,

        -1, 0, 2, 0, 0, 2, 1, 0, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"big tire (stable)"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2,

         -1, -2, -1, 0, -2, -1,
         -2, -1, -1,
         -2, 0, -1,

        1, -1, 0,
        -1, 1, 0,

         0, -2, 1,
         -2, 0, 1,

        1, -1, 2,
        1, 0, 2,
        -1, 1, 2, 0, 1, 2,

         0, -1, 3,
         -1, 0, 3, 0, 0, 3,
        127
	},
#endif
};

static char patterns_14S56B45[][3 * NUMPTS + 1] =
{
#ifdef LIFE_NAMES
	{"ball (p10)"},
#endif
	{
        -1, -2, -3,

        0, -2, -2,
        1, -1, -2,
        -1, 0, -2, 0, 0, -2,

         -2, -2, -1,
         -1, -1, -1, 1, -1, -1,
         0, 0, -1,

        -1, -2, 0, 1, -2, 0,

         0, -3, 1,
         -1, -2, 1,
         -2, -1, 1, 0, -1, 1,
         -1, 0, 1,

        -1, -2, 2,
        1, -1, 2,
        1, 0, 2,

         0, -2, 3,
         -1, -1, 3,
        127
	},
};

static char patterns_18S45B4[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (c/2, p2)"},
#endif
	{
        0, 0, 0, 1, 0, 0,
        1, 1, 0,
        1, 2, 0,
        0, 3, 0, 1, 3, 0,

        0, 0, 1, 1, 0, 1,
        1, 1, 1,
        1, 2, 1,
        0, 3, 1, 1, 3, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (alt view) (c/2, p2)"},
#endif
	{
        0, 0, 0, 1, 0, 0,
        0, 1, 0, 1, 1, 0,

        1, 0, 1,
        1, 1, 1,

        1, 0, 2,
        1, 1, 2,

        0, 0, 3, 1, 0, 3,
        0, 1, 3, 1, 1, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"blinker"},
#endif
	{
        0, 0, -1, -1, 0, -1,
        0, -1, 0, -1, -1, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"helicopter"},
#endif
	{
        1, -1, -1,
        1, 1, -1,

        0, 0, 0, 1, 0, 0, 2, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"couch"},
#endif
	{
        -2, 0, -1, 1, 0, -1,
        0, -1, -1, -1, -1, -1,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"twisty"},
#endif
	{
        -1, 0, -2, 0, 0, -2,

        0, -2, -1,
        1, -1, -1,
        0, 1, -1, -1, 1, -1,

        0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0,

        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"ball"},
#endif
	{
        1, 1, -1,

        1, 0, 0, 2, 0, 0,
        0, 1, 0, 1, 1, 0,
        0, 2, 0,

        1, -1, 1,
        0, 0, 1, 1, 0, 1,
        -1, 1, 1, 0, 1, 1,

        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"death star"},
#endif
	{
        0, 0, -2,

        0, -1, -1,
        -1, 0, -1,
        0, 1, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -2, 0, 0, 2, 0, 0,
        1, 1, 0,
        0, 2, 0,

        -1, 0, 1, 1, 0, 1,
        0, 1, 1,

        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"corner (p4)"},
#endif
	{
        0, 1, -2,

        2, -1, -1,
        1, 0, -1, 2, 0, -1,
        0, 1, -1,
        -1, 2, -1,

        1, -2, 0,
        1, -1, 0,
        -1, 1, 0,
        -1, 2, 0,

        -2, 0, 1, -1, 0, 1,
        0, -1, 1,

        -1, -1, 2, 0, -1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"Hogwart stairway (p8)"},
#endif
	{
        1, -2, -1,
        0, -1, -1,
        -1, 0, -1,
        -2, 1, -1,

        1, -2, 0,
        0, -1, 0,
        -1, 0, 0,
        -2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"X (p38)"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 0, 0, -1, 1, 0, -1,
        0, 1, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"step (stable)"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
        -1, 0, -1,

        0, -1, 0,
        -1, 0, 0, 0, 0, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"TXT (stable)"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 0, 0, -1, 1, 0, -1,
        0, 1, -1,

        0, 0, 0,
        127
	},
#endif
};

static char patterns_20S45B4[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (c/4, p8)"},
#endif
	{
        1, 0, 0,
        2, 1, 0,
        2, 2, 0,
        1, 3, 0,

        1, 0, 1,
        0, 1, 1, 1, 1, 1, 2, 1, 1,
        0, 2, 1, 1, 2, 1, 2, 2, 1,
        1, 3, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (alt view) (c/4, p8)"},
#endif
	{
        1, 0, 0,
        1, 1, 0,

        2, 0, 1,
        0, 1, 1, 1, 1, 1, 2, 1, 1,

        2, 0, 2,
        0, 1, 2, 1, 1, 2, 2, 1, 2,

        1, 0, 3,
        1, 1, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"blinker"},
#endif
	{
        -1, 0, -1, 1, 0, -1,
        -1, 0, 0, 1, 0, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"pillars"},
#endif
	{
        -1, -2, -1, 0, -2, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 1, 0, -2, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"window"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
        -1, 1, -1, 0, 1, -1,
        -1, -1, 0, 0, -1, 0,
        -1, 1, 0, 0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"stargate"},
#endif
	{
        0, 0, -4,

        0, 0, -3,

        -2, 0, -2, 0, 0, -2, 2, 0, -2,

        -4, 0, 0, -3, 0, 0, -2, 0, 0, 2, 0, 0, 3, 0, 0, 4, 0, 0,

        -2, 0, 2, 0, 0, 2, 2, 0, 2,

        0, 0, 3,

        0, 0, 4,
        127
	},
#ifdef LIFE_NAMES
	{"rock and window"},
#endif
	{
        -1, -1, -3, 0, -1, -3,
        -1, 0, -3, 0, 0, -3,

        0, -2, -1,
        1, -1, -1,
        1, 0, -1,

        -1, -2, -1,
        -2, -1, -1,
        -2, 0, -1,
        -1, 1, -1, 0, 1, -1,
        127
	},
#ifdef LIFE_NAMES
	{"alternator"},
#endif
	{
        -1, -2, -2, 0, -2, -2,
        -1, 1, -2, 0, 1, -2,

        -1, -3, -1, 0, -3, -1,
        -2, -2, -1, 1, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        -2, 1, -1, 1, 1, -1,
        -1, 2, -1, 0, 2, -1,

        -1, -3, 0, 0, -3, 0,
        -2, -2, 0, 1, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -2, 1, 0, 1, 1, 0,
        -1, 2, 0, 0, 2, 0,

        -1, -2, 1, 0, -2, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"exploding wheel (p3)"},
#endif
	{
        0, 0, -3,

        0, -2, -2,
        -2, 0, -2, 2, 0, -2,
        0, 2, -2,

        0, -1, -1,
        -1, 0, -1, 1, 0, -1,
        0, 1, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        0, -2, 1,
        -2, 0, 1, 2, 0, 1,
        0, 2, 1,

        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"fish (p3)"},
#endif
	{
        -2, -1, -2, -1, -2, -2, 0, -1, -2,
        -1, 0, -2,

        -2, -2, -1, 0, -2, -1,
        -2, 0, -1, 1, 0, -1,
        0, 1, -1,

        -1, -2, 0,
        -2, -1, 0, -1, 1, 0, 0, 1, 0, 1, -1, 0,
        1, 0, 0,

        -1, 0, 1, 0, 0, 1,
        0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"flipping triangles (p4)"},
#endif
	{
        -1, -1, -1, 0, -1, -1, 1, -1, -1,
        -1, 0, -1, 0, 0, -1,
        -1, 1, -1,

        -1, -1, 1, 0, -1, 1, 1, -1, 1,
        -1, 0, 1, 0, 0, 1,
        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"shuttle (p4)"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1,
        -2, 0, -1, 1, 0, -1,
        0, 1, -1,

        -1, -2, 0,
        -2, -1, 0, 1, -1, 0,
        2, 0, 0,
        -1, 1, 0, 2, 1, 0,
        0, 2, 0, 1, 2, 0,

        0, -1, 1,
        -1, 0, 1, 2, 0, 1,
        2, 1, 1,
        0, 2, 1, 1, 2, 1,

        0, 0, 2, 1, 0, 2,
        0, 1, 2, 1, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"pair (p7)"},
#endif
	{
        -2, -3, -4, -1, -3, -4,
        -2, -2, -4,

        -2, -4, -3, -1, -4, -3,
        -3, -3, -3, -1, -3, -3,
        -3, -2, -3, -2, -2, -3,

        -2, -4, -2,
        -3, -3, -2, -2, -3, -2,

        2, 1, 0, 3, 1, 0,
        2, 2, 0,

        2, 0, 1, 3, 0, 1,
        1, 1, 1, 3, 1, 1,
        1, 2, 1, 2, 2, 1,

        2, 0, 2,
        1, 1, 2, 2, 1, 2,
        127
	},
};

static char patterns_26S23B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (c/2, p4)"},
#endif
	{
        0, 0, 0,
        1, 1, 0,
        1, 2, 0,
        0, 3, 0,

        1, 0, 1,
        1, 3, 1,

        1, 0, 2,
        1, 3, 2,

        0, 0, 3,
        1, 1, 3,
        1, 2, 3,
        0, 3, 3,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"glider pair orthogonal (c/2, p4)"},
#endif
	{
        -2, -2, -3, 1, -2, -3,
        -2, 1, -3, 1, 1, -3,

        -1, -2, -2, 0, -2, -2,
        -2, -1, -2, 1, -1, -2,
        -2, 0, -2, 1, 0, -2,
        -1, 1, -2, 0, 1, -2,

        -2, -2, 0, 1, -2, 0,
        -1, -1, 0, 0, -1, 0,
        -1, 0, 0, 0, 0, 0,
        -2, 1, 0, 1, 1, 0,

        -1, -2, 1, 0, -2, 1,
        -2, -1, 1, -1, -1, 1, 0, -1, 1, 1, -1, 1,
        -2, 0, 1, -1, 0, 1, 0, 0, 1, 1, 0, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"toggler"},
#endif
	{
        0, -2, -1,
        0, -1, -1,
        0, 0, -1,
        0, 1, -1,

        -1, -1, 0,
        -1, 0, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"123 (p3)"},
#endif
	{
        -2, -2, -1,
        -1, -1, -1,

        -1, -1, 0,
        1, 1, 0,

        0, 0, 1, 1, 0, 1,
        1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"corner (p3)"},
#endif
	{
        -1, -2, -2, 1, -2, -2,
        -2, -1, -2, -1, -1, -2, 0, -1, -2,
        -1, 0, -2,
        -2, 1, -2,

        -2, -2, -1, -1, -2, -1, 0, -2, -1,
        -2, -1, -1, -2, 0, -1,

        -1, -2, 0,
        -2, -1, 0,

        -2, -2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"toaster (p4)"},
#endif
	{
        -1, -2, -1,
        0, -1, -1,
        -1, 0, -1, 1, 0, -1,

        0, -2, 0,
        -2, -1, 0, 0, -1, 0, 1, -1, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"twisty (p4)"},
#endif
	{
        -1, -1, 1, 0, -1, 1,
        0, 1, 1,
        0, 2, 1,

        0, -2, 0,
        0, 1, 0, 1, 1, 0,
        1, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"catch (p4)"},
#endif
	{
        -2, -2, -1, -1, -2, -1,
        -2, -1, -1,
        0, 0, -1,

        0, 0, 0, 1, 0, 0,
        0, 1, 0, 1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"v drum (p4)"},
#endif
	{
        -3, -3, -1, 1, -3, -1,
        2, -2, -1,
        2, 2, -1,

        -2, -3, 0, -1, -3, 0,
        -2, -2, 0, -1, -2, 0, 0, -2, 0,
        1, -1, 0,
        1, 0, 0, 2, 0, 0,
        1, 1, 0, 2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"change flow (p4)"},
#endif
	{
        1, -2, -2,
        1, -1, -2,
        -2, 0, -2,
        -2, 1, -2,

        1, -2, -1,
        1, -1, -1,
        -2, 0, -1,
        -2, 1, -1,

        -2, -2, 0,
        -1, -1, 0,
        0, 0, 0,
        1, 1, 0,

        -3, -3, 1,
        -2, -2, 1,
        1, 1, 1,
        2, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"cross drum (p4)"},
#endif
	{
        -1, -3, -1, 1, -3, -1,
        -2, -2, -1, 2, -2, -1,
        -2, 0, -1, 2, 0, -1,
        -1, 1, -1, 1, 1, -1,

        0, -2, 0,
        -1, -1, 0, 0, -1, 0, 1, -1, 0,
        0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"invert (p4)"},
#endif
	{
        -1, -4, -1, 1, -4, -1,
        -2, -3, -1, 2, -3, -1,
        -2, -1, -1, 2, -1, -1,
        -1, 0, -1, 1, 0, -1,

        0, -6, 0,
        -1, -5, 0, 1, -5, 0,
        -3, -3, 0, 3, -3, 0,
        -4, -2, 0, 4, -2, 0,
        -3, -1, 0, 3, -1, 0,
        -1, 1, 0, 1, 1, 0,
        0, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"lean forward (p6)"},
#endif
	{
        -1, -2, -2,
        -1, 1, -2,

        -1, -2, -1, 0, -2, -1,
        -1, 1, -1, 0, 1, -1,

        1, -2, 0,
        1, 1, 0,

        0, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"bird (p7)"},
#endif
	{
        -1, -3, -2,
        0, -2, -2,
        0, -1, -2,
        0, 0, -2,
        -1, 1, -2,

        -1, -4, -1,
        1, -2, -1,
        1, 0, -1,
        -1, 2, -1,

        -1, -3, 0,
        0, -2, 0,
        0, -1, 0,
        0, 0, 0,
        -1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"double dutch (p8)"},
#endif
	{
        -2, -2, -1, -1, -2, -1, 0, -2, -1, 1, -2, -1,
        -2, 0, -1, -1, 0, -1, 0, 0, -1, 1, 0, -1,

        -3, -1, 0, 2, -1, 0,
        127
	},
};

static char patterns_26S25B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (c/3, p3)"},
#endif
	{
        1, 0, 0,
        1, 1, 0,
        0, 2, 0, 1, 2, 0,
        1, 3, 0,
        0, 4, 0, 1, 4, 0,
        1, 5, 0,
        1, 6, 0,

        1, 0, 1,
        1, 2, 1,
        1, 4, 1,
        1, 6, 1,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"crate (p3)"},
#endif
	{
        -2, -3, -2, -1, -3, -2, 0, -3, -2, 1, -3, -2,
        -3, -2, -2, 2, -2, -2,
        -3, -1, -2, 2, -1, -2,
        -3, 0, -2, 2, 0, -2,
        -3, 1, -2, 2, 1, -2,
        -2, 2, -2, -1, 2, -2, 0, 2, -2, 1, 2, -2,

        -3, -3, -1, 2, -3, -1,
        -3, 2, -1, 2, 2, -1,

        -3, -3, 0, 2, -3, 0,
        -3, 2, 0, 2, 2, 0,

        -2, -3, 1, -1, -3, 1, 0, -3, 1, 1, -3, 1,
        -3, -2, 1, 2, -2, 1,
        -3, -1, 1, 2, -1, 1,
        -3, 0, 1, 2, 0, 1,
        -3, 1, 1, 2, 1, 1,
        -2, 2, 1, -1, 2, 1, 0, 2, 1, 1, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"toaster (p4)"},
#endif
	{
        -2, 0, -1, 0, 0, -1,
        0, -2, -1,

        -1, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"boats (p4)"},
#endif
	{
        -1, 0, -1, 0, 0, -1,
        0, 1, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        0, -1, 1,
        0, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"bench (p4)"},
#endif
	{
        -1, -3, -2,
        -1, -2, -2,
        -1, -1, -2,
        -1, 0, -2,

        -1, -4, -1,
        -1, 1, -1,

        0, -3, 0,
        0, -2, 0,
        0, -1, 0,
        0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"broken glider (p4)"},
#endif
	{
        1, -3, -1, 1, -2, -1,
        -3, 1, -1, -2, 1, -1,

        2, -3, 0,
        1, -2, 0, 2, -2, 0,
        -2, 1, 0,
        -3, 2, 0, -2, 2, 0,

        -1, -2, 1, 0, -2, 1,
        -2, -1, 1,
        -2, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"twisty (p4)"},
#endif
	{
        -2, 0, 0, -1, 0, 0, 0, 0, 0, 2, 0, 0,

        1, -1, -1,
        0, 0, -1, 2, 0, -1,
        -1, 1, -1,
        127
	},
#ifdef LIFE_NAMES
	{"catch (p4)"},
#endif
	{
        -2, -2, -1, -1, -2, -1,
        -2, -1, -1,
        0, 0, -1,

        0, 0, 0, 1, 0, 0,
        0, 1, 0, 1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"leap frog (p4)"},
#endif
	{
        -1, -3, -2,
        -1, 2, -2,

        -1, -2, -1, 0, -2, -1,
        -1, -1, -1, 0, -1, -1,
        -1, 0, -1, 0, 0, -1,
        -1, 1, -1, 0, 1, -1,

        0, -2, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"v drum (p4)"},
#endif
	{
        -3, -3, -1, 1, -3, -1,
        2, -2, -1,
        2, 2, -1,

        -2, -3, 0, -1, -3, 0,
        -2, -2, 0, -1, -2, 0, 0, -2, 0,
        1, -1, 0,
        1, 0, 0, 2, 0, 0,
        1, 1, 0, 2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"hot potato (p4)"},
#endif
	{
        -1, -2, -3, 0, -2, -3, 1, -2, -3,
        -1, -1, -3, 1, -1, -3,
        -1, 0, -3, 0, 0, -3, 1, 0, -3,

        0, -1, -2,

        -1, -2, 0, 1, -2, 0,
        -1, 0, 0, 1, 0, 0,

        0, -2, 1,
        -1, -1, 1, 1, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"invert (p4)"},
#endif
	{
        -1, -4, -1, 1, -4, -1,
        -2, -3, -1, 2, -3, -1,
        -2, -1, -1, 2, -1, -1,
        -1, 0, -1, 1, 0, -1,

        0, -6, 0,
        -1, -5, 0, 1, -5, 0,
        -3, -3, 0, 3, -3, 0,
        -4, -2, 0, 4, -2, 0,
        -3, -1, 0, 3, -1, 0,
        -1, 1, 0, 1, 1, 0,
        0, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"4C (p6)"},
#endif
	{
        0, -3, -2, 1, -3, -2,
        2, -2, -2,
        -2, -1, -2, 2, -1, -2,
        -2, 0, -2,
        -1, 1, -2, 0, 1, -2,

        1, -3, -1,
        2, -2, -1,
        -2, 0, -1,
        -1, 1, -1,

        0, -3, 0, 1, -3, 0,
        2, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 0, 0,
        -1, 1, 0, 0, 1, 0,
        127
	},
};

static char patterns_26S27B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (c/2, p2)"},
#endif
	{
        2, 1, 0,

        2, 0, 1,
        2, 2, 1,

        0, 0, 2, 2, 0, 2,
        0, 2, 2, 2, 2, 2,

        0, 0, 3, 2, 0, 3,
        0, 2, 3, 2, 2, 3,

        2, 0, 4,
        2, 2, 4,

        2, 1, 5,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"toaster (p4)"},
#endif
	{
        0, -2, -1,
        -1, -1, -1,
        -2, 0, -1, 0, 0, -1,

        -1, -2, 0,
        -2, -1, 0, -1, -1, 0, 1, -1, 0,
        -1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"bird (p4)"},
#endif
	{
        0, -3, -1,
        -1, -2, -1, 0, -2, -1,
        1, -1, -1,
        1, 0, -1,
        -1, 1, -1, 0, 1, -1,
        0, 2, -1,

        0, -2, 0, 1, -2, 0,
        -1, -1, 0,
        -1, 0, 0,
        0, 1, 0, 1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"shear (p4)"},
#endif
	{
        -1, -2, -1,
        -1, -1, -1,
        -1, 0, -1,
        -1, 1, -1,

        -2, -3, 0,
        -2, 2, 0,

        -2, -2, 1,
        -2, -1, 1,
        -2, 0, 1,
        -2, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"twisty (p4)"},
#endif
	{
        0, 1, -2,

        -1, 1, -1,
        -1, 0, -1,

        -1, 0, 0, 0, 0, 0,

        0, -1, 1,

        -1, -1, 2,
        -1, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"catch (p4)"},
#endif
	{
        -2, -2, -1, -1, -2, -1,
        -2, -1, -1,
        0, 0, -1,

        0, 0, 0, 1, 0, 0,
        0, 1, 0, 1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"v drum (p4)"},
#endif
	{
        -3, -3, -1, 1, -3, -1,
        2, -2, -1,
        2, 2, -1,

        -2, -3, 0, -1, -3, 0,
        -2, -2, 0, -1, -2, 0, 0, -2, 0,
        1, -1, 0,
        1, 0, 0, 2, 0, 0,
        1, 1, 0, 2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"invert (p4)"},
#endif
	{
        -1, -4, -1, 1, -4, -1,
        -2, -3, -1, 2, -3, -1,
        -2, -1, -1, 2, -1, -1,
        -1, 0, -1, 1, 0, -1,

        0, -6, 0,
        -1, -5, 0, 1, -5, 0,
        -3, -3, 0, 3, -3, 0,
        -4, -2, 0, 4, -2, 0,
        -3, -1, 0, 3, -1, 0,
        -1, 1, 0, 1, 1, 0,
        0, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"flipping cross (p4)"},
#endif
	{
        -2, -3, -2, 1, -3, -2,
        -2, 0, -2, 1, 0, -2,

        -2, -3, -1, 1, -3, -1,
        -1, -2, -1, 0, -2, -1,
        -1, -1, -1, 0, -1, -1,
        -2, 0, -1, 1, 0, -1,

        -1, -4, 0, 0, -4, 0,
        -3, -2, 0, 2, -2, 0,
        -3, -1, 0, 2, -1, 0,
        -1, 1, 0, 0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"ball (p4)"},
#endif
	{
        -1, -3, -3,
        1, -2, -3,
        -2, -1, -3,
        0, 0, -3,

        0, -4, -2,
        -3, -2, -2, -1, -2, -2,
        0, -1, -2, 2, -1, -2,
        -1, 1, -2,

        -2, -4, -1,
        -1, -3, -1, 2, -3, -1,
        -2, -2, -1,
        1, -1, -1,
        -3, 0, -1, 0, 0, -1,
        1, 1, -1,

        1, -4, 0,
        -3, -3, 0, 0, -3, 0,
        1, -2, 0,
        -2, -1, 0,
        -1, 0, 0, 2, 0, 0,
        -2, 1, 0,

        -1, -4, 1,
        0, -2, 1, 2, -2, 1,
        -3, -1, 1, -1, -1, 1,
        0, 1, 1,

        0, -3, 2,
        -2, -2, 2,
        1, -1, 2,
        -1, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"xbox (p6)"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 1, 0, -1,
        0, 1, -1,

        0, -2, 0,
        -2, 0, 0, 0, 0, 0, 2, 0, 0,
        0, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"CC (p6)"},
#endif
	{
        -2, -2, -2, -1, -2, -2,
        1, 0, -2,
        1, 1, -2,

        -2, -2, -1,
        1, 1, -1,

        -2, -2, 0, -1, -2, 0,
        1, 0, 0,
        1, 1, 0,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"sextominos (p6)"},
#endif
	{
        -2, -4, -3, -1, -4, -3, 0, -4, -3, 1, -4, -3,
        -2, -2, -3, -1, -2, -3, 0, -2, -3, 1, -2, -3,
        -2, 1, -3, -1, 1, -3, 0, 1, -3, 1, 1, -3,
        -2, 3, -3, -1, 3, -3, 0, 3, -3, 1, 3, -3,

        -1, -4, -2, 0, -4, -2,
        -1, -2, -2, 0, -2, -2,
        -1, 1, -2, 0, 1, -2,
        -1, 3, -2, 0, 3, -2,

        -1, -4, 0, 0, -4, 0,
        -1, -2, 0, 0, -2, 0,
        -1, 1, 0, 0, 1, 0,
        -1, 3, 0, 0, 3, 0,

        -2, -4, 1, -1, -4, 1, 0, -4, 1, 1, -4, 1,
        -2, -2, 1, -1, -2, 1, 0, -2, 1, 1, -2, 1,
        -2, 1, 1, -1, 1, 1, 0, 1, 1, 1, 1, 1,
        -2, 3, 1, -1, 3, 1, 0, 3, 1, 1, 3, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"stick ball (p8)"},
#endif
	{
        -1, -3, -3, 0, -3, -3,
        -1, 0, -3, 0, 0, -3,

        -3, -2, -2, -1, -2, -2, 2, -2, -2,
        -3, -1, -2, 0, -1, -2, 2, -1, -2,

        -2, -4, -1, 1, -4, -1,
        -1, -3, -1,
        -2, -2, -1,
        1, -1, -1,
        0, 0, -1,
        -2, 1, -1, 1, 1, -1,

        -2, -4, 0, 1, -4, 0,
        0, -3, 0,
        1, -2, 0,
        -2, -1, 0,
        -1, 0, 0,
        -2, 1, 0, 1, 1, 0,

        -3, -2, 1, 0, -2, 1, 2, -2, 1,
        -3, -1, 1, -1, -1, 1, 2, -1, 1,

        -1, -3, 2, 0, -3, 2,
        -1, 0, 2, 0, 0, 2,
        127
	},
#endif
};

static char patterns_26S35B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (c/2, p2)"},
#endif
	{
        2, 2, 0,
        3, 3, 0,
        3, 4, 0,
        2, 5, 0,

        2, 2, 1,
        2, 5, 1,

        0, 0, 2, 1, 0, 2,
        2, 1, 2,
        3, 2, 2,
        3, 5, 2,
        2, 6, 2,
        0, 7, 2, 1, 7, 2,

        2, 2, 3,
        2, 5, 3,

        2, 2, 4,
        3, 3, 4,
        3, 4, 4,
        2, 5, 4,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"C"},
#endif
	{
        0, -1, -1, 0, -1, 0,
        0, 0, -1,
        0, 1, -1, 0, 1, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"pulsing cross"},
#endif
	{
        0, -1, -2,

        -1, -2, -1, 1, -2, -1,
        0, -1, -1,

        0, -2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"tri rotor"},
#endif
	{
        -1, -1, -2, 0, -1, -2,

        -2, -1, -1, 1, -1, -1,

        -1, -2, 0, 0, -2, 0,
        -1, 0, 0, 0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"toggler"},
#endif
	{
        -2, -2, -1,
        0, 0, -1,

        -1, -3, 0,
        -2, -2, 0, -1, -2, 0,
        0, -1, 0, 1, -1, 0,
        0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"drop em"},
#endif
	{
        -1, -2, -1,
        1, -1, -1,
        -2, 0, -1,
        0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"easy come (p3)"},
#endif
	{
        0, -1, -2,
        -1, 0, -2,

        -1, 0, -1, 0, 0, -1,

        -1, -3, 0,
        -1, -2, 0,

        0, -3, 1,
        0, -2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"invert (p4)"},
#endif
	{
        -1, -3, -1, 0, -3, -1,
        -2, -2, -1, 1, -2, -1,
        -3, -1, -1, 2, -1, -1,
        -3, 0, -1, 2, 0, -1,
        -2, 1, -1, 1, 1, -1,
        -1, 2, -1, 0, 2, -1,

        -1, -2, 0,
        1, -1, 0,
        -2, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"corner (p4)"},
#endif
	{
        2, -1, -2,
        1, 0, -2,
        0, 1, -2,
        -1, 2, -2,

        2, -2, -1,
        2, 0, -1,
        -2, 2, -1, 0, 2, -1,

        1, -2, 0,
        2, -1, 0,
        -2, 1, 0,
        -1, 2, 0,

        0, -2, 1,
        -2, 0, 1,

        -1, -2, 2,
        -2, -1, 2, 0, -1, 2,
        -1, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"arena (p4)"},
#endif
	{
        -2, -5, -1, -1, -5, -1, 0, -5, -1, 1, -5, -1,
        -5, -2, -1, 4, -2, -1,
        -5, -1, -1, 4, -1, -1,
        -5, 0, -1, 4, 0, -1,
        -5, 1, -1, 4, 1, -1,
        -2, 4, -1, -1, 4, -1, 0, 4, -1, 1, 4, -1,

        -3, -4, 0, -2, -4, 0, 1, -4, 0, 2, -4, 0,
        -4, -3, 0, -3, -3, 0, 2, -3, 0, 3, -3, 0,
        -4, -2, 0, 3, -2, 0,
        -4, 1, 0, 3, 1, 0,
        -4, 2, 0, -3, 2, 0, 2, 2, 0, 3, 2, 0,
        -3, 3, 0, -2, 3, 0, 1, 3, 0, 2, 3, 0,
        127
	},
#ifdef LIFE_NAMES
	{"polyomino (p6)"},
#endif
	{
        1, 0, -1,
        -1, -1, 0, 1, -1, 0,
        0, 0, 0, 1, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"gadget (p6)"},
#endif
	{
        0, -2, -2,
        0, -1, -2,

        1, -3, -1,
        -1, -2, -1,
        1, -1, -1,
        -1, 0, -1,

        0, -3, 0,
        0, -2, 0,
        0, -1, 0,
        0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"star (p6)"},
#endif
	{
        -1, -2, -3,
        0, -1, -3,

        -1, -2, -2,
        0, -1, -2,

        -1, -4, -1,
        -1, -3, -1,
        -3, -2, -1, -2, -2, -1,
        1, -1, -1, 2, -1, -1,
        0, 0, -1,
        0, 1, -1,

        0, -4, 0,
        0, -3, 0,
        1, -2, 0, 2, -2, 0,
        -3, -1, 0, -2, -1, 0,
        -1, 0, 0,
        -1, 1, 0,

        0, -2, 1,
        -1, -1, 1,

        0, -2, 2,
        -1, -1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"HH (p12)"},
#endif
	{
        -2, -2, -1, -1, -2, -1, 0, -2, -1, 1, -2, -1,
        -2, 1, -1, -1, 1, -1, 0, 1, -1, 1, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -1, 1, 0, 0, 1, 0,

        -2, -2, 1, -1, -2, 1, 0, -2, 1, 1, -2, 1,
        -2, 1, 1, -1, 1, 1, 0, 1, 1, 1, 1, 1,
        127
	},
};

static char patterns_26S36B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (c/2, p4)"},
#endif
	{
        0, 2, 0,
        0, 3, 0,

        1, 2, 1,
        1, 3, 1,

        0, 0, 2,
        1, 1, 2,
        1, 2, 2,
        1, 3, 2,
        1, 4, 2,
        0, 5, 2,

        0, 0, 3,
        1, 1, 3,
        1, 2, 3,
        1, 3, 3,
        1, 4, 3,
        0, 5, 3,

        1, 2, 4,
        1, 3, 4,

        0, 2, 5,
        0, 3, 5,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"puffer (c/2, p4)"},
#endif
	{
        -1, -3, -2, 0, -3, -2,
        -2, -2, -2, -1, -2, -2, 0, -2, -2, 1, -2, -2,
        -2, -1, -2, -1, -1, -2, 0, -1, -2, 1, -1, -2,
        -1, 0, -2, 0, 0, -2,

        -1, -4, -1, 0, -4, -1,
        -3, -2, -1, 2, -2, -1,
        -3, -1, -1, 2, -1, -1,
        -1, 1, -1, 0, 1, -1,

        -2, -4, 1, -1, -4, 1, 0, -4, 1, 1, -4, 1,
        -3, -3, 1, 2, -3, 1,
        -3, -2, 1, 2, -2, 1,
        -3, -1, 1, 2, -1, 1,
        -3, 0, 1, 2, 0, 1,
        -2, 1, 1, -1, 1, 1, 0, 1, 1, 1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"puffer2 (c/2, p8)"},
#endif
	{
        -1, -2, -3, 0, -2, -3,
        -3, 0, -3, -1, 0, -3, 0, 0, -3, 2, 0, -3,

        -1, -3, -2, 0, -3, -2,

        -2, -3, -1, -1, -3, -1, 0, -3, -1, 1, -3, -1,
        -3, -2, -1, 2, -2, -1,
        -3, 0, -1, 2, 0, -1,

        -2, -3, 0, -1, -3, 0, 0, -3, 0, 1, -3, 0,
        -3, -2, 0, 2, -2, 0,
        -3, 0, 0, 2, 0, 0,

        -1, -3, 1, 0, -3, 1,

        -1, -2, 2, 0, -2, 2,
        -3, 0, 2, -1, 0, 2, 0, 0, 2, 2, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"puffer3 (c/2, p20)"},
#endif
	{
        -1, -3, -5, 0, -3, -5,
        -2, -2, -5, 1, -2, -5,
        -3, -1, -5, -1, -1, -5, 0, -1, -5, 2, -1, -5,
        -3, 0, -5, -1, 0, -5, 0, 0, -5, 2, 0, -5,
        -2, 1, -5, 1, 1, -5,
        -1, 2, -5, 0, 2, -5,

        -2, -3, -4, 1, -3, -4,
        -3, -2, -4, 2, -2, -4,
        -3, 1, -4, 2, 1, -4,
        -2, 2, -4, 1, 2, -4,

        -1, -1, 0, 0, -1, 0,
        -1, 0, 0, 0, 0, 0,

        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,

        -1, -1, 3, 0, -1, 3,
        -1, 0, 3, 0, 0, 3,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"C"},
#endif
	{
        0, -1, -1, 0, -1, 0,
        0, 0, -1,
        0, 1, -1, 0, 1, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"pulsing cross"},
#endif
	{
        0, -1, -2,

        -1, -2, -1, 1, -2, -1,
        0, -1, -1,

        0, -2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"toggler"},
#endif
	{
        -2, -2, -1,
        0, 0, -1,

        -1, -3, 0,
        -2, -2, 0, -1, -2, 0,
        0, -1, 0, 1, -1, 0,
        0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"drop em"},
#endif
	{
        -1, -2, -1,
        1, -1, -1,
        -2, 0, -1,
        0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"TT (p4)"},
#endif
	{
        -1, 0, 1,

        0, -1, -1,
        0, 0, -1,
        0, 1, -1,

        -0, -1, 1,
        0, 0, 1,
        0, 1, 1,

        1, 0, -1,
        127
	},
#ifdef LIFE_NAMES
	{"corner flip (p4)"},
#endif
	{
        0, -2, -2, 1, -2, -2,
        -1, -1, -2, 0, -1, -2,
        -2, 0, -2, -1, 0, -2,
        -2, 1, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1,
        -2, 0, -1,

        -2, -2, 0, -1, -2, 0,
        -2, -1, 0,

        -2, -2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"4T (p4)"},
#endif
	{
        0, -3, -2,
        -2, -2, -2,
        1, -1, -2,
        -1, 0, -2,

        0, -4, -1,
        0, -3, -1,
        -3, -2, -1, -2, -2, -1,
        1, -1, -1, 2, -1, -1,
        -1, 0, -1,
        -1, 1, -1,

        0, -3, 0,
        -2, -2, 0,
        1, -1, 0,
        -1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"tick tock (p4)"},
#endif
	{
        0, -2, -3,
        -1, -1, -3,

        -2, -2, -2, 1, -2, -2,
        -2, -1, -2, 1, -1, -2,

        -1, -3, -1, 0, -3, -1,
        -1, 0, -1, 0, 0, -1,

        -2, -2, 0, 1, -2, 0,
        -2, -1, 0, 1, -1, 0,

        -1, -2, 1,
        0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"arena (p4)"},
#endif
	{
        -2, -5, -1, -1, -5, -1, 0, -5, -1, 1, -5, -1,
        -5, -2, -1, 4, -2, -1,
        -5, -1, -1, 4, -1, -1,
        -5, 0, -1, 4, 0, -1,
        -5, 1, -1, 4, 1, -1,
        -2, 4, -1, -1, 4, -1, 0, 4, -1, 1, 4, -1,

        -3, -4, 0, -2, -4, 0, 1, -4, 0, 2, -4, 0,
        -4, -3, 0, -3, -3, 0, 2, -3, 0, 3, -3, 0,
        -4, -2, 0, 3, -2, 0,
        -4, 1, 0, 3, 1, 0,
        -4, 2, 0, -3, 2, 0, 2, 2, 0, 3, 2, 0,
        -3, 3, 0, -2, 3, 0, 1, 3, 0, 2, 3, 0,
        127
	},
#ifdef LIFE_NAMES
	{"group exercise (p4)"},
#endif
	{
        -1, -4, -2, 0, -4, -2,
        -4, -1, -2, 3, -1, -2,
        -4, 0, -2, 3, 0, -2,
        -1, 3, -2, 0, 3, -2,

        -1, -4, -1, 0, -4, -1,
        -4, -1, -1, 3, -1, -1,
        -4, 0, -1, 3, 0, -1,
        -1, 3, -1, 0, 3, -1,

        -1, -4, 0, 0, -4, 0,
        -2, -3, 0, 1, -3, 0,
        -3, -2, 0, 2, -2, 0,
        -4, -1, 0, 3, -1, 0,
        -4, 0, 0, 3, 0, 0,
        -3, 1, 0, 2, 1, 0,
        -2, 2, 0, 1, 2, 0,
        -1, 3, 0, 0, 3, 0,

        -1, -4, 1, 0, -4, 1,
        -4, -1, 1, 3, -1, 1,
        -4, 0, 1, 3, 0, 1,
        -1, 3, 1, 0, 3, 1,
        127
	},
#ifdef LIFE_NAMES
	{"deformed ball (p6)"},
#endif
	{
        -1, -2, -2,
        -2, -1, -2, -1, -1, -2,
        1, 0, -2,
        0, 1, -2,

        -2, -2, -1, -1, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -1, 1, -1,

        1, -2, 0,
        1, 0, 0,
        -2, 1, 0, 0, 1, 0,

        0, -2, 1,
        -1, -1, 1,
        -2, 0, 1, 0, 0, 1,
        127
	},
};

static char patterns_26S37B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (c/3, p3)"},
#endif
	{
        0, 2, 0,

        0, 1, 1, 1, 1, 1,
        0, 2, 1, 1, 2, 1,
        0, 3, 1, 1, 3, 1,

        0, 0, 2,
        0, 1, 2, 1, 1, 2,
        0, 3, 2, 1, 3, 2,
        0, 4, 2,

        0, 1, 3, 1, 1, 3,
        0, 2, 3, 1, 2, 3,
        0, 3, 3, 1, 3, 3,

        0, 2, 4,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"C"},
#endif
	{
        0, -1, -1, 0, -1, 0,
        0, 0, -1,
        0, 1, -1, 0, 1, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"pulsing cross"},
#endif
	{
        0, -1, -2,

        -1, -2, -1, 1, -2, -1,
        0, -1, -1,

        0, -2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"tri rotor"},
#endif
	{
        -1, -1, -2, 0, -1, -2,

        -2, -1, -1, 1, -1, -1,

        -1, -2, 0, 0, -2, 0,
        -1, 0, 0, 0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"toggler"},
#endif
	{
        -2, -2, -1,
        0, 0, -1,

        -1, -3, 0,
        -2, -2, 0, -1, -2, 0,
        0, -1, 0, 1, -1, 0,
        0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"drop em"},
#endif
	{
        -1, -2, -1,
        1, -1, -1,
        -2, 0, -1,
        0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"stretch"},
#endif
	{
        -1, -2, -2, 0, -2, -2,
        -2, -1, -2, -1, -1, -2, 0, -1, -2, 1, -1, -2,
        -2, 0, -2, -1, 0, -2, 0, 0, -2, 1, 0, -2,
        -1, 1, -2, 0, 1, -2,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, -1, -1, 0, 0, -1, 0, 1, -1, 0,
        -2, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"arena (p3)"},
#endif
	{
        -3, -4, -1, 2, -4, -1,
        -4, -3, -1, -2, -3, -1, 1, -3, -1, 3, -3, -1,
        -3, -2, -1, -2, -2, -1, 1, -2, -1, 2, -2, -1,
        -3, 1, -1, -2, 1, -1, 1, 1, -1, 2, 1, -1,
        -4, 2, -1, -2, 2, -1, 1, 2, -1, 3, 2, -1,
        -3, 3, -1, 2, 3, -1,

        -2, -4, 0, -1, -4, 0, 0, -4, 0, 1, -4, 0,
        -4, -2, 0, 3, -2, 0,
        -4, -1, 0, 3, -1, 0,
        -4, 0, 0, 3, 0, 0,
        -4, 1, 0, 3, 1, 0,
        -2, 3, 0, -1, 3, 0, 0, 3, 0, 1, 3, 0,
        127
	},
#ifdef LIFE_NAMES
	{"TT (p4)"},
#endif
	{
        -1, 0, 1,

        0, -1, -1,
        0, 0, -1,
        0, 1, -1,

        -0, -1, 1,
        0, 0, 1,
        0, 1, 1,

        1, 0, -1,
        127
	},
#ifdef LIFE_NAMES
	{"capture (p4)"},
#endif
	{
        0, -1, -1,
        1, 0, -1,

        1, 0, 0,
        0, -1, 0,

        -1, -2, 1, 0, -2, 1,
        -1, -1, 1,
        2, 0, 1,
        1, 1, 1, 2, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"4T (p4)"},
#endif
	{
        0, -3, -2,
        -2, -2, -2,
        1, -1, -2,
        -1, 0, -2,

        0, -4, -1,
        0, -3, -1,
        -3, -2, -1, -2, -2, -1,
        1, -1, -1, 2, -1, -1,
        -1, 0, -1,
        -1, 1, -1,

        0, -3, 0,
        -2, -2, 0,
        1, -1, 0,
        -1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"arena (p4)"},
#endif
	{
        -2, -5, -1, -1, -5, -1, 0, -5, -1, 1, -5, -1,
        -5, -2, -1, 4, -2, -1,
        -5, -1, -1, 4, -1, -1,
        -5, 0, -1, 4, 0, -1,
        -5, 1, -1, 4, 1, -1,
        -2, 4, -1, -1, 4, -1, 0, 4, -1, 1, 4, -1,

        -3, -4, 0, -2, -4, 0, 1, -4, 0, 2, -4, 0,
        -4, -3, 0, -3, -3, 0, 2, -3, 0, 3, -3, 0,
        -4, -2, 0, 3, -2, 0,
        -4, 1, 0, 3, 1, 0,
        -4, 2, 0, -3, 2, 0, 2, 2, 0, 3, 2, 0,
        -3, 3, 0, -2, 3, 0, 1, 3, 0, 2, 3, 0,
        127
	},
#ifdef LIFE_NAMES
	{"xbox (p6)"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 1, 0, -1,
        0, 1, -1,

        0, -2, 0,
        -2, 0, 0, 0, 0, 0, 2, 0, 0,
        0, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"centaur (p6)"},
#endif
	{
        0, -2, -1,
        1, -1, -1,
        -2, 0, -1,
        -1, 1, -1,

        -2, -1, 0, -1, -1, 0,
        0, -1, 0,
        -1, 0, 0, 0, 0, 0, 1, 0, 0,

        0, -2, 1,
        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"uu (p10)"},
#endif
	{
        -2, -1, -1,
        0, 1, -1,

        -2, -2, 0, -1, -2, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 1, 1, 0,

        -2, -1, 1,
        0, 1, 1,
        127
	},
};

static char patterns_26S38B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider diagonal (p2)"},
#endif
	{
        1, 0, 2, 2, 0, 2,
        1, 1, 2, 2, 1, 2,
        0, 2, 2, 1, 2, 2, 2, 2, 2, 3, 2, 2,

        1, 1, 3, 2, 1, 3,
        1, 2, 3, 2, 2, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"glider diagonal with tail (p2)"},
#endif
	{
        1, 0, 0, 2, 0, 0,

        0, 0, 1, 3, 0, 1,

        1, 0, 2, 2, 0, 2,
        1, 1, 2, 2, 1, 2,
        0, 2, 2, 1, 2, 2, 2, 2, 2, 3, 2, 2,

        1, 1, 3, 2, 1, 3,
        1, 2, 3, 2, 2, 3,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"double glider (diagonal p4)"},
#endif
	{
        -1, 0, -2, 0, 0, -2,
        -2, 1, -2, -1, 1, -2, 0, 1, -2, 1, 1, -2,

        -1, 0, -1, 0, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -1, -1, 0, 0, -1, 0,
        -1, 1, 0, 0, 1, 0,
        -2, 2, 0, 1, 2, 0,

        -2, -2, 1, -1, -2, 1, 0, -2, 1, 1, -2, 1,
        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,

        -2, 0, 2, 1, 0, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"C"},
#endif
	{
        0, -1, -1, 0, -1, 0,
        0, 0, -1,
        0, 1, -1, 0, 1, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"pulsing cross"},
#endif
	{
        0, -1, -2,

        -1, -2, -1, 1, -2, -1,
        0, -1, -1,

        0, -2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"tri rotor"},
#endif
	{
        -1, -1, -2, 0, -1, -2,

        -2, -1, -1, 1, -1, -1,

        -1, -2, 0, 0, -2, 0,
        -1, 0, 0, 0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"toggler"},
#endif
	{
        -2, -2, -1,
        0, 0, -1,

        -1, -3, 0,
        -2, -2, 0, -1, -2, 0,
        0, -1, 0, 1, -1, 0,
        0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"drop em"},
#endif
	{
        -1, -2, -1,
        1, -1, -1,
        -2, 0, -1,
        0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"arena (p3)"},
#endif
	{
        -3, -4, -1, 2, -4, -1,
        -4, -3, -1, -2, -3, -1, 1, -3, -1, 3, -3, -1,
        -3, -2, -1, -2, -2, -1, 1, -2, -1, 2, -2, -1,
        -3, 1, -1, -2, 1, -1, 1, 1, -1, 2, 1, -1,
        -4, 2, -1, -2, 2, -1, 1, 2, -1, 3, 2, -1,
        -3, 3, -1, 2, 3, -1,

        -2, -4, 0, -1, -4, 0, 0, -4, 0, 1, -4, 0,
        -4, -2, 0, 3, -2, 0,
        -4, -1, 0, 3, -1, 0,
        -4, 0, 0, 3, 0, 0,
        -4, 1, 0, 3, 1, 0,
        -2, 3, 0, -1, 3, 0, 0, 3, 0, 1, 3, 0,
        127
	},
#ifdef LIFE_NAMES
	{"TT (p4)"},
#endif
	{
        -1, 0, 1,

        0, -1, -1,
        0, 0, -1,
        0, 1, -1,

        -0, -1, 1,
        0, 0, 1,
        0, 1, 1,

        1, 0, -1,
        127
	},
#ifdef LIFE_NAMES
	{"tornado (p4)"},
#endif
	{
        -1, -3, -1,
        0, -2, -1, 2, -2, -1,
        -1, -1, -1, 1, -1, -1,
        -2, 0, -1, 0, 0, -1,
        1, 1, -1,

        -1, -2, 0, 0, -2, 0, 1, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 0, 0, 0, 1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"4T (p4)"},
#endif
	{
        0, -3, -2,
        -2, -2, -2,
        1, -1, -2,
        -1, 0, -2,

        0, -4, -1,
        0, -3, -1,
        -3, -2, -1, -2, -2, -1,
        1, -1, -1, 2, -1, -1,
        -1, 0, -1,
        -1, 1, -1,

        0, -3, 0,
        -2, -2, 0,
        1, -1, 0,
        -1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"invert (p4)"},
#endif
	{
        -2, -2, -2, 1, -2, -2,
        -2, 1, -2, 1, 1, -2,

        -1, -3, 0, 0, -3, 0,
        -3, -1, 0, -1, -1, 0, 0, -1, 0, 2, -1, 0,
        -3, 0, 0, -1, 0, 0, 0, 0, 0, 2, 0, 0,
        -1, 2, 0, 0, 2, 0,

        -1, -2, 1, 0, -2, 1,
        -2, -1, 1, 1, -1, 1,
        -2, 0, 1, 1, 0, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"arena (p4)"},
#endif
	{
        -2, -5, -1, -1, -5, -1, 0, -5, -1, 1, -5, -1,
        -5, -2, -1, 4, -2, -1,
        -5, -1, -1, 4, -1, -1,
        -5, 0, -1, 4, 0, -1,
        -5, 1, -1, 4, 1, -1,
        -2, 4, -1, -1, 4, -1, 0, 4, -1, 1, 4, -1,

        -3, -4, 0, -2, -4, 0, 1, -4, 0, 2, -4, 0,
        -4, -3, 0, -3, -3, 0, 2, -3, 0, 3, -3, 0,
        -4, -2, 0, 3, -2, 0,
        -4, 1, 0, 3, 1, 0,
        -4, 2, 0, -3, 2, 0, 2, 2, 0, 3, 2, 0,
        -3, 3, 0, -2, 3, 0, 1, 3, 0, 2, 3, 0,
        127
	},
};

static char patterns_26S4B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (c/2, p4)"},
#endif
	{
        0, 0, 0,
        1, 1, 0,
        1, 2, 0,
        0, 3, 0,

        1, 1, 1,
        1, 2, 1,

        1, 0, 2,
        1, 1, 2,
        1, 2, 2,
        1, 3, 2,

        1, 0, 3,
        1, 1, 3,
        1, 2, 3,
        1, 3, 3,

        1, 1, 4,
        1, 2, 4,

        0, 0, 5,
        1, 1, 5,
        1, 2, 5,
        0, 3, 5,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"pinwheel (p4)"},
#endif
	{
        -1, 1, -1, 0, 1, -1,

        -1, -1, 0, 0, -1, 0,
        -2, 0, 0, 1, 0, 0,

        -1, 0, 1, 0, 0, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"bronco (p4)"},
#endif
	{
        0, -1, -1,
        0, 0, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"gate (p4)"},
#endif
	{
        0, -2, -2,
        -1, -1, -2, 0, -1, -2,

        0, -3, -1, 1, -3, -1,
        -2, -1, -1,
        -2, 0, -1,

        0, -3, 0, 1, -3, 0,
        -2, -1, 0,
        -2, 0, 0,

        0, -2, 1,
        -1, -1, 1, 0, -1, 1,
        127
	},
};

static char patterns_26S45B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider diagonal p4"},
#endif
	{
        0, 0, 0, 0, 1, 0,
        1, 2, 0,
        2, 2, 0,
        3, 0, 0, 3, 1, 0,

        1, 0, 1, 1, 1, 1,
        2, 0, 1, 2, 1, 1,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"linked glider (diag p4)"},
#endif
	{
        -1, 0, -3, -1, 0, -2, -1, 0, 1, -1, 0, 2,

        0, -1, -3, 0, -1, -2, 0, -1, 1, 0, -1, 2,
        0, 0, -4, 0, 0, -1, 0, 0, 0, 0, 0, 3,

        1, -1, -3, 1, -1, -2, 1, -1, 1, 1, -1, 2,
        1, 0, -4, 1, 0, 3,
        1, 1, -1, 1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"crab glider (diag p7)"},
#endif
	{
        0, 0, -2, 1, 0, -2,
        0, 1, -2,

        1, -2, -1,
        2, -1, -1,
        2, 0, -1,
        -2, 1, -1,
        -1, 2, -1, 0, 2, -1,

        0, -1, 0, 2, -1, 0,
        -1, 0, 0, 0, 0, 0, 2, 0, 0,
        -1, 2, 0, 0, 2, 0,

        1, -1, 1,
        1, 0, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"glider 3 (24 cell, c/2, p4)"},
#endif
	{
        0, -1, -2,
        -2, 0, -2,
        0, 1, -2,

        0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        -2, 1, -1, 1, 1, -1,
        0, 2, -1,

        1, -1, 0,
        1, 1, 0,

        0, -2, 1,
        -2, -1, 1, 1, -1, 1,
        -2, 0, 1, 1, 0, 1,
        -2, 1, 1, 1, 1, 1,
        0, 2, 1,

        0, -1, 2,
        -2, 0, 2,
        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"zepplin (asym 24 cell, c/2, p2)"},
#endif
	{
        -2, -3, -2,
        2, -2, -2,
        -3, 1, -2,
        1, 2, -2,

        1, -3, -1,
        -3, -2, -1,
        2, 1, -1,
        -2, 2, -1,

        -1, -3, 0, 0, -3, 0,
        -2, -2, 0, 0, -2, 0, 1, -2, 0,
        -3, -1, 0, -2, -1, 0, 2, -1, 0,
        -3, 0, 0, 1, 0, 0, 2, 0, 0,
        -2, 1, 0, -1, 1, 0, 1, 1, 0,
        -1, 2, 0, 0, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"glider 4 (28 cell, c/2, p2)"},
#endif
	{
        -2, -2, -2,
        -2, -1, -2, 0, -1, -2,
        -2, 1, -2, 0, 1, -2,
        -2, 2, -2,

        -2, -2, -1, 0, -2, -1,
        1, -1, -1,
        1, 0, -1,
        1, 1, -1,
        -2, 2, -1, 0, 2, -1,

        1, -1, 0,
        1, 1, 0,

        -2, -2, 1, 0, -2, 1,
        1, -1, 1,
        1, 0, 1,
        1, 1, 1,
        -2, 2, 1, 0, 2, 1,

        -2, -2, 2,
        -2, -1, 2, 0, -1, 2,
        -2, 1, 2, 0, 1, 2,
        -2, 2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"blinker"},
#endif
	{
        0, 0, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        -1, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"double blinker"},
#endif
	{
        0, -1, -1,
        0, 1, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        -1, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"deformed double blinker"},
#endif
	{
        0, 0, -1,
        0, 1, -1,

        0, -1, 0, 1, -1, 0,
        -1, 0, 0,
        1, 1, 0,

        0, 0, 1,
        0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"rotor"},
#endif
	{
        0, -1, -1,
        0, 0, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        0, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"gate"},
#endif
	{
        -2, -1, -1, -1, -1, -1, 0, -1, -1,
        -2, 0, -1, -1, 0, -1,

        1, 0, 1, 2, 0, 1,
        0, 1, 1, 1, 1, 1, 2, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"triple blinker 1"},
#endif
	{
        -1, -1, -2,
        -1, 0, -2,

        -2, -1, -1,
        1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, 0, 0,

        0, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"triple blinker 2"},
#endif
	{
        -1, -1, -2, 0, -1, -2,

        0, -2, -1,
        1, -1, -1,
        1, 0, -1,
        -1, 1, -1,

        0, -2, 0,
        -2, -1, 0,
        -2, 0, 0,
        -1, 1, 0,

        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"three halves blinker"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 1, 0, -1,

        -1, -1, 0,
        1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        0, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"seesaw"},
#endif
	{
        0, 0, -2,

        -2, -1, -1, -1, -1, -1,
        -2, 0, -1,
        0, 1, -1,

        -1, -1, 0,
        1, 0, 0,
        0, 1, 0, 1, 1, 0,

        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"tripump"},
#endif
	{
        0, -2, -2,
        -2, -1, -2, -1, -1, -2, 0, -1, -2,

        0, -2, -1,
        -2, 0, -1,
        -2, 1, -1, -1, 1, -1,

        1, -2, 0,
        1, -1, 0,
        1, 0, 0,
        -1, 1, 0,

        0, 0, 1, 1, 0, 1,
        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"windshieldwiper (helicopter)"},
#endif
	{
        -2, -1, -2, -1, -1, -2,
        0, 0, -2,

        -1, -2, -1,
        -2, -1, -1,
        1, 0, -1,
        -1, 1, -1, 0, 1, -1, 1, 1, -1,

        0, -2, 0,
        -2, -1, 0, 1, -1, 0,

        0, -2, 1,
        0, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"blink junk"},
#endif
	{
        0, -1, -1,
        -2, 0, -1, -1, 0, -1,

        0, -2, 0,
        1, -1, 0,
        -2, 0, 0,
        -1, 1, 0,

        0, -2, 1,
        1, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"beacon"},
#endif
	{
        -1, -2, -1, 0, -2, -1,
        -1, -1, -1,
        0, 0, -1,

        -1, -2, 0, 0, -2, 0,
        0, 1, 0, 1, 1, 0,

        0, -1, 1,
        1, 0, 1,
        0, 1, 1, 1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"opening box"},
#endif
	{
        0, -1, -2,
        -1, 0, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"ball"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2, 0, 0, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"shower (p3)"},
#endif
	{
        -1, -2, -3,
        -2, -1, -3, 0, -1, -3,
        -1, 0, -3,

        -1, -2, -2,
        -2, -1, -2,
        1, 0, -2,
        0, 1, -2,

        1, 0, -1,
        0, 1, -1,

        1, -1, 0,
        -1, 1, 0,

        0, -1, 1,
        -1, 0, 1, 1, 0, 1,
        0, 1, 1,

        1, 0, 2,
        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"blob with stabilizers (p3)"},
#endif
	{
        -1, -1, -3, 3, -1, -3,
        2, 0, -3, 3, 0, -3,

        0, -1, -2, 1, -1, -2, 3, -1, -2,
        -1, 0, -2, 3, 0, -2,

        -1, -3, -1,
        0, -2, -1,
        -3, -1, -1, 1, -1, -1,
        -2, 0, -1,
        -2, 1, -1, -1, 1, -1,
        -3, 3, -1, -2, 3, -1,

        -1, -2, 0,
        -2, -1, 0,
        -3, 2, 0,
        -3, 3, 0, -2, 3, 0,

        -1, -2, 1,
        -1, -1, 1,

        0, -3, 2,

        -1, -3, 3, 0, -3, 3,
        -1, -2, 3, 0, -2, 3,
        127
	},
#ifdef LIFE_NAMES
	{"blob with stabilizers (variant) (p3)"},
#endif
	{
        -1, 2, -3,
        -1, 3, -3, 0, 3, -3,

        0, 0, -2,
        0, 1, -2,
        -1, 3, -2, 0, 3, -2,

        2, -3, -1, 3, -3, -1,
        3, -2, -1,
        1, 0, -1,
        0, 1, -1,

        3, -3, 0,
        0, -2, 0, 1, -2, 0, 3, -2, 0,
        1, -1, 0,
        -2, 0, 0, 2, 0, 0,
        -1, 1, 0,
        0, 2, 0,

        0, -1, 1,
        -2, 0, 1, -1, 0, 1,

        -3, -1, 2,
        0, 0, 2,

        -3, -1, 3, -2, -1, 3,
        -3, 0, 3, -2, 0, 3,
        127
	},
#ifdef LIFE_NAMES
	{"cheshire (p3)"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
        -2, 0, -1, 1, 0, -1,
        -1, 2, -1, 0, 2, -1,

        -1, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 1, 0, 1, 1, 0,

        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,
        -1, 2, 1, 0, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"puffer (p4)"},
#endif
	{
        0, -1, -1,
        0, 0, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"arrow (p4)"},
#endif
	{
        0, -1, -1,
        0, 0, -1,

        0, -2, 0,
        1, -1, 0,
        1, 0, 0,
        0, 1, 0,

        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"heart (p4)"},
#endif
	{
        -1, -1, -1,
        -1, 0, -1, 0, 0, -1,

        0, -1, 0,
        -2, 0, 0, 1, 0, 0,

        -1, -1, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"pinwheel (p4)"},
#endif
	{
        -1, 1, -1, 0, 1, -1,

        -1, -1, 0, 0, -1, 0,
        -2, 0, 0, 1, 0, 0,

        -1, 0, 1, 0, 0, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"bronco (p4)"},
#endif
	{
        0, -1, -1,
        0, 0, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"dancing beacon2 (p4)"},
#endif
	{
        0, -2, -2, 1, -2, -2,
        0, -1, -2, 1, -1, -2,

        1, -2, -1,

        0, -1, 0,
        -2, 0, 0, 0, 0, 0,
        -2, 1, 0,

        -2, 0, 1,
        -2, 1, 1, -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"shift rotate (p4)"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2, 0, 0, -2,

        -1, -2, -1,
        1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        -1, 1, -1,

        -1, -2, 0,
        -2, -1, 0,
        0, 0, 0,

        -1, -1, 1, 0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"waltzer (p6)"},
#endif
	{
        -1, -1, -1,
        -2, 0, -1,

        -1, -1, 0, 0, -1, 0,
        -2, 0, 0,
        1, 1, 0,

        -1, 0, 1, 1, 0, 1,
        0, 1, 1, 1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"big waltzer (p6)"},
#endif
	{
        0, -1, -1, 1, -1, -1,
        -1, 0, -1, 0, 0, -1,
        -1, 1, -1,

        0, -2, 0, 1, -2, 0,
        -2, 0, 0,
        -2, 1, 0,

        0, -1, 1, 1, -1, 1,
        -1, 0, 1, 0, 0, 1,
        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"123243 (p6)"},
#endif
	{
        -1, -1, -1, -1, -1, 0,
        -1, 1, -1, -1, 1, 0,

        0, -2, -1, 0, -2, 0,
        0, -1, -2, 0, -1, 1,
        0, 1, -2, 0, 1, 1,
        0, 2, -1, 0, 2, 0,

        1, 0, -1, 1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"dancing beacon (p6)"},
#endif
	{
        -2, -2, -2, -1, -2, -2,
        -2, -1, -2, -1, -1, -2,

        -2, -2, -1, 0, -1, -1,

        1, 0, 0,
        0, 1, 0, 1, 1, 0,

        1, 0, 1,
        0, 1, 1, 1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"big pinwheel (p6)"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        0, 1, -2, 1, 1, -2,

        1, -1, -1,
        -1, 0, -1, 1, 0, -1,
        -1, 1, -1,

        1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -1, 1, 0,

        -1, -1, 1, 0, -1, 1,
        0, 1, 1, 1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"diablo (p6)"},
#endif
	{
        0, -2, -3,
        -2, 0, -3,

        0, -3, -2,
        0, -1, -2,
        -3, 0, -2, -1, 0, -2,

        0, -2, -1,
        0, -1, -1,
        -2, 0, -1, -1, 0, -1,

        -2, -3, 0,
        -3, -2, 0, -1, -2, 0,
        -2, -1, 0, -1, -1, 0,
        1, 1, 0, 2, 1, 0,
        1, 2, 0, 3, 2, 0,
        2, 3, 0,

        1, 0, 1, 2, 0, 1,
        0, 1, 1,
        0, 2, 1,

        1, 0, 2, 3, 0, 2,
        0, 1, 2,
        0, 3, 2,

        2, 0, 3,
        0, 2, 3,
        127
	},
#ifdef LIFE_NAMES
	{"pulsar 10 (p10)"},
#endif
	{
        1, -1, -2,
        -1, 0, -2, 1, 0, -2,
        -1, 1, -2,
        0, 1, -2,

        0, -2, -1, 1, -2, -1,
        -2, 1, -1, 0, 1, -1,

        1, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 1, 0,

        -1, -2, 1, 0, -2, 1,
        -2, -1, 1,
        -2, 0, 1, -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"Lq (p16)"},
#endif
	{
        -1, 1, -1, 0, 1, -1,
        -1, 2, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -2, 1, 0, 0, 1, 0,
        -1, 2, 0,

        0, -2, 1,
        -1, -1, 1, 0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"4 cups (p16)"},
#endif
	{
        -1, -2, -4, 0, -2, -4,
        -1, 1, -4, 0, 1, -4,

        -2, -2, -3, 1, -2, -3,
        -3, -1, -3, -2, -1, -3, -1, -1, -3,
        0, -1, -3, 1, -1, -3, 2, -1, -3,
        -3, 0, -3, -2, 0, -3, -1, 0, -3,
        0, 0, -3, 1, 0, -3, 2, 0, -3,
        -2, 1, -3, 1, 1, -3,

        -2, -2, 2, 1, -2, 2,
        -3, -1, 2, -2, -1, 2, -1, -1, 2,
        0, -1, 2, 1, -1, 2, 2, -1, 2,
        -3, 0, 2, -2, 0, 2, -1, 0, 2,
        0, 0, 2, 1, 0, 2, 2, 0, 2,
        -2, 1, 2, 1, 1, 2,

        -1, -2, 3, 0, -2, 3,
        -1, 1, 3, 0, 1, 3,
        127
	},
#ifdef LIFE_NAMES
	{"pulsar 20 (p20)"},
#endif
	{
        1, 0, -2,

        0, -1, -1, 1, -1, -1,
        0, 0, -1, 2, 0, -1,
        1, 1, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        -1, -2, 1,
        -2, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,

        -1, -1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"collision -> redirection"},
#endif
	{
        -2, 3, -7, -1, 3, -7,
        -3, 4, -7, 0, 4, -7,
        -3, 5, -7, 0, 5, -7,

        -2, 4, -6, -1, 4, -6,
        -2, 5, -6, -1, 5, -6,

        1, -2, 1,

        1, -3, 2,
        0, -2, 2, 2, -2, 2,
        1, -1, 2,

        0, -2, 3, 2, -2, 3,
        127
	},
#ifdef LIFE_NAMES
	{"collision -> seesaw"},
#endif
	{
        -4, -6, -7, -1, -6, -7,
        -4, -5, -7, -1, -5, -7,
        -3, -4, -7, -2, -4, -7,

        -3, -6, -6, -2, -6, -6,
        -3, -5, -6, -2, -5, -6,

        1, 4, 6, 2, 4, 6,
        0, 5, 6, 3, 5, 6,
        0, 6, 6, 3, 6, 6,

        1, 5, 5, 2, 5, 5,
        1, 6, 5, 2, 6, 5,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"V (stable)"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
        -1, 0, -1, 0, 0, -1,

        -1, -1, 0, 0, -1, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"step (stable)"},
#endif
	{
        -1, -1, -1,
        -1, 0, -1, 0, 0, -1,

        -1, -1, 0, 0, -1, 0,
        0, 0, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"cross (stable)"},
#endif
	{
        0, 0, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        0, 0, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"pillar (stable)"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 1, 0, -1,
        0, 1, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,
        127
	},
#endif
};

static char patterns_26S47B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider orthogonal (p5)"},
#endif
	{
        0, 0, 0,
        0, 2, 0, 1, 2, 0,
        0, 4, 0,

        1, 1, 1,
        1, 2, 1,
        1, 3, 1,

        0, 0, 2, 1, 0, 2,
        1, 1, 2,
        1, 3, 2,
        0, 4, 2, 1, 4, 2,

        1, 1, 3,
        1, 2, 3,
        1, 3, 3,

        0, 0, 4,
        0, 2, 4, 1, 2, 4,
        0, 4, 4,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"glider orthogonal (p8)"},
#endif
	{
        -1, -2, -2, 0, -2, -2,
        -2, -1, -2, -1, -1, -2, 0, -1, -2, 1, -1, -2,
        -2, 0, -2, -1, 0, -2, 0, 0, -2, 1, 0, -2,
        -1, 1, -2, 0, 1, -2,

        -2, -2, 0, 1, -2, 0,
        -2, 1, 0, 1, 1, 0,

        -2, -2, 1, 1, -2, 1,
        -4, -1, 1, 3, -1, 1,
        -4, 0, 1, 3, 0, 1,
        -2, 1, 1, 1, 1, 1,

        -1, -3, 2, 0, -3, 2,
        -2, -2, 2, -1, -2, 2, 0, -2, 2, 1, -2, 2,
        -3, -1, 2, 2, -1, 2,
        -3, 0, 2, 2, 0, 2,
        -2, 1, 2, -1, 1, 2, 0, 1, 2, 1, 1, 2,
        -1, 2, 2, 0, 2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"rotor"},
#endif
	{
        0, -1, -1,
        0, 0, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        0, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"corner"},
#endif
	{
        0, 0, -2,

        0, -1, -1,
        -1, 0, -1,
        1, 1, -1,

        0, -2, 0,
        -1, -1, 0,
        -2, 0, 0, 2, 0, 0,
        1, 1, 0,
        0, 2, 0,

        1, -1, 1,
        1, 0, 1,
        -1, 1, 1, 0, 1, 1,

        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"bracelet"},
#endif
	{
        1, 0, -3,
        0, 1, -3, 1, 1, -3,

        2, -1, -2,
        2, 1, -2,
        -1, 2, -2, 1, 2, -2,

        2, -2, -1,
        3, -1, -1,
        3, 0, -1,
        -2, 2, -1,
        -1, 3, -1, 0, 3, -1,

        1, -3, 0,
        3, -1, 0,
        -3, 1, 0,
        -1, 3, 0,

        0, -3, 1, 1, -3, 1,
        2, -2, 1,
        -3, 0, 1,
        -3, 1, 1,
        -2, 2, 1,

        -1, -2, 2, 1, -2, 2,
        -2, -1, 2,
        -2, 1, 2,

        -1, -1, 3, 0, -1, 3,
        -1, 0, 3,
        127
	},
#ifdef LIFE_NAMES
	{"hex L"},
#endif
	{
        1, -1, -4,
        1, 0, -4,
        -1, 1, -4, 0, 1, -4, 1, 1, -4,


        3, -2, -2,
        3, -1, -2,
        3, 0, -2,
        -2, 3, -2, -1, 3, -2, 0, 3, -2,

        1, -4, -1,
        3, -2, -1,
        -4, 1, -1,
        -2, 3, -1,

        1, -4, 0,
        3, -2, 0,
        -4, 1, 0,
        -2, 3, 0,

        -1, -4, 1, 0, -4, 1, 1, -4, 1,
        -4, -1, 1,
        -4, 0, 1,
        -4, 1, 1,


        -2, -2, 3, -1, -2, 3, 0, -2, 3,
        -2, -1, 3,
        -2, 0, 3,
        127
	},
#ifdef LIFE_NAMES
	{"hex square"},
#endif
	{
        0, 3, -4, 1, 3, -4,

        3, -1, -3, 4, -1, -3,
        3, 0, -3, 4, 0, -3,
        2, 1, -3,
        0, 3, -3, 1, 3, -3,

        -1, 3, -2,

        3, -2, -1,
        -3, 3, -1,
        -3, 4, -1,

        3, -4, 0,
        3, -3, 0,
        -3, 3, 0,
        -3, 4, 0,

        3, -4, 1,
        3, -3, 1,
        -3, 2, 1,

        1, -3, 2,

        -1, -3, 3, 0, -3, 3,
        -2, -1, 3,
        -4, 0, 3, -3, 0, 3,
        -4, 1, 3, -3, 1, 3,

        -1, -3, 4, 0, -3, 4,
        127
	},
#ifdef LIFE_NAMES
	{"hex blocks"},
#endif
	{
        0, 0, -3, 1, 0, -3,
        0, 1, -3, 1, 1, -3,

        0, 0, -2,

        3, -1, -1,
        3, 0, -1,
        -1, 3, -1, 0, 3, -1,

        0, -3, 0, 1, -3, 0,
        0, -2, 0,
        3, -1, 0,
        -3, 0, 0, -2, 0, 0, 2, 0, 0, 3, 0, 0,
        -3, 1, 0,
        0, 2, 0,
        -1, 3, 0, 0, 3, 0,

        0, -3, 1, 1, -3, 1,
        -3, 0, 1,
        -3, 1, 1,

        0, 0, 2,

        -1, -1, 3, 0, -1, 3,
        -1, 0, 3, 0, 0, 3,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"ball flicker"},
#endif
	{
        0, -2, -3,
        -2, -1, -3,
        1, 0, -3,
        -1, 1, -3,

        -1, -3, -2,
        0, -2, -2,
        -1, -1, -2, 1, -1, -2, 2, -1, -2,
        -3, 0, -2, -2, 0, -2, 0, 0, -2,
        -1, 1, -2,
        0, 2, -2,

        1, -3, -1,
        -3, -2, -1, -1, -2, -1, 1, -2, -1,
        -2, -1, -1,
        1, 0, -1,
        -2, 1, -1, 0, 1, -1, 2, 1, -1,
        -2, 2, -1,

        -2, -3, 0,
        -2, -2, 0, 0, -2, 0, 2, -2, 0,
        1, -1, 0,
        -2, 0, 0,
        -3, 1, 0, -1, 1, 0, 1, 1, 0,
        1, 2, 0,

        0, -3, 1,
        -1, -2, 1,
        -3, -1, 1, -2, -1, 1, 0, -1, 1,
        -1, 0, 1, 1, 0, 1, 2, 0, 1,
        0, 1, 1,
        -1, 2, 1,

        -1, -2, 2,
        1, -1, 2,
        -2, 0, 2,
        0, 1, 2,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"paddles (p3)"},
#endif
	{
        -1, -1, -2, 2, -1, -2,
        -3, 0, -2, 0, 0, -2,

        2, -2, -1, 0, -2, -1,
        -2, -1, -1,
        1, 0, -1,
        -3, 1, -1, -1, 1, -1,

        0, -2, 0, 2, -2, 0,
        -2, -1, 0,
        1, 0, 0,
        -3, 1, 0, -1, 1, 0,

        2, -1, 1, -1, -1, 1,
        -3, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"pinwheel (p4)"},
#endif
	{
        -1, 1, -1, 0, 1, -1,

        -1, -1, 0, 0, -1, 0,
        -2, 0, 0, 1, 0, 0,

        -1, 0, 1, 0, 0, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"bronco (p4)"},
#endif
	{
        0, -1, -1,
        0, 0, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"gate (p4)"},
#endif
	{
        0, -2, -2,
        -1, -1, -2, 0, -1, -2,

        0, -3, -1, 1, -3, -1,
        -2, -1, -1,
        -2, 0, -1,

        0, -3, 0, 1, -3, 0,
        -2, -1, 0,
        -2, 0, 0,

        0, -2, 1,
        -1, -1, 1, 0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"T-Ball (p4)"},
#endif
	{
        -1, -2, -2, 1, -2, -2,
        -2, -1, -2, 0, -1, -2, 2, -1, -2,
        -2, 1, -2, 0, 1, -2, 2, 1, -2,
        -1, 2, -2, 1, 2, -2,

        -2, -2, -1, 2, -2, -1,
        -2, 0, -1, 2, 0, -1,
        -2, 2, -1, 2, 2, -1,

        -1, -2, 0, 1, -2, 0,
        -1, 2, 0, 1, 2, 0,

        -2, -2, 1, 2, -2, 1,
        -2, 0, 1, 2, 0, 1,
        -2, 2, 1, 2, 2, 1,

        -1, -2, 2, 1, -2, 2,
        -2, -1, 2, 0, -1, 2, 2, -1, 2,
        -2, 1, 2, 0, 1, 2, 2, 1, 2,
        -1, 2, 2, 1, 2, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"wavy ball (p4)"},
#endif
	{
        0, -2, -3,
        0, -1, -3,
        -2, 0, -3, -1, 0, -3, 1, 0, -3, 2, 0, -3,
        0, 1, -3,
        0, 2, -3,

        0, -3, -2,
        -1, -2, -2,
        -2, -1, -2,
        -3, 0, -2, 3, 0, -2,
        2, 1, -2,
        1, 2, -2,
        0, 3, -2,

        0, -3, -1,
        -2, -2, -1,
        -3, 0, -1, 3, 0, -1,
        2, 2, -1,
        0, 3, -1,

        -2, -3, 0, -1, -3, 0, 1, -3, 0, 2, -3, 0,
        -3, -2, 0, 3, -2, 0,
        -3, -1, 0, 3, -1, 0,
        -3, 1, 0, 3, 1, 0,
        -3, 2, 0, 3, 2, 0,
        -2, 3, 0, -1, 3, 0, 1, 3, 0, 2, 3, 0,

        0, -3, 1,
        2, -2, 1,
        -3, 0, 1, 3, 0, 1,
        -2, 2, 1,
        0, 3, 1,

        0, -3, 2,
        1, -2, 2,
        2, -1, 2,
        -3, 0, 2, 3, 0, 2,
        -2, 1, 2,
        -1, 2, 2,
        0, 3, 2,

        0, -2, 3,
        0, -1, 3,
        -2, 0, 3, -1, 0, 3, 1, 0, 3, 2, 0, 3,
        0, 1, 3,
        0, 2, 3,
        127
	},
#endif
};

static char patterns_26S56B5[][3 * NUMPTS + 1] =
{
#ifdef LIFE_NAMES
	{"glider 1 (18 cell, c/2, p2)"},
#endif
	{
        -1, -2, -1, 0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 1, -1, 1, 1, -1,
        -1, 2, -1, 0, 2, -1,

        -1, -2, 0, 0, -2, 0,
        -1, -1, 0, 0, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,
        -1, 2, 0, 0, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"glider 2 (32 cell, 3c/4, p4)"},
#endif
	{
        -1, -2, -3,
        1, -1, -3,
        1, 0, -3,
        -1, 1, -3,

        -1, -3, -2,
        -2, -1, -2,
        -2, 0, -2,
        -1, 2, -2,

        1, -3, -1,
        -2, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        -2, 1, -1,
        1, 2, -1,

        1, -3, 0,
        -2, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -2, 1, 0,
        1, 2, 0,

        -1, -3, 1,
        -2, -1, 1,
        -2, 0, 1,
        -1, 2, 1,

        -1, -2, 2,
        1, -1, 2,
        1, 0, 2,
        -1, 1, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"glider 3 (14 cell diagonal, p7)"},
#endif
	{
        1, -2, -1,
        -2, 1, -1,

        0, -2, 0, 2, -2, 0,
        1, -1, 0, 2, -1, 0,
        -2, 0, 0,
        -1, 1, 0,
        -2, 2, 0, -1, 2, 0,

        1, -2, 1, 2, -2, 1,
        -2, 1, 1,
        -2, 2, 1,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"glider 3 better(14 cell diagonal, p7)"},
#endif
	{
        1, 4, 0, 2, 4, 0,
        0, 4, 1, 1, 4, 1, 2, 4, 1,
        0, 3, 1, 1, 3, 1,

        0, 1, 3, 1, 1, 3,

        1, 0, 4, 2, 0, 4,
        0, 1, 4, 1, 1, 4, 2, 1, 4,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"C"},
#endif
	{
        -1, 0, -1, 1, 0, -1,

        -1, 0, 0, 0, 0, 0, 1, 0, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"mosquito"},
#endif
	{
        0, 0, -1,
        -1, -1, 0,
        -1, 0, 0, 0, 0, 0,
        -1, 1, 0,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"prop"},
#endif
	{
        -1, 0, -1, 0, 0, -1, 1, 0, -1,

        0, -1, 0,
        0, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"seesaw"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 0, 0, -1,

        0, 0, 0, 1, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"arrow"},
#endif
	{
        -1, -1, -1,
        -1, 0, -1,

        1, -1, 0,
        0, 0, 0, 1, 0, 0,

        0, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"broken seesaw"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 0, 0, -1,

        1, -1, 0,
        0, 0, 0, 1, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"column"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 0, 0, -1, 1, 0, -1,
        0, 1, -1,

        0, 0, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"small rower"},
#endif
	{
        -1, 0, -1, 0, 0, -1, 1, 0, -1,

        -1, -1, 0, 0, -1, 0, 1, -1, 0,
        0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"runner"},
#endif
	{
        0, -1, -1,
        -1, 0, -1,

        -1, -1, 0, 0, -1, 0,
        -1, 0, 0,

        -1, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"sliding blocks"},
#endif
	{
        0, -1, -1,
        0, 0, -1,

        0, -1, 0,
        -1, 0, 0, 0, 0, 0,

        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"stinging mosquito"},
#endif
	{
        0, 0, -1,
        0, 1, -1, 1, 1, -1,

        0, -1, 0,
        -1, 0, 0, 0, 0, 0, 1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"double blinker"},
#endif
	{
        0, 0, -1,
        0, 1, -1,

        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 1, 0, 0,

        0, 0, 1,
        0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2C"},
#endif
	{
        -1, -1, -1, 1, -1, -1,
        -1, 0, -1, 1, 0, -1,
        1, 1, -1,

        -1, -1, 0, 1, -1, 0,
        1, 1, 0,

        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2C2"},
#endif
	{
        -2, -1, -1, 0, -1, -1,
        -1, 1, -1, 0, 1, -1, 1, 1, -1,

        -2, -1, 0, -1, -1, 0, 0, -1, 0,
        -1, 1, 0, 1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"2S"},
#endif
	{
        0, 0, -2,
        0, 1, -2,

        -2, 0, -1, -1, 0, -1,
        0, 1, -1,

        -1, 0, 0,
        0, 1, 0,
        0, 2, 0,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"clock"},
#endif
	{
        -1, -2, -1,
        -1, -1, -1, 1, -1, -1,
        -2, 0, -1, 0, 0, -1,
        0, 1, -1,

        -1, -2, 0,
        1, -1, 0,
        -2, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"clock2"},
#endif
	{
        -1, 0, -2, 0, 0, -2,

        -1, -2, -1, 0, -2, -1,
        0, -1, -1,

        -1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1, 0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"bat"},
#endif
	{
        0, -1, -1, 1, -1, -1,
        -1, 0, -1,
        -1, 1, -1,

        0, -2, 0, 1, -2, 0,
        0, -1, 0,
        -2, 0, 0, -1, 0, 0,
        -2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"deformed stairs"},
#endif
	{
        1, -1, -2,
        1, 0, -2,

        0, -1, -1,
        0, 0, -1, 1, 0, -1,

        -2, -1, 0, -1, -1, 0,
        -2, 0, 0, -1, 0, 0,

        -1, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"deformed stairs 2"},
#endif
	{
        0, -1, -2, 1, -1, -2,
        0, 0, -2,

        0, -1, -1,
        0, 0, -1,

        -1, -1, 0,
        -1, 0, 0,

        -1, -1, 1,
        -2, 0, 1, -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"folding stairs"},
#endif
	{
        -1, -2, -2, 0, -2, -2,

        -1, -2, -1,
        -1, -1, -1,
        0, -1, -1,

        -1, 0, 0, 0, 0, 0,
        0, 0, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"folding stairs 2"},
#endif
	{
        -1, -2, -2, 0, -2, -2,

        -1, -2, -1,
        -1, -1, -1, 0, -1, -1,

        -1, 0, 0, 0, 0, 0,
        -1, 0, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"folding stairs 3"},
#endif
	{
        1, 0, -2,

        0, -1, -1, 1, -1, -1,
        0, 0, -1, 1, 0, -1,
        -1, -1, 0,
        -1, 0, 0,

        -2, -1, 1,
        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"folding stairs 4"},
#endif
	{
        1, -2, -1,
        0, -1, -1,
        -1, 0, -1,
        -2, 1, -1, -1, 1, -1,

        0, -2, 0,
        0, -1, 0, 1, -1, 0,
        -2, 0, 0, -1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"folding stairs 5"},
#endif
	{
        -1, -2, -2,

        -1, -2, -1, 0, -2, -1,
        -1, -1, -1, 0, -1, -1,

        -1, 0, 0, 0, 0, 0,

        -1, 0, 1, 0, 0, 1,
        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"folding stairs 6"},
#endif
	{
        -2, -1, -2,
        -1, 0, -2,

        -1, -1, -1,
        -2, 0, -1, -1, 0, -1,

        0, -1, 0,
        0, 0, 0,
        1, 0, 0,

        1, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"folding stairs 7"},
#endif
	{
        0, 0, -2,

        0, -1, -1, 1, -1, -1,
        0, 0, -1, 1, 0, -1,

        -1, -1, 0,
        -2, 0, 0, -1, 0, 0,

        -2, -1, 1,
        -2, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"pinwheel"},
#endif
	{
        -1, -1, -2,
        -1, -1, -1,
        0, -1, -1,
        -1, 1, -1,
        0, 1, -1,
        -1, -1, 0,
        0, -1, 0,
        -1, 1, 0,
        0, 1, 0,
        0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"pinwheel2"},
#endif
	{
        0, -1, -2,
        0, -1, -1,
        1, -1, -1,
        -2, 0, -1,
        -1, 0, -1,
        0, -1, 0,
        1, -1, 0,
        -2, 0, 0,
        -1, 0, 0,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"pump"},
#endif
	{
        0, -1, -1, 1, -1, -1,
        0, 0, -1,

        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 1, 0, 0,

        -1, -1, 1, 0, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"rubberband"},
#endif
	{
        0, -1, -1,
        1, -1, -1,
        -1, 0, -1,
        0, 0, -1,
        1, -1, 0,
        -1, 0, 0,
        0, -1, 1,
        1, -1, 1,
        -1, 0, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"switch"},
#endif
	{
        2, -1, -2,
        1, 0, -2, 2, 0, -2,

        1, -1, -1, 2, -1, -1,
        1, 0, -1,

        1, 0, 0,

        -1, -1, 1,
        -2, 0, 1, -1, 0, 1, 0, 0, 1,

        -2, -1, 2, -1, -1, 2,
        -2, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"capacitor"},
#endif
	{
        0, -1, -2,
        -1, 0, -2, 0, 0, -2,

        0, 0, -1, 1, 0, -1,
        0, 1, -1, 1, 1, -1,

        0, 0, 1, 1, 0, 1,
        0, 1, 1, 1, 1, 1,

        0, -1, 2,
        -1, 0, 2, 0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"backwards runner"},
#endif
	{
        -1, -2, -1, 0, -2, -1,
        0, -1, -1,

        -1, -1, 0, 0, -1, 0,

        -1, 0, 1, 0, 0, 1,
        -1, 1, 1,

        -1, 0, 2, 0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"eagle"},
#endif
	{
        0, -2, -1, 1, -2, -1,
        0, -1, -1, 1, -1, -1,
        0, 1, -1, 1, 1, -1,
        0, 2, -1, 1, 2, -1,

        0, -1, 0,
        -1, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"variant 1"},
#endif
	{
        1, -1, -2,
        0, 0, -2,

        0, -1, -1,
        0, 0, -1, 1, 0, -1,

        -1, -1, 0,

        0, -1, 1,
        0, 0, 1, 1, 0, 1,

        1, -1, 2,
        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"variant 2"},
#endif
	{
        0, -1, -2,
        1, 0, -2,

        0, -1, -1, 1, -1, -1,
        0, 0, -1,

        -1, 0, 0,

        0, -1, 1,
        0, 0, 1, 1, 0, 1,

        1, -1, 2,
        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"variant 3"},
#endif
	{
        1, -1, -2,
        0, 0, -2,

        0, -1, -1, 1, -1, -1,
        0, 0, -1,

        -1, -1, 0,

        0, -1, 1,
        0, 0, 1, 1, 0, 1,

        1, -1, 2,
        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"variant 4"},
#endif
	{
        1, -1, -2,
        0, 0, -2,

        0, -1, -1, 1, -1, -1,
        0, 0, -1,

        -1, 0, 0,

        0, -1, 1,
        0, 0, 1, 1, 0, 1,

        1, -1, 2,
        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"squid"},
#endif
	{
        -2, -1, -2, -1, -1, -2,
        1, 1, -2,
        1, 2, -2,

        -2, -1, -1, -1, -1, -1, 0, -1, -1,
        1, 0, -1,
        1, 1, -1,
        1, 2, -1,

        -1, -1, 0,
        1, 1, 0,

        -1, 0, 1,
        -2, 1, 1, -1, 1, 1, 0, 1, 1,
        -2, 2, 1, -1, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"rower"},
#endif
	{
        0, 1, -2,

        -1, -1, -1, 1, -1, -1,
        -2, 0, -1, -1, 0, -1, 1, 0, -1, 2, 0, -1,

        -1, 0, 0, 1, 0, 0,
        -1, 1, 0, 1, 1, 0,

        0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"flip"},
#endif
	{
        -1, -2, -2,
        0, -1, -2,
        0, 0, -2,

        -1, -2, -1,
        -2, -1, -1, 1, -1, -1,
        1, 0, -1,
        1, 1, -1,

        -1, -2, 0,
        -2, -1, 0,
        -1, 1, 0, 0, 1, 0,

        -2, 0, 1, -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"corner 1"},
#endif
	{
        -1, -3, -3,
        -1, -2, -3, 0, -2, -3,
        1, -1, -3,
        1, 0, -3, 2, 0, -3,

        -1, -3, -2,
        0, -2, -2,
        1, -1, -2,
        2, 0, -2,

        -3, -3, -1, -2, -3, -1,
        -3, -2, -1,
        2, 1, -1,
        1, 2, -1, 2, 2, -1,

        -3, -2, 0, -2, -2, 0,
        1, 1, 0,
        1, 2, 0,

        -3, -1, 1, -2, -1, 1,
        -3, 0, 1,
        0, 1, 1,
        -1, 2, 1, 0, 2, 1,

        -3, 0, 2, -2, 0, 2,
        -1, 1, 2,
        -1, 2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"corner 2"},
#endif
	{
        -2, -2, -3, -1, -2, -3,
        -2, -1, -3,
        2, 1, -3,
        1, 2, -3, 2, 2, -3,

        -3, -2, -2, -1, -2, -2,
        -3, -1, -2, 0, -1, -2,
        1, 0, -2,
        2, 1, -2,
        1, 3, -2, 2, 3, -2,

        -3, -2, -1, -2, -2, -1,
        0, -1, -1,
        1, 0, -1,
        2, 2, -1,
        2, 3, -1,

        -2, -1, 0, -1, -1, 0,
        1, 1, 0,
        1, 2, 0,

        -2, 0, 1, -1, 0, 1,
        0, 1, 1,
        -3, 2, 1, 0, 2, 1,
        -2, 3, 1,

        -3, 1, 2, -2, 1, 2,
        -3, 2, 2, -1, 2, 2,
        -2, 3, 2, -1, 3, 2,
        127
	},
#ifdef LIFE_NAMES
	{"runner"},
#endif
	{
        -1, -2, -1, 0, -2, -1,
        0, -1, -1,

        -1, -1, 0, 0, -1, 0,

        -1, 0, 1, 0, 0, 1,
        0, 1, 1,

        -1, 1, 2, 0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"3 columns"},
#endif
	{
        0, 0, -6,

        0, 0, -5,

        0, -1, -4,
        -1, 0, -4, 0, 0, -4, 1, 0, -4,
        0, 1, -4,

        0, -1, -1,
        -1, 0, -1, 0, 0, -1, 1, 0, -1,
        0, 1, -1,

        0, 0, 0,

        0, 0, 1,

        0, 0, 2,

        0, 0, 3,

        0, -1, 4,
        -1, 0, 4, 0, 0, 4, 1, 0, 4,
        0, 1, 4,
        127
	},
#ifdef LIFE_NAMES
	{"H (p3)"},
#endif
	{
        -1, -2, 0, 0, -2, 0, 1, -2, 0,
        0, -1, 0,
        -1, 0, 0, 0, 0, 0, 1, 0, 0,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"big crate (p3)"},
#endif
	{
        -3, -4, -4, 2, -4, -4,
        -4, -3, -4, -1, -3, -4, 0, -3, -4, 3, -3, -4,
        -3, -2, -4, 2, -2, -4,
        -3, -1, -4, 2, -1, -4,
        -3, 0, -4, 2, 0, -4,
        -3, 1, -4, 2, 1, -4,
        -4, 2, -4, -1, 2, -4, 0, 2, -4, 3, 2, -4,
        -3, 3, -4, 2, 3, -4,

        -4, -4, -3, -2, -4, -3, -1, -4, -3, 0, -4, -3, 1, -4, -3, 3, -4, -3,
        -4, -1, -3, 3, -1, -3,
        -4, 0, -3, 3, 0, -3,
        -4, 3, -3, -2, 3, -3, -1, 3, -3, 0, 3, -3, 1, 3, -3, 3, 3, -3,

        -4, -3, -2, 3, -3, -2,
        -4, 2, -2, 3, 2, -2,

        -3, -4, -1, 2, -4, -1,
        -4, -3, -1, 3, -3, -1,
        -4, 2, -1, 3, 2, -1,
        -3, 3, -1, 2, 3, -1,

        -3, -4, 0, 2, -4, 0,
        -4, -3, 0, 3, -3, 0,
        -4, 2, 0, 3, 2, 0,
        -3, 3, 0, 2, 3, 0,

        -4, -3, 1, 3, -3, 1,
        -4, 2, 1, 3, 2, 1,

        -4, -4, 2, -2, -4, 2, -1, -4, 2, 0, -4, 2, 1, -4, 2, 3, -4, 2,
        -4, -1, 2, 3, -1, 2,
        -4, 0, 2, 3, 0, 2,
        -4, 3, 2, -2, 3, 2, -1, 3, 2, 0, 3, 2, 1, 3, 2, 3, 3, 2,

        -3, -4, 3, 2, -4, 3,
        -4, -3, 3, -1, -3, 3, 0, -3, 3, 3, -3, 3,
        -3, -2, 3, 2, -2, 3,
        -3, -1, 3, 2, -1, 3,
        -3, 0, 3, 2, 0, 3,
        -3, 1, 3, 2, 1, 3,
        -4, 2, 3, -1, 2, 3, 0, 2, 3, 3, 2, 3,
        -3, 3, 3, 2, 3, 3,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"1 leg walker (p4)"},
#endif
	{
        0, 1, -2,
        -1, 2, -2, 0, 2, -2,

        -1, 1, -1, 0, 1, -1,
        -1, 2, -1,

        0, -2, 0,
        0, -1, 0, 1, -1, 0,
        1, 0, 0,

        1, -2, 1,
        1, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2 enemies (p4)"},
#endif
	{
        -1, -2, -1, 0, -2, -1,
        0, 2, -1, 1, 2, -1,

        0, -2, 0,
        -1, -1, 0, 0, -1, 0,
        0, 1, 0, 1, 1, 0,
        1, 2, 0,

        -1, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"W (p4)"},
#endif
	{
        -1, -2, -1,
        1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        0, 1, -1, 2, 1, -1,

        -1, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -2, 0, 0,
        0, 1, 0, 2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"W2 (p4)"},
#endif
	{
        0, -1, -2,
        0, 0, -2,

        1, -1, -1,
        0, 0, -1, 1, 0, -1,

        -2, -1, 0,
        -2, 0, 0,

        -1, -1, 1, 0, -1, 1,
        0, 0, 1,

        -1, -1, 2,
        -1, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"beacon (p4)"},
#endif
	{
        1, -2, -1, 2, -2, -1,
        1, -1, -1, 2, -1, -1,
        2, -2, 0,
        0, -1, 0, 2, -1, 0,
        -1, 0, 0,
        -2, 1, 0, -1, 1, 0,
        -2, 0, 1, -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"beacon2 (p4)"},
#endif
	{
        2, -2, -1,
        1, -1, -1, 2, -1, -1,
        1, -2, 0, 2, -2, 0,
        0, -1, 0, 2, -1, 0,
        -1, 0, 0,
        -2, 1, 0, -1, 1, 0,
        -2, 0, 1, -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"friend with stabilizer (p4)"},
#endif
	{
        -2, 0, -2, -1, 0, -2,

        -2, 0, -1, -1, 0, -1,
        -1, 1, -1,

        1, -1, 0,
        1, 0, 0,
        -1, 1, 0,

        0, -1, 1, 1, -1, 1,
        0, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"double switch (p4)"},
#endif
	{
        -2, -3, -1,
        -1, -2, -1,
        -2, -1, -1, -1, -1, -1,

        -1, -3, 0,
        -2, -2, 0, -1, -2, 0,
        -1, 0, 0,

        0, 1, 0, 1, 1, 0,
        0, 2, 0,

        0, 1, 1,
        1, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"double switch2 (p4)"},
#endif
	{
        -1, 0, -3,
        0, 1, -3,

        -1, 0, -2, 0, 0, -2,
        0, 1, -2,

        -1, 0, -1,
        0, 1, -1,

        0, -1, 0,

        0, -2, 1,
        0, -1, 1, 1, -1, 1,
        1, -2, 2,

        0, -1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"3 friends (p4)"},
#endif
	{
        2, -1, -3,
        1, 0, -3,

        1, -1, -2,
        0, 0, -2, 1, 0, -2, 2, 0, -2,

        -2, 1, -1,
        -3, 2, -1,

        0, -2, 0,
        -2, 0, 0,
        -3, 1, 0, -2, 1, 0,
        -2, 2, 0,

        0, -3, 1,
        -1, -2, 1, 0, -2, 1,

        -1, -3, 2,
        0, -2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"stuff with 3 stabilizers (p4)"},
#endif
	{
        -2, 2, -3, -1, 2, -3,
        -2, 3, -3, -1, 3, -3,

        2, -3, -2, 3, -3, -2,
        2, -2, -2, 3, -2, -2,
        -2, 2, -2,
        -2, 3, -2,

        2, -3, -1, 3, -3, -1,
        2, -1, -1,
        0, 0, -1,
        0, 1, -1,
        -1, 2, -1,

        0, -1, 0, 1, -1, 0,
        -1, 0, 0,

        -1, 0, 1,

        -3, -2, 2, -2, -2, 2,
        -3, -1, 2, -1, -1, 2,

        -3, -2, 3, -2, -2, 3,
        -3, -1, 3,
        127
	},
#ifdef LIFE_NAMES
	{"invert (p6)"},
#endif
	{
        -1, -3, -2, 1, -3, -2,
        -2, -2, -2, -1, -2, -2, 1, -2, -2, 2, -2, -2,
        -2, 0, -2, -1, 0, -2, 1, 0, -2, 2, 0, -2,
        -1, 1, -2, 1, 1, -2,

        -1, -3, -1, 1, -3, -1,
        -2, -2, -1, -1, -2, -1, 1, -2, -1, 2, -2, -1,
        -2, 0, -1, -1, 0, -1, 1, 0, -1, 2, 0, -1,
        -1, 1, -1, 1, 1, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"corner (p6)"},
#endif
	{
        1, 1, -3,
        2, 2, -3,

        2, 1, -2,
        1, 2, -2, 2, 2, -2,

        1, 1, -1,
        2, 2, -1,

        2, 1, 0,

        1, -3, 1,
        2, -2, 1,
        1, -1, 1,
        -3, 1, 1, -1, 1, 1,
        -2, 2, 1, 0, 2, 1, 2, 2, 1,

        2, -3, 2,
        1, -2, 2, 2, -2, 2,
        2, -1, 2,
        1, 0, 2,
        -2, 1, 2, 2, 1, 2,
        -3, 2, 2, -2, 2, 2, -1, 2, 2, 1, 2, 2,
        127
	},
};

static char patterns_26S567B6[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider diagonal (c/2, p4)"},
#endif
	{
        0, 1, 0, 1, 1, 0,
        0, 2, 1, 1, 2, 1,
        0, 0, 2, 1, 0, 2,
        0, 1, 2, 1, 1, 2,
        0, 2, 2, 1, 2, 2,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"glider 2 (16 cell, c/4, p8)"},
#endif
	{
        -1, -2, -1, -1, -2, 0,
        -1, -1, -1, -1, -1, 0,
        -1, 1, -1, -1, 1, 0,

        0, -1, -1, 0, -1, 0,
        0, 1, -1, 0, 1, 0,
        0, 2, -1, 0, 2, 0,

        1, 0, -1, 1, 0, 0,
        1, 1, -1, 1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"glider (32 cell, c/4, p8)"},
#endif
	{
        -1, -3, -2, 0, -3, -2, 1, -3, -2,
        -2, -2, -2, -1, -2, -2, 1, -2, -2, 2, -2, -2,
        -2, -1, -2, 2, -1, -2,
        -2, 0, -2, -1, 0, -2, 1, 0, -2, 2, 0, -2,
        -1, 1, -2, 0, 1, -2, 1, 1, -2,

        -1, -4, -1, 0, -4, -1, 1, -4, -1,
        -2, -3, -1, 2, -3, -1,
        -3, -2, -1, 3, -2, -1,
        -3, -1, -1, 3, -1, -1,
        -3, 0, -1, 3, 0, -1,
        -2, 1, -1, 2, 1, -1,
        -1, 2, -1, 0, 2, -1, 1, 2, -1,

        1, -3, 0,
        -2, -2, 0,
        2, 0, 0,
        -1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"glider (36 cell, c/4, p8)"},
#endif
	{
        -1, -3, -2, 0, -3, -2, 1, -3, -2,
        -2, -2, -2, -1, -2, -2, 1, -2, -2, 2, -2, -2,
        -2, -1, -2, 2, -1, -2,
        -2, 0, -2, -1, 0, -2, 1, 0, -2, 2, 0, -2,
        -1, 1, -2, 0, 1, -2, 1, 1, -2,

        -1, -4, -1, 0, -4, -1, 1, -4, -1,
        -2, -3, -1, 2, -3, -1,
        -3, -2, -1, 3, -2, -1,
        -3, -1, -1, 3, -1, -1,
        -3, 0, -1, 3, 0, -1,
        -2, 1, -1, 2, 1, -1,
        -1, 2, -1, 0, 2, -1, 1, 2, -1,

        -1, -3, 0,
        2, -2, 0,
        -2, 0, 0,
        1, 1, 0,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"blinker"},
#endif
	{
        -1, -1, 0, 0, -1, 0, 1, -1, 0,
        -1, 0, 0, 0, 0, 0, 1, 0, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"knife-switch blinker"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
        -1, 0, -1, 1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, 0, 0, 0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"switch"},
#endif
	{
        -1, 0, -1, 1, 0, -1,

        0, -1, 0,
        -1, 0, 0, 0, 0, 0, 1, 0, 0,
        0, 1, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"triknot"},
#endif
	{
        0, 0, -1, 1, 0, -1,

        -1, -1, 0, 0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        0, 0, 1,
        0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"double blinker"},
#endif
	{
        0, 0, -1,
        0, 1, -1,

        -1, -1, 0, 0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        0, -1, 1,
        1, 0, 1,
        0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"pile driver"},
#endif
	{
        -1, 0, -1, 0, 0, -1,
        -1, 1, -1,

        -1, -1, 0, 0, -1, 0,
        1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"run around"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 1, 0, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0, 1, 1, 0,

        0, -1, 1,
        -1, 0, 1,
        0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"single blinker"},
#endif
	{
        0, -1, -1,
        1, 0, -1,
        0, 1, -1,

        -1, -1, 0, 0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -1, 1, 0, 1, 1, 0,

        0, 0, 1,
        0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"beacon"},
#endif
	{
        -2, -1, -2, -1, -1, -2,
        -2, 0, -2, -1, 0, -2,

        -2, -1, -1,
        -2, 0, -1,

        1, -1, 0,
        1, 0, 0,

        0, -1, 1, 1, -1, 1,
        0, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"clock"},
#endif
	{
        -1, -2, -1,
        -1, -1, -1, 1, -1, -1,
        -2, 0, -1, 0, 0, -1,
        0, 1, -1,

        -1, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -2, 0, 0, 0, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"gear"},
#endif
	{
        0, 0, -2,

        0, -2, -1,
        -1, -1, -1, 1, -1, -1,
        -1, 0, -1, 1, 0, -1,

        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"s"},
#endif
	{
        -1, -1, -2, 0, -1, -2,

        -1, -1, -1, 0, -1, -1,
        -1, 0, -1, 0, 0, -1,

        -1, -1, 0, 0, -1, 0,
        -1, 0, 0, 0, 0, 0,

        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"3 halves blinker"},
#endif
	{
        -1, -1, -1,
        -1, 0, -1,

        0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        0, -2, 1,
        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"digger"},
#endif
	{
        0, -1, -2,
        -1, 0, -2, 0, 0, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1,
        1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -1, 0, 0, -1, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"deformed digger"},
#endif
	{
        0, -1, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -1, 0, -1, 1, 0, -1,
        0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0,
        -2, 0, 0, -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"help"},
#endif
	{
        -1, 0, -2, 0, 0, -2,

        -1, -1, -1, 0, -1, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1, 0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"half blinkers"},
#endif
	{
        0, -1, -2,
        0, 0, -2,

        -1, -1, -1, 1, -1, -1,
        -1, 0, -1, 1, 0, -1,
        0, 1, -1,

        -1, -2, 0, 0, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 0, 0, 2, 0, 0,
        0, 1, 0,

        -1, -1, 1, 1, -1, 1,
        -1, 0, 1, 1, 0, 1,
        0, 1, 1,

        0, -1, 2,
        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"mutant half blinkers"},
#endif
	{
        0, -1, -2,
        0, 0, -2,

        0, -2, -1,
        -1, -1, -1, 1, -1, -1,
        -1, 0, -1, 1, 0, -1,
        0, 1, -1,

        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 0, 0, 2, 0, 0,
        0, 1, 0,

        0, -2, 1, 1, -2, 1,
        -1, -1, 1, 2, -1, 1,
        -1, 0, 1, 2, 0, 1,
        0, 1, 1,

        0, -1, 2, 1, -1, 2,
        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"2 pts of star of David"},
#endif
	{
        -2, -1, -3,
        -3, 0, -3, -1, 0, -3,
        -2, 1, -3,

        -2, -1, -2,
        -3, 0, -2, -1, 0, -2,
        -2, 1, -2,

        -2, 0, -1, 0, 0, -1,

        1, 0, 0, 2, 0, 0,

        1, -1, 1, 2, -1, 1,
        0, 0, 1,
        1, 1, 1, 2, 1, 1,

        1, 0, 2, 2, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"triple blinker 1"},
#endif
	{
        0, -1, -2,
        0, 0, -2,

        -1, -1, -1, 1, -1, -1,
        -2, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        1, -1, 0,
        -2, 0, 0, 0, 0, 0,

        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"triple blinker 2"},
#endif
	{
        -1, -1, -2, 0, -1, -2,

        -1, -2, -1,
        -2, -1, -1, -1, -1, -1,
        -2, 0, -1,
        0, 1, -1,

        -1, -2, 0,
        1, -1, 0,
        0, 0, 0, 1, 0, 0,
        0, 1, 0,

        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"searchlight"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2, 0, 0, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,

        -1, -1, 1, 0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"little star"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 1, 0, -1,
        -1, 1, -1, 0, 1, -1, 1, 1, -1,

        -1, -1, 0, 1, -1, 0,
        -1, 1, 0, 1, 1, 0,

        -1, -1, 1, 0, -1, 1, 1, -1, 1,
        -1, 0, 1, 1, 0, 1,
        0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"cruncher"},
#endif
	{
        0, -2, -2,
        0, -1, -2,

        0, -2, -1, 1, -2, -1,
        1, -1, -1,
        -1, 0, -1, 1, 0, -1,

        -1, -1, 0, 1, -1, 0,
        -1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        0, 0, 1,
        0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"fountain (p3)"},
#endif
	{
        1, -2, -3, 2, -2, -3,
        1, 1, -3, 2, 1, -3,

        1, -3, -2, 2, -3, -2,
        0, 0, -2, 3, 0, -2,
        0, 1, -2, 3, 1, -2,
        1, 2, -2, 2, 2, -2,

        1, -2, -1, 2, -2, -1,
        0, 0, -1, 3, 0, -1,
        0, 1, -1, 3, 1, -1,
        1, 2, -1, 2, 2, -1,

        1, 1, 0, 2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"star maker (p3)"},
#endif
	{
        1, -2, -1, 2, -2, -1,
        1, -1, -1, 2, -1, -1,
        -2, 1, -1, -1, 1, -1,
        -2, 2, -1, -1, 2, -1,

        1, -3, 0, 2, -3, 0,
        3, -2, 0, 0, -1, 0,
        3, -1, 0, -1, 0, 0,
        1, 0, 0,
        -3, 1, 0, 0, 1, 0,
        -3, 2, 0,
        -2, 3, 0, -1, 3, 0,

        1, -2, 1, 2, -2, 1,
        1, -1, 1, 2, -1, 1,
        -2, 1, 1, -1, 1, 1,
        -2, 2, 1, -1, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"v (p3)"},
#endif
	{
        1, 0, -3,
        0, 1, -3, 1, 1, -3,

        -1, -1, -2, 0, -1, -2, 1, -1, -2,
        -1, 0, -2, 2, 0, -2,
        -1, 1, -2, 2, 1, -2,
        0, 2, -2, 1, 2, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1,
        -2, 0, -1, 2, 0, -1,
        2, 1, -1,
        0, 2, -1, 1, 2, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0,
        -1, 1, 0,

        0, -1, 1, 1, -1, 1,
        -1, 0, 1,
        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"peak-a-boo (p3)"},
#endif
	{
        -1, -2, -3, 0, -2, -3,
        -2, -1, -3, 1, -1, -3,
        -2, 0, -3, 1, 0, -3,

        -1, -3, -2, 0, -3, -2,
        -2, -2, -2, 1, -2, -2,
        -3, -1, -2, 2, -1, -2,
        -3, 0, -2, -1, 0, -2, 0, 0, -2, 2, 0, -2,
        -2, 1, -2, 1, 1, -2,

        -1, -3, -1, 0, -3, -1,
        -2, -2, -1, 1, -2, -1,
        -3, 0, -1, 2, 0, -1,
        -2, 1, -1, 1, 1, -1,

        -2, -2, 0, 1, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"jaws (p3)"},
#endif
	{
        0, -1, -2,
        -1, 0, -2, 1, 0, -2,
        0, 1, -2,

        0, -2, -1,
        -1, -1, -1, 1, -1, -1,
        -1, 0, -1, 2, 0, -1,
        0, 1, -1, 1, 1, -1,

        -1, -2, 0, 1, -2, 0,
        -1, -1, 0, 2, -1, 0,
        1, 1, 0, 2, 1, 0,

        0, -2, 1,
        0, -1, 1, 1, -1, 1,
        1, 0, 1, 2, 0, 1,

        -2, 1, 1,
        -2, 2, 1, -1, 2, 1,

        -2, 1, 2, -1, 1, 2,
        -2, 2, 2, -1, 2, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"egg (p3)"},
#endif
	{
        1, -3, -5,

        2, -4, -4,
        0, -3, -4, 1, -3, -4, 2, -3, -4,
        -1, -2, -4, 0, -2, -4,
        -1, -1, -4, 0, -1, -4, 1, -1, -4,

        1, -5, -3, 2, -5, -3,
        0, -4, -3, 3, -4, -3,
        3, -3, -3,
        -2, -2, -3, 3, -2, -3,
        -2, -1, -3, 2, -1, -3,
        0, 0, -3, 1, 0, -3,

        1, -6, -2, 2, -6, -2,
        1, -4, -2,
        -2, -3, -2, 1, -3, -2, 3, -3, -2,
        -1, -2, -2, 0, -2, -2, 1, -2, -2, 3, -2, -2,
        -3, -1, -2, 2, -1, -2,
        -2, 0, -2, 0, 0, -2,
        0, 1, -2,

        0, -6, -1, 1, -6, -1, 2, -6, -1,
        -1, -5, -1, 3, -5, -1,
        1, -4, -1, 3, -4, -1, 4, -4, -1,
        -3, -3, -1, 3, -3, -1,
        -4, -2, -1, -3, -2, -1, -1, -2, -1,
        -3, -1, -1, 1, -1, -1,
        -2, 0, -1, -1, 0, -1, 0, 0, -1,

        0, -7, 0,
        0, -6, 0, 2, -6, 0,
        -2, -5, 0, 3, -5, 0,
        -3, -4, 0, -1, -4, 0, 0, -4, 0, 1, -4, 0,
        -3, -3, 0, -1, -3, 0, 2, -3, 0,
        -1, -2, 0,
        -2, 0, 0, -1, 0, 0,

        -1, -6, 1, 0, -6, 1,
        -2, -5, 1, 2, -5, 1,
        -3, -4, 1, 2, -4, 1,
        -3, -3, 1,
        -3, -2, 1, 0, -2, 1,
        -2, -1, 1, -1, -1, 1,

        -1, -5, 2, 0, -5, 2, 1, -5, 2,
        0, -4, 2, 1, -4, 2,
        -2, -3, 2, -1, -3, 2, 0, -3, 2,
        -2, -2, 2,

        -1, -3, 3,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"sparky (p4)"},
#endif
	{
        0, -1, -2,
        0, 0, -2,

        0, -2, -1,
        -1, -1, -1, 1, -1, -1,
        -1, 0, -1, 1, 0, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, 0, 1, 0, 0, 1,
        -1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"star (p4)"},
#endif
	{
        0, 0, -2,

        0, -1, -1, 1, -1, -1,
        -1, 0, -1, 1, 0, -1,
        0, 1, -1, 1, 1, -1,

        -1, -1, 0, 1, -1, 0,
        -1, 1, 0, 1, 1, 0,

        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 1, 0, 1,
        -1, 1, 1, 0, 1, 1,

        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"big star (p4)"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
        -1, 0, -1, 1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -1, 0, 1, -1, 0,
        -2, 0, 0, 2, 0, 0,
        -1, 1, 0, 1, 1, 0,

        0, -1, 1, 1, -1, 1,
        -1, 0, 1, 1, 0, 1,
        0, 1, 1, 1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"mouth (p4)"},
#endif
	{
        -1, 1, -2,

        0, -2, -1, 1, -2, -1,
        -1, -1, -1, 2, -1, -1,
        -2, 0, -1, 2, 0, -1,
        -2, 1, -1, 1, 1, -1,
        -1, 2, -1, 0, 2, -1,

        0, -2, 0, 1, -2, 0,
        -1, -1, 0, 2, -1, 0,
        -2, 0, 0, 2, 0, 0,
        -2, 1, 0, 1, 1, 0,
        -1, 2, 0, 0, 2, 0,

        1, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"v2 (p5)"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2,

        0, -2, -1, 1, -2, -1,
        -2, 0, -1, 0, 0, -1,
        -2, 1, -1,

        0, -2, 0, 1, -2, 0,
        -1, -1, 0, 2, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -2, 1, 0, 0, 1, 0,
        -1, 2, 0,

        1, -1, 1,
        1, 0, 1,
        -1, 1, 1, 0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"m (p5)"},
#endif
	{
        1, -1, -3,
        1, 0, -3,
        -1, 1, -3, 0, 1, -3,

        1, -2, -2,
        0, -1, -2, 2, -1, -2,
        -1, 0, -2, 2, 0, -2,
        -2, 1, -2, 1, 1, -2,
        -1, 2, -2, 0, 2, -2,

        1, -2, -1,
        2, -1, -1,
        2, 0, -1,
        -2, 1, -1,
        -1, 2, -1, 0, 2, -1,

        0, -1, 0, 1, -1, 0,
        -1, 0, 0, 0, 0, 0,
        -1, 1, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"birthday cake (p5)"},
#endif
	{
        -1, 0, -2, 0, 0, -2,
        -1, 1, -2, 0, 1, -2,

        -1, -1, -1,
        -2, 0, -1,
        -2, 1, -1, 1, 1, -1,
        -1, 2, -1, 0, 2, -1,

        0, -2, 0,
        -1, -1, 0, 0, -1, 0,
        2, 0, 0,
        -1, 1, 0, 2, 1, 0,
        -1, 2, 0,

        0, -1, 1, 1, -1, 1,
        2, 0, 1,
        0, 1, 1, 2, 1, 1,
        0, 2, 1, 1, 2, 1,

        1, 0, 2,
        1, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"sparky2 (p5)"},
#endif
	{
        0, -1, -2, 1, -1, -2,
        0, 0, -2, 1, 0, -2,

        0, -2, -1,
        -1, -1, -1,
        2, 0, -1,
        1, 1, -1,

        -1, -2, 0, 0, -2, 0,
        0, 0, 0, 2, 0, 0,
        2, 1, 0,

        -1, -2, 1, 0, -2, 1,
        -2, -1, 1, 1, -1, 1,
        -1, 0, 1, 2, 0, 1,
        0, 1, 1, 2, 1, 1,
        1, 2, 1,

        -1, -1, 2,
        -1, 0, 2,
        0, 1, 2, 1, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"fuse"},
#endif
	{
        0, 0, 4,

        0, 0, 3,

        0, -2, 2,
        -1, -1, 2, 1, -1, 2,
        -2, 0, 2, 2, 0, 2,
        -1, 1, 2, 1, 1, 2,
        0, 2, 2,

        0, -2, 1,
        -1, -1, 1, 1, -1, 1,
        -2, 0, 1, 2, 0, 1,
        -1, 1, 1, 1, 1, 1,
        0, 2, 1,

        0, 0, 0,

        0, 0, -1,

        0, -2, -2,
        -1, -1, -2, 1, -1, -2,
        -2, 0, -2, 2, 0, -2,
        -1, 1, -2, 1, 1, -2,
        0, 2, -2,

        0, -2, -3,
        -1, -1, -3, 1, -1, -3,
        -2, 0, -3, 2, 0, -3,
        -1, 1, -3, 1, 1, -3,
        0, 2, -3,

        -1, 0, -4, 0, 0, -4, 1, 0, -4,
        127
	},
#ifdef LIFE_NAMES
	{"near ship"},
#endif
	{
        -2, -1, -2, -1, -1, -2,
        -2, 0, -2, -1, 0, -2,

        -2, -1, -1, -1, -1, -1,
        -2, 0, -1, -1, 0, -1,

        0, -1, 0,
        0, 0, 0,

        -2, -1, 1, -1, -1, 1,
        -2, 0, 1, -1, 0, 1,

        -2, -1, 2, -1, -1, 2,
        -2, 0, 2, -1, 0, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"barrier"},
#endif
	{
        -3, -9, -6, -2, -9, -6, 1, -9, -6, 2, -9, -6,
        -3, -8, -6, -2, -8, -6, 1, -8, -6, 2, -8, -6,
        -7, -7, -6, -6, -7, -6, 5, -7, -6, 6, -7, -6,
        -7, -6, -6, -6, -6, -6, 5, -6, -6, 6, -6, -6,
        -9, -3, -6, -8, -3, -6, 7, -3, -6, 8, -3, -6,
        -9, -2, -6, -8, -2, -6, 7, -2, -6, 8, -2, -6,
        -9, 1, -6, -8, 1, -6, 7, 1, -6, 8, 1, -6,
        -9, 2, -6, -8, 2, -6, 7, 2, -6, 8, 2, -6,
        -7, 5, -6, -6, 5, -6, 5, 5, -6, 6, 5, -6,
        -7, 6, -6, -6, 6, -6, 5, 6, -6, 6, 6, -6,
        -3, 7, -6, -2, 7, -6, 1, 7, -6, 2, 7, -6,
        -3, 8, -6, -2, 8, -6, 1, 8, -6, 2, 8, -6,

        -3, -9, -5, -2, -9, -5, 1, -9, -5, 2, -9, -5,
        -3, -8, -5, -2, -8, -5, 1, -8, -5, 2, -8, -5,
        -6, -7, -5, 5, -7, -5,
        -7, -6, -5, 6, -6, -5,
        -9, -3, -5, -8, -3, -5, 7, -3, -5, 8, -3, -5,
        -9, -2, -5, -8, -2, -5, 7, -2, -5, 8, -2, -5,
        -9, 1, -5, -8, 1, -5, 7, 1, -5, 8, 1, -5,
        -9, 2, -5, -8, 2, -5, 7, 2, -5, 8, 2, -5,
        -7, 5, -5, 6, 5, -5,
        -6, 6, -5, 5, 6, -5,
        -3, 7, -5, -2, 7, -5, 1, 7, -5, 2, 7, -5,
        -3, 8, -5, -2, 8, -5, 1, 8, -5, 2, 8, -5,

        -6, -7, -4, 5, -7, -4,
        -7, -6, -4, 6, -6, -4,
        -7, 5, -4, 6, 5, -4,
        -6, 6, -4, 5, 6, -4,

        -5, -7, -3, -4, -7, -3, -3, -7, -3, -2, -7, -3, -1, -7, -3, 0, -7, -3, 1, -7, -3, 2, -7, -3, 3, -7, -3, 4, -7, -3,
        -6, -6, -3, -5, -6, -3, -4, -6, -3, -3, -6, -3, -2, -6, -3, -1, -6, -3, 0, -6, -3, 1, -6, -3, 2, -6, -3, 3, -6, -3, 4, -6, -3, 5, -6, -3,
        -7, -5, -3, -6, -5, -3, -4, -5, -3, -3, -5, -3, -1, -5, -3, 0, -5, -3, 2, -5, -3, 3, -5, -3, 5, -5, -3, 6, -5, -3,
        -7, -4, -3, -6, -4, -3, -5, -4, -3, -4, -4, -3, -3, -4, -3, -2, -4, -3, -1, -4, -3, 0, -4, -3, 1, -4, -3, 2, -4, -3, 3, -4, -3, 4, -4, -3, 5, -4, -3, 6, -4, -3,
        -7, -5, -3, -6, -5, -3, -4, -5, -3, -3, -5, -3, -1, -5, -3, 0, -5, -3, 2, -5, -3, 3, -5, -3, 5, -5, -3, 6, -5, -3,
        -7, -4, -3, -6, -4, -3, -5, -4, -3, -4, -4, -3, -3, -4, -3, -2, -4, -3, -1, -4, -3, 0, -4, -3, 1, -4, -3, 2, -4, -3, 3, -4, -3, 4, -4, -3, 5, -4, -3, 6, -4, -3,
        -7, -3, -3, -6, -3, -3, -5, -3, -3, -4, -3, -3, -3, -3, -3, -2, -3, -3, -1, -3, -3, 0, -3, -3, 1, -3, -3, 2, -3, -3, 3, -3, -3, 4, -3, -3, 5, -3, -3, 6, -3, -3,
        -7, -2, -3, -6, -2, -3, -4, -2, -3, -3, -2, -3, -1, -2, -3, 0, -2, -3, 2, -2, -3, 3, -2, -3, 5, -2, -3, 6, -2, -3,
        -7, -1, -3, -6, -1, -3, -5, -1, -3, -4, -1, -3, -3, -1, -3, -2, -1, -3, -1, -1, -3, 0, -1, -3, 1, -1, -3, 2, -1, -3, 3, -1, -3, 4, -1, -3, 5, -1, -3, 6, -1, -3,
        -7, 0, -3, -6, 0, -3, -5, 0, -3, -4, 0, -3, -3, 0, -3, -2, 0, -3, -1, 0, -3, 0, 0, -3, 1, 0, -3, 2, 0, -3, 3, 0, -3, 4, 0, -3, 5, 0, -3, 6, 0, -3,
        -7, 1, -3, -6, 1, -3, -4, 1, -3, -3, 1, -3, -1, 1, -3, 0, 1, -3, 2, 1, -3, 3, 1, -3, 5, 1, -3, 6, 1, -3,
        -7, 2, -3, -6, 2, -3, -5, 2, -3, -4, 2, -3, -3, 2, -3, -2, 2, -3, -1, 2, -3, 0, 2, -3, 1, 2, -3, 2, 2, -3, 3, 2, -3, 4, 2, -3, 5, 2, -3, 6, 2, -3,
        -7, 3, -3, -6, 3, -3, -5, 3, -3, -4, 3, -3, -3, 3, -3, -2, 3, -3, -1, 3, -3, 0, 3, -3, 1, 3, -3, 2, 3, -3, 3, 3, -3, 4, 3, -3, 5, 3, -3, 6, 3, -3,
        -7, 4, -3, -6, 4, -3, -4, 4, -3, -3, 4, -3, -1, 4, -3, 0, 4, -3, 2, 4, -3, 3, 4, -3, 5, 4, -3, 6, 4, -3,
        -6, 5, -3, -5, 5, -3, -4, 5, -3, -3, 5, -3, -2, 5, -3, -1, 5, -3, 0, 5, -3, 1, 5, -3, 2, 5, -3, 3, 5, -3, 4, 5, -3, 5, 5, -3,
        -5, 6, -3, -4, 6, -3, -3, 6, -3, -2, 6, -3, -1, 6, -3, 0, 6, -3, 1, 6, -3, 2, 6, -3, 3, 6, -3, 4, 6, -3,


        -3, -9, -1, -2, -9, -1, 1, -9, -1, 2, -9, -1,
        -3, -8, -1, -2, -8, -1, 1, -8, -1, 2, -8, -1,
        -9, -3, -1, -8, -3, -1, 7, -3, -1, 8, -3, -1,
        -9, -2, -1, -8, -2, -1, 7, -2, -1, 8, -2, -1,
        -3, 0, -1, -2, 0, -1, -1, 0, -1,
        -9, 1, -1, -8, 1, -1, -1, 1, -1, 7, 1, -1, 8, 1, -1,
        -9, 2, -1, -8, 2, -1, -2, 2, -1, 7, 2, -1, 8, 2, -1,
        -3, 7, -1, -2, 7, -1, 1, 7, -1, 2, 7, -1,
        -3, 8, -1, -2, 8, -1, 1, 8, -1, 2, 8, -1,

        -3, -9, 0, -2, -9, 0, 1, -9, 0, 2, -9, 0,
        -3, -8, 0, -2, -8, 0, 1, -8, 0, 2, -8, 0,
        -9, -3, 0, -8, -3, 0, 7, -3, 0, 8, -3, 0,
        -9, -2, 0, -8, -2, 0, 7, -2, 0, 8, -2, 0,
        -3, 0, 0, -2, 0, 0, -1, 0, 0,
        -9, 1, 0, -8, 1, 0, -1, 1, 0, 7, 1, 0, 8, 1, 0,
        -9, 2, 0, -8, 2, 0, -2, 2, 0, 7, 2, 0, 8, 2, 0,
        -3, 7, 0, -2, 7, 0, 1, 7, 0, 2, 7, 0,
        -3, 8, 0, -2, 8, 0, 1, 8, 0, 2, 8, 0,


        -5, -7, 2, -4, -7, 2, -3, -7, 2, -2, -7, 2, -1, -7, 2, 0, -7, 2, 1, -7, 2, 2, -7, 2, 3, -7, 2, 4, -7, 2,
        -6, -6, 2, -5, -6, 2, -4, -6, 2, -3, -6, 2, -2, -6, 2, -1, -6, 2, 0, -6, 2, 1, -6, 2, 2, -6, 2, 3, -6, 2, 4, -6, 2, 5, -6, 2,
        -7, -5, 2, -6, -5, 2, -4, -5, 2, -3, -5, 2, -1, -5, 2, 0, -5, 2, 2, -5, 2, 3, -5, 2, 5, -5, 2, 6, -5, 2,
        -7, -4, 2, -6, -4, 2, -5, -4, 2, -4, -4, 2, -3, -4, 2, -2, -4, 2, -1, -4, 2, 0, -4, 2, 1, -4, 2, 2, -4, 2, 3, -4, 2, 4, -4, 2, 5, -4, 2, 6, -4, 2,
        -7, -3, 2, -6, -3, 2, -5, -3, 2, -4, -3, 2, -3, -3, 2, -2, -3, 2, -1, -3, 2, 0, -3, 2, 1, -3, 2, 2, -3, 2, 3, -3, 2, 4, -3, 2, 5, -3, 2, 6, -3, 2,
        -7, -2, 2, -6, -2, 2, -4, -2, 2, -3, -2, 2, -1, -2, 2, 0, -2, 2, 2, -2, 2, 3, -2, 2, 5, -2, 2, 6, -2, 2,
        -7, -1, 2, -6, -1, 2, -5, -1, 2, -4, -1, 2, -3, -1, 2, -2, -1, 2, -1, -1, 2, 0, -1, 2, 1, -1, 2, 2, -1, 2, 3, -1, 2, 4, -1, 2, 5, -1, 2, 6, -1, 2,
        -7, 0, 2, -6, 0, 2, -5, 0, 2, -4, 0, 2, -3, 0, 2, -2, 0, 2, -1, 0, 2, 0, 0, 2, 1, 0, 2, 2, 0, 2, 3, 0, 2, 4, 0, 2, 5, 0, 2, 6, 0, 2,
        -7, 1, 2, -6, 1, 2, -4, 1, 2, -3, 1, 2, -1, 1, 2, 0, 1, 2, 2, 1, 2, 3, 1, 2, 5, 1, 2, 6, 1, 2,
        -7, 2, 2, -6, 2, 2, -5, 2, 2, -4, 2, 2, -3, 2, 2, -2, 2, 2, -1, 2, 2, 0, 2, 2, 1, 2, 2, 2, 2, 2, 3, 2, 2, 4, 2, 2, 5, 2, 2, 6, 2, 2,
        -7, 3, 2, -6, 3, 2, -5, 3, 2, -4, 3, 2, -3, 3, 2, -2, 3, 2, -1, 3, 2, 0, 3, 2, 1, 3, 2, 2, 3, 2, 3, 3, 2, 4, 3, 2, 5, 3, 2, 6, 3, 2,
        -7, 4, 2, -6, 4, 2, -4, 4, 2, -3, 4, 2, -1, 4, 2, 0, 4, 2, 2, 4, 2, 3, 4, 2, 5, 4, 2, 6, 4, 2,
        -6, 5, 2, -5, 5, 2, -4, 5, 2, -3, 5, 2, -2, 5, 2, -1, 5, 2, 0, 5, 2, 1, 5, 2, 2, 5, 2, 3, 5, 2, 4, 5, 2, 5, 5, 2,
        -5, 6, 2, -4, 6, 2, -3, 6, 2, -2, 6, 2, -1, 6, 2, 0, 6, 2, 1, 6, 2, 2, 6, 2, 3, 6, 2, 4, 6, 2,

        -6, -7, 3, 5, -7, 3,
        -7, -6, 3, 6, -6, 3,
        -7, 5, 3, 6, 5, 3,
        -6, 6, 3, 5, 6, 3,

        -3, -9, 4, -2, -9, 4, 1, -9, 4, 2, -9, 4,
        -3, -8, 4, -2, -8, 4, 1, -8, 4, 2, -8, 4,
        -6, -7, 4, 5, -7, 4,
        -7, -6, 4, 6, -6, 4,
        -9, -3, 4, -8, -3, 4, 7, -3, 4, 8, -3, 4,
        -9, -2, 4, -8, -2, 4, 7, -2, 4, 8, -2, 4,
        -9, 1, 4, -8, 1, 4, 7, 1, 4, 8, 1, 4,
        -9, 2, 4, -8, 2, 4, 7, 2, 4, 8, 2, 4,
        -7, 5, 4, 6, 5, 4,
        -6, 6, 4, 5, 6, 4,
        -3, 7, 4, -2, 7, 4, 1, 7, 4, 2, 7, 4,
        -3, 8, 4, -2, 8, 4, 1, 8, 4, 2, 8, 4,

        -3, -9, 5, -2, -9, 5, 1, -9, 5, 2, -9, 5,
        -3, -8, 5, -2, -8, 5, 1, -8, 5, 2, -8, 5,
        -7, -7, 5, -6, -7, 5, 5, -7, 5, 6, -7, 5,
        -7, -6, 5, -6, -6, 5, 5, -6, 5, 6, -6, 5,
        -9, -3, 5, -8, -3, 5, 7, -3, 5, 8, -3, 5,
        -9, -2, 5, -8, -2, 5, 7, -2, 5, 8, -2, 5,
        -9, 1, 5, -8, 1, 5, 7, 1, 5, 8, 1, 5,
        -9, 2, 5, -8, 2, 5, 7, 2, 5, 8, 2, 5,
        -7, 5, 5, -6, 5, 5, 5, 5, 5, 6, 5, 5,
        -7, 6, 5, -6, 6, 5, 5, 6, 5, 6, 6, 5,
        -3, 7, 5, -2, 7, 5, 1, 7, 5, 2, 7, 5,
        -3, 8, 5, -2, 8, 5, 1, 8, 5, 2, 8, 5,
        127
	},
#endif
};

static char patterns_26S57B6[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider diagonal (c/2, p4)"},
#endif
	{
        0, 1, 0, 1, 1, 0,

        0, 2, 1, 1, 2, 1,

        0, 0, 2, 1, 0, 2,
        0, 1, 2, 1, 1, 2,
        0, 2, 2, 1, 2, 2,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"snake ship diagonal (4c/7, p14)"},
#endif
	{
        0, 5, 0, 1, 5, 0,
        0, 4, 0, 1, 4, 0,
        0, 0, 0, 1, 0, 0,

        0, 4, 1, 1, 4, 1,
        0, 0, 1, 1, 0, 1,

        0, 3, 2, 1, 3, 2,
        0, 2, 2, 1, 2, 2,
        0, 1, 2, 1, 1, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"bumpy ball (p3)"},
#endif
	{
        0, -2, -3,

        0, -3, -2, 1, -3, -2,
        -1, -2, -2, 0, -2, -2, 1, -2, -2,
        -1, -1, -2, 0, -1, -2,

        0, -4, -1, 1, -4, -1,
        1, -3, -1, 2, -3, -1,
        -2, -2, -1, 1, -2, -1,
        -2, -1, -1, -1, -1, -1, 0, -1, -1,
        -1, 0, -1,

        0, -5, 0,
        -1, -4, 0, 0, -4, 0, 1, -4, 0,
        -2, -3, 0, 1, -3, 0,
        -3, -2, 0, -2, -2, 0,
        -2, -1, 0, -1, -1, 0,

        -1, -4, 1, 0, -4, 1,
        -2, -3, 1, -1, -3, 1, 0, -3, 1,
        -2, -2, 1, -1, -2, 1,

        -1, -3, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"ball (p3)"},
#endif
	{
        0, -4, -4,
        -2, -3, -4, 0, -3, -4, 2, -3, -4,
        -3, -1, -4, -2, -1, -4, 2, -1, -4, 3, -1, -4,
        -2, 1, -4, 0, 1, -4, 2, 1, -4,
        0, 2, -4,

        -2, -4, -3, 0, -4, -3, 2, -4, -3,
        -3, -3, -3, 0, -3, -3, 3, -3, -3,
        -3, -1, -3, -2, -1, -3, 2, -1, -3, 3, -1, -3,
        -3, 1, -3, 0, 1, -3, 3, 1, -3,
        -2, 2, -3, 0, 2, -3, 2, 2, -3,

        -3, -4, -1, -2, -4, -1, 2, -4, -1, 3, -4, -1,
        -3, -3, -1, -2, -3, -1, 2, -3, -1, 3, -3, -1,
        -3, 1, -1, -2, 1, -1, 2, 1, -1, 3, 1, -1,
        -3, 2, -1, -2, 2, -1, 2, 2, -1, 3, 2, -1,

        -2, -4, 1, 0, -4, 1, 2, -4, 1,
        -3, -3, 1, 0, -3, 1, 3, -3, 1,
        -3, -1, 1, -2, -1, 1, 2, -1, 1, 3, -1, 1,
        -3, 1, 1, 0, 1, 1, 3, 1, 1,
        -2, 2, 1, 0, 2, 1, 2, 2, 1,

        0, -4, 2,
        -2, -3, 2, 0, -3, 2, 2, -3, 2,
        -3, -1, 2, -2, -1, 2, 2, -1, 2, 3, -1, 2,
        -2, 1, 2, 0, 1, 2, 2, 1, 2,
        0, 2, 2,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"transformer (p11)"},
#endif
	{
        -1, -4, -1, 0, -4, -1,
        -3, -2, -1, -1, -2, -1, 0, -2, -1, 2, -2, -1,
        -3, -1, -1, -1, -1, -1, 0, -1, -1, 2, -1, -1,
        -3, 0, -1, -1, 0, -1, 0, 0, -1, 2, 0, -1,
        -3, 1, -1, -1, 1, -1, 0, 1, -1, 2, 1, -1,
        -1, 3, -1, 0, 3, -1,

        -1, -4, 0, 0, -4, 0,
        -3, -2, 0, -1, -2, 0, 0, -2, 0, 2, -2, 0,
        -3, -1, 0, -1, -1, 0, 0, -1, 0, 2, -1, 0,
        -3, 0, 0, -1, 0, 0, 0, 0, 0, 2, 0, 0,
        -3, 1, 0, -1, 1, 0, 0, 1, 0, 2, 1, 0,
        -1, 3, 0, 0, 3, 0,
        127
	},
};

static char patterns_26S58B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider diagonal (p2)"},
#endif
	{
        1, 3, 0, 2, 3, 0,

        1, 2, 1, 2, 2, 1,
        1, 3, 1, 2, 3, 1,

        1, 0, 2, 2, 0, 2,
        0, 2, 2, 1, 2, 2, 2, 2, 2, 3, 2, 2,
        1, 3, 2, 2, 3, 2,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"glider orthogonal (p2)"},
#endif
	{
        0, -1, -3,
        0, 0, -3,

        -1, -2, -2,
        0, -1, -2,
        0, 0, -2,
        -1, 1, -2,

        0, -3, -1,
        0, -2, -1,
        0, 1, -1,
        0, 2, -1,

        0, -3, 0,
        0, -2, 0,
        0, 1, 0,
        0, 2, 0,

        -1, -2, 1,
        0, -1, 1,
        0, 0, 1,
        -1, 1, 1,

        0, -1, 2,
        0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"crate"},
#endif
	{
        -1, -2, -2, 0, -2, -2,
        -1, -1, -2, 0, -1, -2,

        -1, -3, -1, 0, -3, -1,
        -2, -2, -1, 1, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -1, 0, -1, 0, 0, -1,

        -1, -3, 0, 0, -3, 0,
        -2, -2, 0, 1, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -1, 0, 0, 0, 0, 0,

        -1, -2, 1, 0, -2, 1,
        -1, -1, 1, 0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"3 runners (p4)"},
#endif
	{
        2, -1, -3,
        1, 0, -3,

        0, 0, -2, 1, 0, -2, 2, 0, -2,
        1, -1, -2,

        -2, 1, -1,
        -3, 2, -1,

        0, -2, 0,
        -2, 0, 0,
        -3, 1, 0, -2, 1, 0,
        -2, 2, 0,

        0, -3, 1,
        -1, -2, 1, 0, -2, 1,

        -1, -3, 2,
        0, -2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"cc (p10)"},
#endif
	{
        -1, -3, -1, 0, -3, -1,
        -1, -2, -1, 0, -2, -1,
        -1, 2, -1, 0, 2, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -3, 1, 0, -3, 1,
        -1, -2, 1, 0, -2, 1,
        -1, 1, 1, 0, 1, 1,
        -1, 2, 1, 0, 2, 1,
        127
	},
};

static char patterns_26S67B67[][3 * NUMPTS + 1] =
{
#ifdef LIFE_NAMES
	{"S"},
#endif
	{
        0, -1, -1, 1, -1, -1,
        -1, 0, -1, 0, 0, -1,

        0, -1, 0, 1, -1, 0,
        -1, 0, 0, 0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"S1"},
#endif
	{
        0, -1, -1, 1, -1, -1,
        0, 0, -1,

        -1, -1, 0, 0, -1, 0, 1, -1, 0,
        -1, 0, 0, 0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"S2"},
#endif
	{
        0, -1, -1, 1, -1, -1,
        -1, 0, -1, 0, 0, -1,

        -1, -1, 0, 0, -1, 0, 1, -1, 0,
        0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"T"},
#endif
	{
        1, 0, -1,

        1, -1, 0,
        -1, 0, 0, 0, 0, 0, 1, 0, 0,
        1, 1, 0,

        1, 0, 1,
        1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"arrow"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 0, 0, -1,
        1, 1, -1,

        0, -1, 0,
        -1, 0, 0, 0, 0, 0,
        1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"runner"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
        -2, 0, -1, -1, 0, -1,

        -2, -1, 0, -1, -1, 0,
        -1, 0, 0, 0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"walker"},
#endif
	{
        0, -1, -1,
        -1, 0, -1, 0, 0, -1, 1, 0, -1,

        -1, -1, 0, 0, -1, 0, 1, -1, 0,
        0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"triknot"},
#endif
	{
        0, -1, -1,
        0, 0, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0, 1, 1, 0,

        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"pile driver"},
#endif
	{
        0, 0, -1, 1, 0, -1,
        1, 1, -1,

        0, -1, 0, 1, -1, 0,
        -1, 0, 0,
        0, 1, 0, 1, 1, 0,

        1, -1, 1,
        0, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"clock"},
#endif
	{
        -1, -1, -2,
        -1, 0, -2,

        -1, -1, -1, 1, -1, -1,
        -1, 0, -1, 1, 0, -1,

        -2, -1, 0, 0, -1, 0,
        -2, 0, 0, 0, 0, 0,

        0, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"worm sandwich"},
#endif
	{
        -1, 0, -2, 0, 0, -2,

        -1, -1, -1, 0, -1, -1,
        -2, 0, -1,
        -2, 1, -1, -1, 1, -1, 0, 1, -1,

        -1, -1, 0, 0, -1, 0, 1, -1, 0,
        1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"worm sandwich2"},
#endif
	{
        -1, -1, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -1, 0, -1, 0, 0, -1, 1, 0, -1,

        -2, -2, 0, -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -1, 0, 0, 0, 0, 0,

        0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"triple switch"},
#endif
	{
        -1, 0, -2,

        0, -2, -1,
        -1, -1, -1, 0, -1, -1,
        -1, 0, -1, 1, 0, -1,

        -2, -1, 0, -1, -1, 0,
        -1, 1, 0, 1, 1, 0,
        1, 2, 0,

        0, -1, 1,
        1, 0, 1, 2, 0, 1,
        0, 1, 1, 1, 1, 1,

        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"3 switch"},
#endif
	{
        -1, 0, -2, 0, 0, -2,

        0, -2, -1,
        -1, -1, -1, 1, -1, -1,
        1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"knot switch"},
#endif
	{
        -1, 0, -2,

        0, -2, -1, -1, -1, -1, 0, -1, -1,
        -1, 0, -1, 1, 0, -1,
        -2, -1, 0, -1, -1, 0,
        -1, 1, 0, 1, 1, 0,
        1, 2, 0,

        0, -1, 1,
        1, 0, 1, 2, 0, 1,
        0, 1, 1, 2, 1, 1,
        1, 2, 1,

        0, 1, 2, 1, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"2 arrows"},
#endif
	{
        -2, -1, -1, 1, -1, -1,
        -4, 0, -1, -3, 0, -1, -1, 0, -1, 0, 0, -1, 2, 0, -1, 3, 0, -1,
        -3, 1, -1, 2, 1, -1,

        -2, -1, 0, 1, -1, 0,
        -4, 0, 0, -3, 0, 0, -1, 0, 0, 0, 0, 0, 2, 0, 0, 3, 0, 0,
        -3, 1, 0, 2, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"fat walker"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2, 0, 0, -2,

        -1, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        -1, 1, -1,

        0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        0, 1, 0,

        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"walking box"},
#endif
	{
        -1, -1, -2,
        0, 0, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"spinning box"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2, 0, 0, -2,

        0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1, 0, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"double knot"},
#endif
	{
        -1, -1, -2, 0, -1, -2,

        -1, -2, -1,
        -2, -1, -1, 0, -1, -1,
        -2, 0, -1, -1, 0, -1,
        0, 1, -1,

        -1, -2, 0,
        -1, -1, 0, 1, -1, 0,
        1, 1, 0, 2, 1, 0,

        -1, 0, 1, 1, 0, 1,
        0, 1, 1, 2, 1, 1,
        0, 2, 1, 1, 2, 1,

        1, 0, 2,
        1, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"planetary war"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0,
        -2, -1, 0, 1, -1, 0,
        1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"fat walker2"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2, 0, 0, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0,

        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"pop change"},
#endif
	{
        0, 0, -2,

        0, -1, -1,
        -1, 0, -1, 2, 0, -1,
        0, 1, -1, 1, 1, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -2, 0, 0, 2, 0, 0,
        -1, 2, 0, 0, 2, 0, 1, 2, 0,

        1, -1, 1,
        -1, 0, 1, 2, 0, 1,
        -1, 1, 1, 1, 1, 1,

        0, -1, 2,
        0, 0, 2,
        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"large pile driver"},
#endif
	{
        -1, -2, -1, 0, -2, -1, 1, -2, -1,
        -2, -1, -1, -1, -1, -1, 1, -1, -1, 2, -1, -1,
        -2, 0, -1, 2, 0, -1,
        -2, 1, -1, -1, 1, -1, 1, 1, -1, 2, 1, -1,
        -1, 2, -1, 0, 2, -1, 1, 2, -1,

        0, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -2, 0, 0, 2, 0, 0,
        -1, 1, 0, 1, 1, 0,
        0, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"F"},
#endif
	{
        1, 0, -2, 2, 0, -2,
        -1, 1, -2,
        -1, 2, -2, 1, 2, -2,

        1, -2, -1, 2, -2, -1,
        2, -1, -1,
        2, 0, -1,
        1, 1, -1,
        -1, 2, -1, 1, 2, -1,

        -2, 1, 0,
        -2, 2, 0, -1, 2, 0,

        0, -2, 1, 2, -2, 1,
        -2, -1, 1, 1, -1, 1, 2, -1, 1,
        -1, 1, 1,

        0, -2, 2,
        -2, -1, 2, -1, -1, 2, 0, -1, 2,
        -2, 1, 2, -1, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"4Y"},
#endif
	{
        0, -2, -1,
        -2, 0, -1, 2, 0, -1,
        0, 2, -1,

        -1, -2, 0, 0, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 0, 0, 2, 0, 0,
        -2, 1, 0, 2, 1, 0,
        -1, 2, 0, 0, 2, 0, 1, 2, 0,

        -1, -2, 1, 1, -2, 1,
        -2, -1, 1, 0, -1, 1, 2, -1, 1,
        -1, 0, 1, 1, 0, 1,
        -2, 1, 1, 0, 1, 1, 2, 1, 1,
        -1, 2, 1, 1, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"blob2"},
#endif
	{
        0, 0, -2, 1, 0, -2, 2, 0, -2,
        0, 1, -2, 1, 1, -2,
        1, 2, -2,

        1, -1, -1,
        2, 0, -1,
        -1, 1, -1,
        1, 2, -1,

        0, -2, 0, 1, -2, 0,
        -2, 0, 0,
        -2, 1, 0, 1, 1, 0,
        -2, 2, 0, -1, 2, 0,

        0, -2, 1, 1, -2, 1, 2, -2, 1,
        -1, -1, 1, 2, -1, 1,
        -2, 0, 1, 1, 0, 1,
        -2, 1, 1, 0, 1, 1,

        0, -2, 2,
        0, -1, 2,
        -2, 1, 2, -1, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"stuff"},
#endif
	{
        1, 0, -2, 2, 0, -2,
        0, 1, -2, 1, 1, -2,
        1, 2, -2,

        1, -1, -1, 2, -1, -1,
        2, 0, -1,
        -1, 1, -1,
        -1, 2, -1, 0, 2, -1, 1, 2, -1,

        1, -2, 0,
        2, -1, 0,
        -2, 1, 0,
        -2, 2, 0, -1, 2, 0,

        0, -2, 1, 1, -2, 1, 2, -2, 1,
        -1, -1, 1, 2, -1, 1,
        -2, 0, 1,
        -2, 1, 1,

        0, -2, 2,
        -1, -1, 2, 0, -1, 2,
        -1, 0, 2,
        -2, 1, 2, -1, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"3 fins"},
#endif
	{
        0, -2, -2, 1, -2, -2, 2, -2, -2,
        0, -1, -2, 1, -1, -2, 2, -1, -2,
        -2, 0, -2,
        -2, 1, -2,
        -2, 2, -2,
        1, -1, -1,
        -2, 0, -1,
        -2, 1, -1, -1, 1, -1, 0, 1, -1,
        -2, 2, -1,
        -2, -2, 0, -1, -2, 0,
        1, -1, 0,
        1, 0, 0,
        0, 1, 0, 1, 1, 0,
        -2, -2, 1, -1, -2, 1,
        -1, -1, 1,
        -1, 0, 1, 0, 0, 1, 1, 0, 1,
        0, 1, 1, 1, 1, 1,
        -2, -2, 2, -1, -2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"solitaire"},
#endif
	{
        -1, -3, -1, 0, -3, -1, 1, -3, -1,
        -3, -1, -1, -1, -1, -1, 1, -1, -1, 3, -1, -1,
        -3, 0, -1, 3, 0, -1,
        -3, 1, -1, -1, 1, -1,
        1, 1, -1, 3, 1, -1,
        -1, 3, -1, 0, 3, -1, 1, 3, -1,

        -1, -3, 0, 0, -3, 0, 1, -3, 0,
        -3, -1, 0, -1, -1, 0, 1, -1, 0, 3, -1, 0,
        -3, 0, 0, 3, 0, 0,
        -3, 1, 0, -1, 1, 0,
        1, 1, 0, 3, 1, 0,
        -1, 3, 0, 0, 3, 0, 1, 3, 0,
        127
	},
#ifdef LIFE_NAMES
	{"tic tac toe"},
#endif
	{
        -3, -3, -1, -2, -3, -1, 1, -3, -1, 2, -3, -1,
        -3, -2, -1, 2, -2, -1,
        -3, 1, -1, 2, 1, -1,
        -3, 2, -1, -2, 2, -1, 1, 2, -1, 2, 2, -1,

        -2, -3, 0, 1, -3, 0,
        -3, -2, 0, -2, -2, 0, -1, -2, 0, 0, -2, 0, 1, -2, 0, 2, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -3, 1, 0, -2, 1, 0, -1, 1, 0, 0, 1, 0, 1, 1, 0, 2, 1, 0,
        -2, 2, 0, 1, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"square peg"},
#endif
	{
        -1, -4, -1, 0, -4, -1,
        -1, -3, -1, 0, -3, -1,
        -2, -2, -1, 1, -2, -1,
        -4, -1, -1, -3, -1, -1, -1, -1, -1,
        0, -1, -1, 2, -1, -1, 3, -1, -1,
        -4, 0, -1, -3, 0, -1, -1, 0, -1, 0, 0, -1, 2, 0, -1, 3, 0, -1,
        -2, 1, -1, 1, 1, -1,
        -1, 2, -1, 0, 2, -1,
        -1, 3, -1, 0, 3, -1,

        -1, -3, 0, 0, -3, 0,
        -2, -2, 0, 1, -2, 0,
        -3, -1, 0, 2, -1, 0,
        -3, 0, 0, 2, 0, 0,
        -2, 1, 0, 1, 1, 0,
        -1, 2, 0, 0, 2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"large solitaire"},
#endif
	{
        -1, -5, -1, 0, -5, -1,
        -3, -3, -1, -2, -3, -1, 1, -3, -1, 2, -3, -1,
        -3, -2, -1, 2, -2, -1,
        -5, -1, -1, 4, -1, -1,
        -5, 0, -1, 4, 0, -1,
        -3, 1, -1, 2, 1, -1,
        -3, 2, -1, -2, 2, -1, 1, 2, -1, 2, 2, -1,
        -1, 4, -1, 0, 4, -1,

        -1, -5, 0, 0, -5, 0,
        -3, -3, 0, -2, -3, 0, 1, -3, 0, 2, -3, 0,
        -3, -2, 0, 2, -2, 0,
        -5, -1, 0, 4, -1, 0,
        -5, 0, 0, 4, 0, 0,
        -3, 1, 0, 2, 1, 0,
        -3, 2, 0, -2, 2, 0, 1, 2, 0, 2, 2, 0,
        -1, 4, 0,
        0, 4, 0,
        127
	},
#ifdef LIFE_NAMES
	{"pancake"},
#endif
	{
        -2, -3, -1, 0, -3, -1, 2, -3, -1,
        -3, -2, -1, 3, -2, -1,
        -3, 0, -1, 3, 0, -1,
        -3, 2, -1, 3, 2, -1,
        -2, 3, -1, 0, 3, -1, 2, 3, -1,

        -2, -3, 0, 0, -3, 0, 2, -3, 0,
        -3, -2, 0, -2, -2, 0, 2, -2, 0, 3, -2, 0,
        -3, 0, 0, 3, 0, 0,
        -3, 2, 0, -2, 2, 0, 2, 2, 0, 3, 2, 0,
        -2, 3, 0, 0, 3, 0, 2, 3, 0,

        -2, -3, 1, 0, -3, 1, 2, -3, 1,
        -3, -2, 1, 3, -2, 1,
        -3, 0, 1, 3, 0, 1,
        -3, 2, 1, 3, 2, 1,
        -2, 3, 1, 0, 3, 1, 2, 3, 1,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"contained (p3)"},
#endif
	{
        -2, -2, -3, -1, -2, -3,
        -2, -1, -3,

        -2, -3, -2, -1, -3, -2,
        -3, -2, -2, 0, -2, -2,
        -3, -1, -2, 0, -1, -2,
        -2, 0, -2, -1, 0, -2,

        -2, -3, -1,
        -3, -2, -1, 0, -2, -1,
        -1, -1, -1, 1, -1, -1,
        -2, 0, -1,
        -1, 1, -1, 1, 1, -1,

        -2, -2, 0, -1, -2, 0,
        -2, -1, 0,
        2, 1, 0,
        1, 2, 0, 2, 2, 0,

        -1, -1, 1, 1, -1, 1,
        2, 0, 1,
        -1, 1, 1, 1, 1, 1,
        0, 2, 1, 3, 2, 1,
        2, 3, 1,

        1, 0, 2, 2, 0, 2,
        0, 1, 2, 3, 1, 2,
        0, 2, 2, 3, 2, 2,
        1, 3, 2, 2, 3, 2,

        2, 1, 3,
        1, 2, 3, 2, 2, 3,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"box (p3)"},
#endif
	{
        -2, -1, -3,
        1, 0, -3,

        -1, -3, -2,
        -2, -2, -2, -1, -2, -2, 0, -2, -2, 1, -2, -2,
        -2, -1, -2, 1, -1, -2,
        -2, 0, -2, 1, 0, -2,
        -2, 1, -2, -1, 1, -2, 0, 1, -2, 1, 1, -2,
        0, 2, -2,

        -3, -2, -1, -2, -2, -1, 1, -2, -1,
        -2, 1, -1, 1, 1, -1, 2, 1, -1,

        -2, -2, 0, 1, -2, 0, 2, -2, 0,
        -3, 1, 0, -2, 1, 0, 1, 1, 0,

        0, -3, 1,
        -2, -2, 1, -1, -2, 1, 0, -2, 1, 1, -2, 1,
        -2, -1, 1, 1, -1, 1,
        -2, 0, 1, 1, 0, 1,
        -2, 1, 1, -1, 1, 1, 0, 1, 1, 1, 1, 1,
        -1, 2, 1,

        1, -1, 2,
        -2, 0, 2,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"arrow beacon (p4)"},
#endif
	{
        1, -2, -2,
        1, -1, -2, 2, -1, -2,
        0, 0, -2,

        1, -2, -1,
        1, -1, -1, 2, -1, -1,
        0, 0, -1,

        -2, 1, 0,
        -2, 2, 0, -1, 2, 0,

        -2, 1, 1, -1, 1, 1,
        -2, 2, 1, -1, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"sticks (p4)"},
#endif
	{
        0, 0, -2, 2, 0, -2,
        0, 1, -2,
        0, 2, -2,

        1, -1, -1,
        2, 0, -1,
        -1, 1, -1, 1, 1, -1,

        0, -2, 0, 1, -2, 0, 2, -2, 0,
        -2, 0, 0, 2, 0, 0,
        -2, 2, 0, -1, 2, 0, 0, 2, 0,

        -1, -1, 1, 1, -1, 1,
        -2, 0, 1,
        -1, 1, 1,

        0, -2, 2,
        0, -1, 2,
        -2, 0, 2, 0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"demanding (p4)"},
#endif
	{
        0, -2, -3,

        0, -3, -2,
        -1, -2, -2, 1, -2, -2,
        0, -1, -2,

        1, -4, -1,
        -1, -3, -1, 2, -3, -1,
        -2, -1, -1, 1, -1, -1,
        -1, 0, -1,

        1, -4, 0,
        -1, -3, 0, 2, -3, 0,
        -2, -1, 0, 1, -1, 0,
        -1, 0, 0,

        1, -4, 1,
        0, -3, 1, 2, -3, 1,
        -1, -2, 1, 0, -2, 1, 1, -2, 1,
        -2, -1, 1, 0, -1, 1,
        -1, 0, 1,

        0, -2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"blob (p4)"},
#endif
	{
        -1, -1, -2, 1, -1, -2,
        -1, 0, -2, 1, 0, -2,
        -1, 1, -2,

        -1, -2, -1, 0, -2, -1, 1, -2, -1,
        -2, -1, -1,
        2, 0, -1,
        -2, 1, -1, 1, 1, -1,
        0, 2, -1,

        -2, -1, 0, 2, -1, 0,
        2, 0, 0,
        -2, 1, 0,
        -1, 2, 0, 0, 2, 0,

        -1, -2, 1, 0, -2, 1,
        -2, -1, 1, 1, -1, 1,
        -1, 1, 1, 1, 1, 1,

        0, -1, 2,
        -1, 0, 2, 0, 0, 2,
        127
	},
#ifdef LIFE_NAMES
	{"pump (p4)"},
#endif
	{
        -1, -1, -2, 1, -1, -2,
        -1, 1, -2, 1, 1, -2,

        0, -1, -1,
        -1, 0, -1, 1, 0, -1,
        0, 1, -1,

        -1, -2, 0, 0, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 0, 0, 2, 0, 0,
        -2, 1, 0, 2, 1, 0,
        -1, 2, 0, 0, 2, 0, 1, 2, 0,

        -1, -1, 1, 0, -1, 1, 1, -1, 1,
        -1, 0, 1, 1, 0, 1,
        -1, 1, 1, 0, 1, 1, 1, 1, 1,

        0, -1, 2,
        -1, 0, 2, 1, 0, 2,
        0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"tomato sandwich (p4)"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -2, 0, -2, 1, 0, -2,
        -1, 1, -2, 0, 1, -2,

        -1, -2, -1, 0, -2, -1,
        -1, 2, -1, 0, 2, -1,

        -2, -2, 0, 1, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -3, 0, 0, 2, 0, 0,
        -2, 1, 0, 1, 1, 0,
        -2, 2, 0, 1, 2, 0,

        -1, -2, 1, 0, -2, 1,
        -1, 2, 1, 0, 2, 1,

        -1, -1, 2, 0, -1, 2,
        -2, 0, 2, 1, 0, 2,
        -1, 1, 2, 0, 1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"L-gate (p4)"},
#endif
	{
        0, -5, -1,
        0, -4, -1,
        1, -3, -1,
        -2, -2, -1,
        -4, -1, -1, -3, -1, -1, 3, -1, -1, 4, -1, -1,
        2, 0, -1,
        -1, 1, -1,
        0, 2, -1,
        0, 3, -1,

        0, -5, 0,
        0, -4, 0,
        -1, -3, 0, 0, -3, 0, 1, -3, 0,
        -2, -2, 0, 2, -2, 0,
        -4, -1, 0, -3, -1, 0, -2, -1, 0, 2, -1, 0, 3, -1, 0, 4, -1, 0,
        -2, 0, 0, 2, 0, 0,
        -1, 1, 0, 0, 1, 0, 1, 1, 0,
        0, 2, 0,
        0, 3, 0,
        127
	},
#ifdef LIFE_NAMES
	{"corner (p4)"},
#endif
	{
        1, 1, -3,
        1, 2, -3,

        1, 1, -2, 2, 1, -2,
        1, 2, -2, 2, 2, -2,

        1, 1, -1,
        2, 2, -1,

        1, 2, 0, 2, 2, 0,

        1, -3, 1, 2, -3, 1,
        1, -2, 1, 2, -2, 1,
        1, -1, 1,
        2, 0, 1,
        -3, 1, 1, -2, 1, 1, -1, 1, 1, 3, 1, 1,
        -2, 2, 1,
        1, 3, 1, 2, 3, 1,

        1, -2, 2, 2, -2, 2,
        2, -1, 2,
        2, 0, 2,
        -3, 1, 2, -2, 1, 2, 0, 1, 2, 3, 1, 2,
        -2, 2, 2, -1, 2, 2, 0, 2, 2, 2, 2, 2,

        1, 1, 3,
        1, 2, 3,
        127
	},
#ifdef LIFE_NAMES
	{"corner2 (p4)"},
#endif
	{
        -2, -1, -3, -1, -1, -3,

        -1, -3, -2,
        -2, -2, -2, 0, -2, -2, 2, -2, -2, 3, -2, -2,
        1, -1, -2, 2, -1, -2,
        -2, 0, -2, -1, 0, -2,
        -1, 1, -2,
        -2, 2, -2, -1, 2, -2,
        -2, 3, -2, -1, 3, -2,

        -1, -3, -1,
        -3, -2, -1, 0, -2, -1, 1, -2, -1, 2, -2, -1, 3, -2, -1,
        -3, -1, -1, 2, -1, -1,
        -2, 1, -1,
        -2, 2, -1, -1, 2, -1,

        -2, -2, 0,
        -2, -1, 0,

        -1, -2, 1,
        -2, -1, 1,

        -2, -2, 2, -1, -2, 2,
        -2, -1, 2, -1, -1, 2,

        -2, -2, 3,
        -2, -1, 3,
        127
	},
#ifdef LIFE_NAMES
	{"shuttlecock (p8)"},
#endif
	{
        -1, -2, -3,
        -2, -1, -3, 0, -1, -3,

        -1, -3, -2,
        -2, -2, -2, 0, -2, -2,
        -3, -1, -2, 1, -1, -2,
        -2, 0, -2,
        -1, 1, -2, 0, 1, -2,
        1, 1, -2,

        -2, -3, -1,
        -3, -2, -1, 1, -2, -1,
        1, -1, -1,
        -3, 0, -1, 1, 0, -1,
        -2, 1, -1, -1, 1, -1,
        0, 2, -1,

        -1, -3, 0,
        -2, -2, 0, 1, -2, 0,
        2, -1, 0,
        -1, 1, 0, 1, 1, 0,

        -1, -2, 1, 1, -2, 1,
        -2, -1, 1, -1, -1, 1,
        0, -1, 1,
        -2, 0, 1, 1, 0, 1,
        -2, 1, 1, 0, 1, 1,

        -1, 0, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"block (stable)"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
        -1, 0, -1, 0, 0, -1,

        -1, -1, 0, 0, -1, 0,
        -1, 0, 0, 0, 0, 0,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"pillow (stable)"},
#endif
	{
        -1, -2, -2, 0, -2, -2,
        -1, -1, -2, 0, -1, -2,

        -1, -3, -1, 0, -3, -1,
        -2, -2, -1, 1, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -1, 0, -1, 0, 0, -1,

        -1, -2, 0, 0, -2, 0,
        -1, -1, 0, 0, -1, 0,
        127
	},
#endif
};

static char patterns_26S678B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider 1 (14 cell diagonal, p2)"},
#endif
	{
        -1, -1, -1, -1, -1, 0,
        -1, 0, -2, -1, 0, -1, -1, 0, 0, -1, 0, 1,

        0, -1, -1, 0, -1, 0,
        0, 0, -1, 0, 0, 0,

        1, 0, -1, 1, 0, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"glider 2 (16 cell, c/3, p3)"},
#endif
	{
        -1, -1, -1, -1, -1, 1,
        -1, 1, -1, -1, 1, 1,

        0, -2, -1, 0, -2, 1,
        0, -1, -2, 0, -1, 0, 0, -1, 2,
        0, 0, -1, 0, 0, 1,
        0, 1, -2, 0, 1, 0, 0, 1, 2,
        0, 2, -1, 0, 2, 1,
        127
	},
#ifdef LIFE_NAMES
	{"glider 3 (24 cell diagonal, p2)"},
#endif
	{
        -2, 0, -1, -2, 0, 0,
        -2, 1, -2, -2, 1, -1, -2, 1, 0, -2, 1, 1,

        -1, 0, -1, -1, 0, 0,
        -1, 1, -1, -1, 1, 0,

        0, -2, -1, 0, -2, 0,
        0, -1, -1, 0, -1, 0,
        0, 2, -2, 0, 2, 1,

        1, -2, -2, 1, -2, -1, 1, -2, 0, 1, -2, 1,
        1, -1, -1, 1, -1, 0,

        2, 0, -2, 2, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"orth glider (24 cell, c/2, p4)"},
#endif
	{
        0, -3, -1,
        -2, -2, -1,
        1, -1, -1,
        -1, 0, -1,

        -1, -4, 0, 0, -4, 0,
        -2, -3, 0, -1, -3, 0, 0, -3, 0, 1, -3, 0,
        -3, -2, 0, -2, -2, 0, 1, -2, 0, 2, -2, 0,
        -3, -1, 0, -2, -1, 0, 1, -1, 0, 2, -1, 0,
        -2, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"C"},
#endif
	{
        0, -1, -1, 0, -1, 0,
        0, 0, -1,
        0, 1, -1, 0, 1, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"arrow"},
#endif
	{
        -1, -1, -1,
        0, 0, -1, 1, 0, -1,
        0, 1, -1,

        -1, -1, 0,
        1, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"little runner"},
#endif
	{
        0, -1, -1,
        0, 0, -1,
        -1, 1, -1,

        -1, -1, 0,
        -1, 0, 0, 0, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"s"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
        0, 0, -1, 1, 0, -1,

        -1, -1, 0,
        0, 0, 0, 1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"rower"},
#endif
	{
        -1, -1, -1,
        -1, 0, -1, 0, 0, -1,
        -1, 1, -1,

        0, -1, 0,
        -1, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"corner"},
#endif
	{
        1, -1, -1,
        0, 0, -1, 1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        1, 0, 0,
        0, 1, 0, 1, 1, 0,
        1, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2C"},
#endif
	{
        1, -2, -1,
        -1, -1, -1,
        -1, 0, -1, 1, 0, -1,
        -1, 1, -1,

        1, -2, 0,
        -1, -1, 0, 1, -1, 0,
        1, 0, 0,
        -1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"deformed runner"},
#endif
	{
        0, -1, -2, 1, -1, -2,

        0, -1, -1,
        0, 0, -1,
        -1, 1, -1,

        0, -2, 0,
        -1, -1, 0,
        -1, 0, 0,

        -2, 0, 1, -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2 friends"},
#endif
	{
        0, -2, -2,
        -1, -1, -2,
        0, -1, -2,
        -1, -1, -1, 0, -1, -1,
        -1, 0, 0, 0, 0, 0,
        -1, 1, 0, 0, 1, 0,
        0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"2 friends2"},
#endif
	{
        -1, -1, -2,

        -2, -1, -1, -1, -1, -1,
        -2, 0, -1, -1, 0, -1,

        0, -1, 0,
        0, 0, 0, 1, 0, 0,

        0, -1, 1,
        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"bird"},
#endif
	{
        -1, -1, -1, 0, -1, -1,
        -2, 0, -1, 0, 0, -1, 1, 0, -1,

        -1, -1, 0, 0, -1, 0,
        -2, 0, 0, -1, 0, 0, 1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"bug jumping jack"},
#endif
	{
        0, -1, -2, 1, -1, -2,
        0, -1, -1,
        0, 0, -1,
        -1, 1, -1,
        0, -2, 0,
        -1, -1, 0,
        -1, 0, 0,
        -2, 0, 1, -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"dali clock"},
#endif
	{
        0, 0, -2,

        0, -2, -1,
        -2, -1, -1, 0, -1, -1,
        0, 0, -1,

        -1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -1, 1, 0,

        -1, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"deformed walker"},
#endif
	{
        -1, -2, -1,
        -2, -1, -1, -1, -1, -1,
        0, 0, -1, 1, 0, -1,

        -2, -2, 0,
        -1, -1, 0,
        0, 0, 0,
        0, 1, 0, 1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"flattened snake"},
#endif
	{
        -2, 0, -1, -1, 0, -1, 0, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -1, -1, 0, 0, -1, 0, 1, -1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"open_wide"},
#endif
	{
        -1, -1, -2,

        -1, -1, -1, 0, -1, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -1, 0, 0, -1, 0,
        -1, 1, 0, 0, 1, 0,

        0, 1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"peek-a-boo"},
#endif
	{
        0, 0, -2,

        -1, 0, -1, 0, 0, -1,
        -1, 1, -1, 0, 1, -1,

        0, -2, 0,
        -1, -1, 0, 0, -1, 0,

        -1, -1, 1, 0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"roll over"},
#endif
	{
        -1, -2, -1,
        -2, -1, -1, 0, -1, -1,
        -1, 0, -1, 1, 0, -1,
        0, 1, -1,

        -1, -1, 0, 0, -1, 0,
        -1, 0, 0, 0, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"switch"},
#endif
	{
        0, -1, -1,
        0, 0, -1,

        0, -2, 0,
        0, -1, 0,
        -1, 0, 0,
        0, 1, 0,

        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"tiny star"},
#endif
	{
        -1, 0, -1, 0, 0, -1,
        0, 1, -1,

        1, -1, 0,
        -1, 0, 0, 1, 0, 0,
        -1, 1, 0,

        0, -1, 1,
        0, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"confused pile driver"},
#endif
	{
        0, -1, -1, 1, -1, -1,
        -1, 0, -1, 1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -1, 0, 0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0, 1, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"small pump"},
#endif
	{
        -1, 1, 0, 0, 1, 0,
        -2, 0, 0, 0, 0, 0, 1, 0, 0,
        -2, -1, 0, -1, -1, 0, 1, -1, 0,
        -1, -2, 0, 0, -2, 0,

        0, 0, 1,
        -1, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"spinning table"},
#endif
	{
        -1, -1, -2,
        -1, 0, -2,
        0, -2, -1,
        -1, -1, -1,
        -1, 0, -1,
        0, 1, -1,
        0, -2, 0,
        -1, -1, 0,
        -1, 0, 0,
        0, 1, 0,
        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"opposing rowers"},
#endif
	{
        0, 2, -1,
        -1, 1, -1, 0, 1, -1, 1, 1, -1,
        -1, -1, -1, 0, -1, -1, 1, -1, -1,
        0, -2, -1,

        0, 2, 0,
        -1, 1, 0, 1, 1, 0,
        -1, -1, 0, 1, -1, 0,
        0, -2, 0,
        127
	},
#ifdef LIFE_NAMES
	{"flower"},
#endif
	{
        -1, 1, -1, 0, 1, -1,
        -2, 0, -1, -1, 0, -1, 0, 0, -1, 1, 0, -1,
        -2, -1, -1, -1, -1, -1, 0, -1, -1, 1, -1, -1,
        -1, -2, -1, 0, -2, -1,

        -1, 0, 1, 0, 0, 1,
        -1, -1, 1, 0, -1, 1,

        -1, 0, 2, 0, 0, 2,
        -1, -1, 2, 0, -1, 2,
        127
	},
#ifdef LIFE_NAMES
	{"compressor"},
#endif
	{
        0, 2, -2,
        0, 1, -2,
        -2, 0, -2, -1, 0, -2, 1, 0, -2, 2, 0, -2,
        0, -1, -2,
        0, -2, -2,

        -1, 1, -1, 0, 1, -1, 1, 1, -1,
        -1, 0, -1, 1, 0, -1,
        -1, -1, -1, 0, -1, -1, 1, -1, -1,

        -1, 1, 1, 0, 1, 1, 1, 1, 1,
        -1, 0, 1, 1, 0, 1,
        -1, -1, 1, 0, -1, 1, 1, -1, 1,

        0, 2, 2,
        0, 1, 2,
        -2, 0, 2, -1, 0, 2, 1, 0, 2, 2, 0, 2,
        0, -1, 2,
        0, -2, 2,
        127
	},
#ifdef LIFE_NAMES
	{"pump"},
#endif
	{
        -1, 2, 0, 0, 2, 0, 1, 2, 0,
        -2, 1, 0, 0, 1, 0, 2, 1, 0,
        -2, 0, 0, -1, 0, 0, 1, 0, 0, 2, 0, 0,
        -2, -1, 0, 0, -1, 0, 2, -1, 0,
        -1, -2, 0, 0, -2, 0, 1, -2, 0,

        0, 1, 1,
        -1, 0, 1, 1, 0, 1,
        0, -1, 1,
        127
	},
#ifdef LIFE_NAMES
	{"H (p3)"},
#endif
	{
        -1, 0, -1, 1, 0, -1,

        -1, 0, 0, 0, 0, 0, 1, 0, 0,

        -1, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"waving tail (p3)"},
#endif
	{
        -1, -1, -1, 0, -1, -1, 1, -1, -1,

        -1, 0, -1, 0, 0, -1, 1, 0, -1,

        0, -1, 0,
        0, 0, 0, 1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"bagel (p3)"},
#endif
	{
        -1, -2, -2, 0, -2, -2, 1, -2, -2,
        -1, -1, -2, 1, -1, -2,
        -1, 0, -2, 0, 0, -2, 1, 0, -2,

        -1, -3, -1, 1, -3, -1,
        -2, -2, -1, -1, -2, -1, 1, -2, -1, 2, -2, -1,
        -2, 0, -1, -1, 0, -1, 1, 0, -1, 2, 0, -1,
        -1, 1, -1, 1, 1, -1,

        -1, -2, 0, 0, -2, 0, 1, -2, 0,
        -1, -1, 0, 1, -1, 0,
        -1, 0, 0, 0, 0, 0, 1, 0, 0,
        127
	},
#ifdef LIFE_NAMES
	{"big corner (p3)"},
#endif
	{
        1, -1, -2, 2, -1, -2,
        1, -2, -2,

        1, 0, -1, 2, 0, -1,
        0, -1, -1,
        0, -2, -1,

        1, 1, 0, 2, 1, 0,
        -1, -1, 0, 1, -1, 0,
        -1, -2, 0,

        1, 2, 1, 2, 2, 1,
        0, 1, 1,
        -1, 0, 1, 1, 0, 1,
        -2, -1, 1, 0, -1, 1,
        -2, -2, 1,

        1, 2, 2,
        0, 1, 2,
        -1, 0, 2,
        -2, -1, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"box (p3)"},
#endif
	{
        -1, -3, -4, 0, -3, -4,
        -1, -2, -4, 0, -2, -4,

        -2, -5, -3, 1, -5, -3,
        -3, -4, -3, 2, -4, -3,
        -3, -1, -3, 2, -1, -3,
        -2, 0, -3, 1, 0, -3,

        -3, -5, -2, 2, -5, -2,
        -1, -3, -2, 0, -3, -2,
        -1, -2, -2, 0, -2, -2,
        -3, 0, -2, 2, 0, -2,

        -1, -6, -1, 0, -6, -1,
        -1, -4, -1, 0, -4, -1,
        -4, -3, -1, -2, -3, -1, 1, -3, -1, 3, -3, -1,
        -4, -2, -1, -2, -2, -1, 1, -2, -1, 3, -2, -1,
        -1, -1, -1, 0, -1, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -6, 0, 0, -6, 0,
        -1, -4, 0, 0, -4, 0,
        -4, -3, 0, -2, -3, 0, 1, -3, 0, 3, -3, 0,
        -4, -2, 0, -2, -2, 0, 1, -2, 0, 3, -2, 0,
        -1, -1, 0, 0, -1, 0,
        -1, 1, 0, 0, 1, 0,

        -3, -5, 1, 2, -5, 1,
        -1, -3, 1, 0, -3, 1,
        -1, -2, 1, 0, -2, 1,
        -3, 0, 1, 2, 0, 1,

        -2, -5, 2, 1, -5, 2,
        -3, -4, 2, 2, -4, 2,
        -3, -1, 2, 2, -1, 2,
        -2, 0, 2, 1, 0, 2,

        -1, -3, 3, 0, -3, 3,
        -1, -2, 3, 0, -2, 3,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"door swing (p4)"},
#endif
	{
        0, -1, -1,
        0, 0, -1,

        0, -2, 0,
        -1, -1, 0, 0, -1, 0,
        0, 0, 0,
        0, 1, 0,

        -1, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"legs (p4)"},
#endif
	{
        -1, -1, -2,
        -1, 0, -2,

        -1, -2, -1,
        -1, -1, -1,
        0, 0, -1,

        0, -1, 0,
        -1, 0, 0,
        -1, 1, 0,

        -1, -1, 1,
        -1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"monroe (p4)"},
#endif
	{
        0, -1, -2,

        0, -2, -1,
        -1, -1, -1,
        0, 0, -1,
        0, 1, -1,

        0, -2, 0,
        0, -1, 0,
        -1, 0, 0,
        0, 1, 0,

        0, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"4C (p4)"},
#endif
	{
        -3, -3, -1, -2, -3, -1, -1, -3, -1, 0, -3, -1, 1, -3, -1, 2, -3, -1,
        -3, -2, -1, -1, -2, -1, 0, -2, -1, 2, -2, -1,
        -3, 0, -1, -1, 0, -1, 0, 0, -1, 2, 0, -1,
        -3, 1, -1, -2, 1, -1, -1, 1, -1, 0, 1, -1, 1, 1, -1, 2, 1, -1,
        127
	},
#ifdef LIFE_NAMES
	{"mirror image (p6)"},
#endif
	{
        0, -1, -1, 1, -1, -1,
        0, 1, -1, 1, 1, -1,

        -1, -2, 0, 0, -2, 0, 1, -2, 0,
        -1, -1, 0, 0, -1, 0,
        -1, 1, 0, 0, 1, 0,
        -1, 2, 0, 0, 2, 0, 1, 2, 0,
        127
	},
};

static char patterns_26S8B5[][3 * NUMPTS + 1] =
{
#if 0
#ifdef LIFE_NAMES
	{"glider (diagonal, p2)"},
#endif
	{
        1, 0, 0, 2, 0, 0,

        1, 0, 1, 2, 0, 1,
        1, 1, 1, 2, 1, 1,

        0, 0, 2, 1, 0, 2, 2, 0, 2, 3, 0, 2,
        1, 1, 2, 2, 1, 2,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"double glider (diagonal, p2)"},
#endif
	{
        -1, -1, -3, 0, -1, -3,

        -1, -2, -2, 0, -2, -2,
        -1, -1, -2, 0, -1, -2,
        -1, 1, -2, 0, 1, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1, -1, -1, -1, 0, -1, -1, 1, -1, -1,
        -1, 2, -1, 0, 2, -1,

        -2, 1, 1, -1, 1, 1, 0, 1, 1, 1, 1, 1,
        -1, 2, 1, 0, 2, 1,
        -1, 3, 1, 0, 3, 1,

        -1, 1, 2, 0, 1, 2,
        -1, 2, 2, 0, 2, 2,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"C"},
#endif
	{
        0, -1, -1, 0, -1, 0,
        0, 0, -1,
        0, 1, -1, 0, 1, 0,
        127
	},
#endif
#ifdef LIFE_NAMES
	{"AV"},
#endif
	{
        -1, -1, -1, 1, -1, -1,
        -1, 0, -1, 1, 0, -1,

        1, -2, 0,
        -1, 1, 0,

        -1, -1, 1, 1, -1, 1,
        -1, 0, 1, 1, 0, 1,
        127
	},
#ifdef LIFE_NAMES
	{"pump"},
#endif
	{
        -1, -2, -1, 0, -2, -1, 1, -2, -1,
        -2, -1, -1, 0, -1, -1, 2, -1, -1,
        -2, 0, -1, -1, 0, -1, 1, 0, -1, 2, 0, -1,
        -2, 1, -1, 0, 1, -1, 2, 1, -1,
        -1, 2, -1, 0, 2, -1, 1, 2, -1,

        0, -1, 0,
        -1, 0, 0, 1, 0, 0,
        0, 1, 0,
        127
	},
#ifdef LIFE_NAMES
	{"box"},
#endif
	{
        -1, -1, -2, 0, -1, -2,
        -1, 0, -2, 0, 0, -2,

        -1, -2, -1, 0, -2, -1,
        -2, -1, -1, 1, -1, -1,
        -2, 0, -1, 1, 0, -1,
        -1, 1, -1, 0, 1, -1,

        -1, -2, 0, 0, -2, 0,
        -2, -1, 0, 1, -1, 0,
        -2, 0, 0, 1, 0, 0,
        -1, 1, 0, 0, 1, 0,

        -1, -1, 1, 0, -1, 1,
        -1, 0, 1, 0, 0, 1,
        127
	},
#if 0
#ifdef LIFE_NAMES
	{"box48"},
#endif
	{
        -1, -1, -2, 0, -1, -2, 1, -1, -2,
        -1, 0, -2, 1, 0, -2,
        -1, 1, -2, 0, 1, -2, 1, 1, -2,

        -1, -2, -1, 0, -2, -1, 1, -2, -1,
        -2, -1, -1, 2, -1, -1,
        -2, 0, -1, 2, 0, -1,
        -2, 1, -1, 2, 1, -1,
        -1, 2, -1, 0, 2, -1, 1, 2, -1,

        -1, -2, 0, 1, -2, 0,
        -2, -1, 0, 2, -1, 0,
        -2, 1, 0, 2, 1, 0,
        -1, 2, 0, 1, 2, 0,

        -1, -2, 1, 0, -2, 1, 1, -2, 1,
        -2, -1, 1, 2, -1, 1,
        -2, 0, 1, 2, 0, 1,
        -2, 1, 1, 2, 1, 1,
        -1, 2, 1, 0, 2, 1, 1, 2, 1,

        -1, -1, 2, 0, -1, 2, 1, -1, 2,
        -1, 0, 2, 1, 0, 2,
        -1, 1, 2, 0, 1, 2, 1, 1, 2,
        127
	},
#endif
#if 0
#ifdef LIFE_NAMES
	{"ball72"},
#endif
	{
        -1, -2, -4, 0, -2, -4,
        -3, -1, -4, 2, -1, -4,
        -3, 0, -4, 2, 0, -4,
        -1, 1, -4, 0, 1, -4,

        -1, -4, -3, 0, -4, -3,
        -2, -3, -3, 1, -3, -3,
        -3, -2, -3, 2, -2, -3,
        -3, 1, -3, 2, 1, -3,
        -2, 2, -3, 1, 2, -3,
        -1, 3, -3, 0, 3, -3,

        -3, -3, -2, 2, -3, -2,
        -4, -1, -2, 3, -1, -2,
        -4, 0, -2, 3, 0, -2,
        -3, 2, -2, 2, 2, -2,

        -2, -4, -1, 1, -4, -1,
        -4, -3, -1, 3, -3, -1,
        -4, 2, -1, 3, 2, -1,
        -2, 3, -1, 1, 3, -1,

        -2, -4, 0, 1, -4, 0,
        -4, -3, 0, 3, -3, 0,
        -4, 2, 0, 3, 2, 0,
        -2, 3, 0, 1, 3, 0,

        -3, -3, 1, 2, -3, 1,
        -4, -1, 1, 3, -1, 1,
        -4, 0, 1, 3, 0, 1,
        -3, 2, 1, 2, 2, 1,

        -1, -4, 2, 0, -4, 2,
        -2, -3, 2, 1, -3, 2,
        -3, -2, 2, 2, -2, 2,
        -3, 1, 2, 2, 1, 2,
        -2, 2, 2, 1, 2, 2,
        -1, 3, 2, 0, 3, 2,

        -1, -2, 3, 0, -2, 3,
        -3, -1, 3, 2, -1, 3,
        -3, 0, 3, 2, 0, 3,
        -1, 1, 3, 0, 1, 3,
        127
	},
#endif
};
/* Above generated from java Life3DForms | dos2unix */
/* http://www.tux.org/~bagleyd/life.html */

#ifdef LIFE_NAMES
#define PAT_SPACE 2
#else
#define PAT_SPACE 1
#endif

static int  patterns_12rules[] =
{
	(sizeof patterns_12S3B3 / sizeof patterns_12S3B3[0]) / PAT_SPACE,
	(sizeof patterns_12S456B3 / sizeof patterns_12S456B3[0]) / PAT_SPACE,
};

static int  patterns_14rules[] =
{
	(sizeof patterns_14S34B4 / sizeof patterns_14S34B4[0]) / PAT_SPACE,
	(sizeof patterns_14S34B46 / sizeof patterns_14S34B46[0]) / PAT_SPACE,
	(sizeof patterns_14S56B45 / sizeof patterns_14S56B45[0]) / PAT_SPACE,
};

static int  patterns_18rules[] =
{
	(sizeof patterns_18S45B4 / sizeof patterns_18S45B4[0]) / PAT_SPACE,
};

static int  patterns_20rules[] =
{
	(sizeof patterns_20S45B4 / sizeof patterns_20S45B4[0]) / PAT_SPACE,
};

static int  patterns_26rules[] =
{
	(sizeof patterns_26S23B5 / sizeof patterns_26S23B5[0]) / PAT_SPACE,
	(sizeof patterns_26S25B5 / sizeof patterns_26S25B5[0]) / PAT_SPACE,
	(sizeof patterns_26S27B5 / sizeof patterns_26S27B5[0]) / PAT_SPACE,
	(sizeof patterns_26S35B5 / sizeof patterns_26S35B5[0]) / PAT_SPACE,
	(sizeof patterns_26S36B5 / sizeof patterns_26S36B5[0]) / PAT_SPACE,
	(sizeof patterns_26S37B5 / sizeof patterns_26S37B5[0]) / PAT_SPACE,
	(sizeof patterns_26S38B5 / sizeof patterns_26S38B5[0]) / PAT_SPACE,
	(sizeof patterns_26S4B5 / sizeof patterns_26S4B5[0]) / PAT_SPACE,
	(sizeof patterns_26S45B5 / sizeof patterns_26S45B5[0]) / PAT_SPACE,
	(sizeof patterns_26S47B5 / sizeof patterns_26S47B5[0]) / PAT_SPACE,
	(sizeof patterns_26S56B5 / sizeof patterns_26S56B5[0]) / PAT_SPACE,
	(sizeof patterns_26S567B6 / sizeof patterns_26S567B6[0]) / PAT_SPACE,
	(sizeof patterns_26S57B6 / sizeof patterns_26S57B6[0]) / PAT_SPACE,
	(sizeof patterns_26S58B5 / sizeof patterns_26S58B5[0]) / PAT_SPACE,
	(sizeof patterns_26S678B5 / sizeof patterns_26S678B5[0]) / PAT_SPACE,
	(sizeof patterns_26S8B5 / sizeof patterns_26S8B5[0]) / PAT_SPACE,
	(sizeof patterns_26S67B67 / sizeof patterns_26S67B67[0]) / PAT_SPACE,
};

/*static paramstruct param_6rules[] =
{
};

static paramstruct param_8rules[] =
{
};*/

static paramstruct param_12rules[] =
{
	{0x8, 0x8}, /* LIFE_12S3B3 */
	{0x70, 0x8} /* LIFE_12S456B3 */
};

static paramstruct param_14rules[] =
{
	{0x18, 0x10}, /* LIFE_14S34B4 */
	{0x18, 0x50}, /* LIFE_14S34B46 */
	{0x60, 0x30} /* LIFE_14S56B45 */
};

/*static paramstruct param_-14rules[] =
{
};*/

static paramstruct param_18rules[] =
{
	{0x30, 0x10} /* LIFE_18S45B4 */
};

static paramstruct param_20rules[] =
{
	{0x30, 0x10} /* LIFE_20S45B4 */
};

static paramstruct param_26rules[] =
{
	{0xC, 0x20}, /* LIFE_26S23B5 */
	{0x24, 0x20}, /* LIFE_26S25B5 */
	{0x84, 0x20}, /* LIFE_26S27B5 */
	{0x28, 0x20}, /* LIFE_26S35B5 */
	{0x48, 0x20}, /* LIFE_26S36B5 */
	{0x88, 0x20}, /* LIFE_26S37B5 */
	{0x108, 0x20}, /* LIFE_26S38B5 */
	{0x10, 0x20}, /* LIFE_26S4B5 */
	{0x30, 0x20}, /* LIFE_26S45B5 */
	{0x90, 0x20}, /* LIFE_26S47B5 */
	{0x60, 0x20}, /* LIFE_26S56B5 */
	{0xE0, 0x40}, /* LIFE_26S567B6 */
	{0xA0, 0x40}, /* LIFE_26S57B6 */
	{0x120, 0x20}, /* LIFE_26S58B5 */
	{0x1C0, 0x20}, /* LIFE_26S678B5 */
	{0x100, 0x20}, /* LIFE_26S8B5 */
	{0xC0, 0xC0}, /* LIFE_26S67B67 */
};

#define LIFE_12S3B3 0
#define LIFE_12S456B3 1
#define LIFE_12GLIDERS 2
#define LIFE_14S34B4 0
#define LIFE_14S34B46 1
#define LIFE_14GLIDERS 2
#define LIFE_14S56B45 2
#define LIFE_18S45B4 0
#define LIFE_18GLIDERS 1
#define LIFE_20S45B4 0
#define LIFE_20GLIDERS 1
#define LIFE_26S23B5 0
#define LIFE_26S25B5 1
#define LIFE_26S27B5 2
#define LIFE_26S35B5 3
#define LIFE_26S36B5 4
#define LIFE_26S37B5 5
#define LIFE_26S38B5 6
#define LIFE_26S4B5 7
#define LIFE_26S45B5 8
#define LIFE_26S47B5 9
#define LIFE_26S56B5 10
#define LIFE_26S567B6 11 /* S57/B6 also contains the glider */
#define LIFE_26S57B6 12
#define LIFE_26S58B5 13
#define LIFE_26S678B5 14
#define LIFE_26S8B5 15  /* S678/B5 also contains the glider + more osc */
#define LIFE_26GLIDERS 16	/* GLIDER rules are first in param_26rules */
#define LIFE_26S67B67 16

#define LIFE_12RULES (sizeof patterns_12rules / sizeof patterns_12rules[0])
#define LIFE_14RULES (sizeof patterns_14rules / sizeof patterns_14rules[0])
#define LIFE_18RULES (sizeof patterns_18rules / sizeof patterns_18rules[0])
#define LIFE_20RULES (sizeof patterns_20rules / sizeof patterns_20rules[0])
#define LIFE_26RULES (sizeof patterns_26rules / sizeof patterns_26rules[0])
